@@ -25,26 +25,44 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GameThread.cpp,v 1.2 2007/02/04 12:34:49 bowkenken Exp $
+* $Id: GameThread.cpp,v 1.12 2007/12/24 16:37:22 bowkenken Exp $
 ***************************************************************/
 
-#ifdef D_WIN
-# include <windows.h>
-#else // D_WIN
+#if defined( D_MFC )
+# include "xlnl-dows/stdafx.h"
+#elif defined( D_DOWS )
+# ifndef	_WINDOWS_
+#  include	<windows.h>
+# endif
+#else // D_DOWS
 # include <pthread.h>
-#endif // D_WIN
+#endif // D_DOWS
 
 ////////////////////////////////////////////////////////////////
 
 #include "GameThread.h"
 
+static void *(*gGameFunc)( void * ) = NULL;
+
+#ifdef D_MFC
+static CWinThread *thread = NULL;
+#endif // D_MFC
+
 ////////////////////////////////////////////////////////////////
 // MS-Windows ѤΥåѡ
 ////////////////////////////////////////////////////////////////
 
-#ifdef D_WIN
+#if defined( D_MFC )
 
-static void *(*gGameFunc)( void * ) = NULL;
+UINT __cdecl GameThread( LPVOID pParam )
+{
+	if( gGameFunc != NULL )
+		gGameFunc( NULL );
+
+	return 0;
+}
+
+#elif defined( D_DOWS )
 
 DWORD WINAPI GameThread( void *arg )
 {
@@ -54,7 +72,7 @@ DWORD WINAPI GameThread( void *arg )
 	return 0;
 }
 
-#endif // D_WIN
+#endif
 
 ////////////////////////////////////////////////////////////////
 // åɤڤ
@@ -64,30 +82,62 @@ DWORD WINAPI GameThread( void *arg )
 
 bool GameThreadCreate( void *(*func)( void * ) )
 {
-#ifdef D_WIN
+	gGameFunc = func;
+
+#if defined( D_MFC )
+	thread = ::AfxBeginThread(
+			(AFX_THREADPROC)GameThread, (LPVOID)NULL );
+#elif defined( D_DOWS )
 # if 0
-//@@@
 	unsigned dmy = 0;
 	int id = _beginthreadex( NULL, 0, func, (void *)1, 0, &dmy );
 	if( id == 0 )
 		return false;
 # else
 	DWORD id = 0;
-	gGameFunc = func;
-	HANDLE status = CreateThread( NULL, 0,
-		GameThread,
-		NULL, 0, &id );
+	HANDLE status = CreateThread( NULL, 0, GameThread, NULL, 0, &id );
 	if( status == FALSE )
 		return false;
 # endif
-#else // D_WIN
+#else
 	pthread_t id;
 	int status = pthread_create( &id, NULL, func, (void *)NULL );
 	if( status != 0 )
 		return false;
 
 	pthread_detach( id );
-#endif // D_WIN
+#endif
+
+	return true;
+}
+
+////////////////////////////////////////////////////////////////
+// åɤλ
+// void *(*func)( void * ) : åɤΥȥ꡼ؿ
+// long code : λ
+// return : 顼̵ä
+////////////////////////////////////////////////////////////////
+
+bool GameThreadExit( void *(*func)( void * ), long code )
+{
+	if( gGameFunc != func )
+		return false;
+
+#if defined( D_MFC )
+	if( thread != NULL ){
+		TRY {
+			::AfxEndThread( (UINT)code, true );
+		} CATCH( CException, e ){
+		} END_CATCH
+
+//@@@		delete thread;
+		thread = NULL;
+	}
+#elif defined( D_DOWS )
+	ExitThread( (DWORD)code );
+#else
+	pthread_exit( (void *)code );
+#endif
 
 	return true;
 }
