@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GlobalVar.h,v 1.11 2007/02/23 05:30:28 bowkenken Exp $
+* $Id: GlobalVar.h,v 1.20 2007/12/10 06:52:36 bowkenken Exp $
 ***************************************************************/
 
 #ifndef GLOBAL_VAR_H
@@ -55,27 +55,42 @@ typedef long GtkButton;
 # include "GuiStat.h"
 #endif // D_GTK
 
+#ifdef D_WS
+# include "StatWinIdx.h"
+#endif // D_WS
+
+#include "SelConf.h"
 #include "GuiMenu.h"
 #include "GuiMessage.h"
+#include "GuiStat.h"
 #include "GuiNum.h"
 #include "GuiInputString.h"
 #include "FileList.h"
 #include "PcgDun.h"
 #include "Key.h"
 #include "MouseMotion.h"
-#include "StatWinIdx.h"
 #include "party.h"
 
+#ifdef D_MFC
+# include "xlnl-dows/Dir3d.h"
+#endif // D_MFC
+
 ////////////////////////////////////////////////////////////////
 // GUI طΥХѿ
 ////////////////////////////////////////////////////////////////
 
+// եå
+extern SelConf gSelConf;
+
 // ˥塼ɥ
 extern GuiMenu gGuiMenu;
 
 // åɥ
 extern GuiMessage gGuiMessage;
 
+// ơɥ
+extern GuiStat gGuiStat;
+
 // ϥɥ
 extern GuiNum gGuiNum;
 
@@ -102,7 +117,7 @@ extern long nMarginY;
 
 #ifdef D_WS
 extern WSCbase *gStatLabel[MBR_MAX_N][STAT_WIN_IDX_MAX_N];
-#endif // D_WS
+# endif // D_WS
 
 #ifdef D_GTK
 extern GtkWidget *gMapWin;
@@ -119,4 +134,10 @@ extern GtkWidget *gMapVScrollBar;
 extern GuiStat gGuiStat;
 #endif // D_GTK
 
+#ifdef D_MFC
+extern volatile bool gFlagInitMfcDone;
+extern bool gFlagExit;
+extern CDir3d g_Dir3d;
+#endif // D_MFC
+
 #endif /* GLOBAL_VAR_H */
