@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiInputString.h,v 1.3 2007/02/23 05:30:28 bowkenken Exp $
+* $Id: GuiInputString.h,v 1.9 2007/12/03 05:43:53 bowkenken Exp $
 ***************************************************************/
 
 #ifndef GUI_INPUT_STRING_H
@@ -35,11 +35,6 @@
 // ʸϡɥ
 ////////////////////////////////////////////////////////////////
 
-#define GUI_INPUT_STRING_CPP
-#include "inc.h"
-
-////////////////////////////////////////////////////////////////
-
 class GuiInputString {
 
 	//////// ץ饤١ȡСѿ ////////
