@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiMenu.cpp,v 1.18 2007/02/28 15:21:47 bowkenken Exp $
+* $Id: GuiMenu.cpp,v 1.31 2007/12/10 06:52:36 bowkenken Exp $
 ***************************************************************/
 
 #include	"gmain.h"
@@ -94,6 +94,12 @@
 # include "main-gtk-prot.h"
 #endif // D_GTK
 
+#ifdef D_MFC
+# include "xlnl-dows/stdafx.h"
+# include "xlnl-dows/xlnl-dows.h"
+# include "xlnl-dows/MenuWnd.h"
+#endif // D_MFC
+
 ////////////////////////////////////////////////////////////////
 
 #define	GUI_MENU_BTN_MARGIN_X	4
@@ -121,29 +127,29 @@ void handle_menu_win_destroy(
 );
 
 void handle_menu_page_release(
-	GtkWidget *widget, GdkEventButton *event, gpointer *data
+	GtkWidget *widget, GdkEventButton *event, gpointer data
 );
 void handle_menu_cancel_release(
-	GtkWidget *widget, GdkEventButton *event, gpointer *data
+	GtkWidget *widget, GdkEventButton *event, gpointer data
 );
 void handle_menu_cancel_all_release(
-	GtkWidget *widget, GdkEventButton *event, gpointer *data
+	GtkWidget *widget, GdkEventButton *event, gpointer data
 );
 
 void handle_menu_button_clicked(
-	GtkWidget *widget, gpointer *data
+	GtkWidget *widget, gpointer data
 );
 void handle_menu_button_press(
-	GtkWidget *widget, GdkEventButton *event, gpointer *data
+	GtkWidget *widget, GdkEventButton *event, gpointer data
 );
 void handle_menu_button_release(
-	GtkWidget *widget, GdkEventButton *event, gpointer *data
+	GtkWidget *widget, GdkEventButton *event, gpointer data
 );
 void handle_menu_button_enter(
-	GtkWidget *widget, gpointer *data
+	GtkWidget *widget, gpointer data
 );
 void handle_menu_button_leave(
-	GtkWidget *widget, gpointer *data
+	GtkWidget *widget, gpointer data
 );
 
 #endif // D_GTK
@@ -361,6 +367,22 @@ void GuiMenu::newWin()
 			(gpointer)i );
 	}
 #endif // D_GTK
+
+#ifdef D_MFC
+	mMenuWin = &(theApp.m_MenuWnd);
+
+	for( long i = IDC_MENU_WND_BTN_BGN;
+			i < IDC_MENU_WND_BTN_END; i++ ){
+		long n = i - IDC_MENU_WND_BTN_BGN;
+
+		if( n >= MENU_MAX_N_PER_PAGE ){
+			aBtnMenu[n] = NULL;
+			break;
+		}
+
+		aBtnMenu[n] = &(mMenuWin->m_aBtn[n]);
+	}
+#endif // D_MFC
 }
 
 ////////////////////////////////////////////////////////////////
@@ -369,6 +391,9 @@ void GuiMenu::newWin()
 
 void GuiMenu::destroy()
 {
+	if( mMenuWin == NULL )
+		return;
+
 #ifdef D_GTK
 	for( long i = 0; i < MENU_MAX_N_PER_PAGE; i++ )
 		gtk_widget_destroy( aBtnMenu[i] );
@@ -377,6 +402,11 @@ void GuiMenu::destroy()
 
 	mMenuWin = NULL;
 #endif // D_GTK
+
+#ifdef D_MFC
+	delete mMenuWin;
+	mMenuWin = (CMenuWnd *)NULL;
+#endif // D_MFC
 }
 
 ////////////////////////////////////////////////////////////////
@@ -413,6 +443,10 @@ void GuiMenu::draw( draw_menu_t *data )
 			NULL );
 #endif // D_GTK
 
+#ifdef D_MFC
+	mMenuWin->SetWindowText( (LPCTSTR)msgTitle );
+#endif // D_MFC
+
 	// ڡڤؤܥ ON/OFF
 
 #ifdef D_WS
@@ -453,6 +487,23 @@ void GuiMenu::draw( draw_menu_t *data )
 	}
 #endif // D_GTK
 
+#ifdef D_MFC
+	if( data->flg_min_page ){
+		mMenuWin->m_BtnPrevPage.SetWindowText(
+				MSG_GUI_MENU_PREV_PAGE_OFF );
+	} else {
+		mMenuWin->m_BtnPrevPage.SetWindowText(
+				MSG_GUI_MENU_PREV_PAGE_ON );
+	}
+	if( data->flg_max_page ){
+		mMenuWin->m_BtnNextPage.SetWindowText(
+				MSG_GUI_MENU_NEXT_PAGE_OFF );
+	} else {
+		mMenuWin->m_BtnNextPage.SetWindowText(
+				MSG_GUI_MENU_NEXT_PAGE_ON );
+	}
+#endif // D_MFC
+
 	// ڡ
 
 	WSCstring strPage = "";
@@ -471,10 +522,20 @@ void GuiMenu::draw( draw_menu_t *data )
 	gtk_label_set_text( GTK_LABEL( labelMenuPageN ), (char *)strPage );
 #endif // D_GTK
 
+#ifdef D_MFC
+	mMenuWin->m_LblPage.SetWindowText( (char *)strPage );
+
+	mMenuWin->m_BtnCancel.SetWindowText(
+			MSG_GUI_MENU_CANCEL_ON );
+	mMenuWin->m_BtnCancelAll.SetWindowText(
+			MSG_GUI_MENU_CANCEL_ALL_ON );
+#endif // D_MFC
+
 	// åޡ褹뤫Ĵ٤
 
+	long i = 0;
 	bool FlagUseOnOff = false;
-	for( long i = 0; i < MENU_MAX_N_PER_PAGE; i++ ){
+	for( i = 0; i < MENU_MAX_N_PER_PAGE; i++ ){
 		if( data->ls[i] == NULL )
 			break;
 
@@ -485,9 +546,19 @@ void GuiMenu::draw( draw_menu_t *data )
 		}
 	}
 
+#ifdef D_MFC
+	bool flgGroup = false;
+	bool flgGroupSwitch = false;
+
+	CRect rectBgn, rectEnd;
+	mMenuWin->m_BtnPrevPage.GetWindowRect( &rectBgn );
+	mMenuWin->m_BtnCancelAll.GetWindowRect( &rectEnd );
+
+	long maxW = rectEnd.right - rectBgn.left;
+#endif // D_MFC
+
 	// ˥塼̾ܥ
 
-	long i = 0;
 	for( i = 0; i < MENU_MAX_N_PER_PAGE; i++ ){
 		if( data->ls[i] == NULL )
 			break;
@@ -551,9 +622,36 @@ void GuiMenu::draw( draw_menu_t *data )
 		WSCstring msg = "";
 		msg += msgChk + msgAccel;
 		msg += msgContents;
+		msg += WSCstring( " " ) + msgOpenWin;
 		msg += WSCstring( " " ) + msgShort;
 		msg += WSCstring( " " ) + msgBranch;
 
+		// ȥ롦ܥΥץѥƥ
+
+#ifdef D_MFC
+		flgGroupSwitch = false;
+		ULONG flgBtn = WS_VISIBLE;
+
+		if( strcmp( data->ls[i]->kind, "<CheckItem>" ) == 0 )
+			flgBtn |= BS_AUTOCHECKBOX;
+		if( strcmp( data->ls[i]->kind, "<RadioItem>" ) == 0 )
+			flgBtn |= BS_AUTORADIOBUTTON;
+
+		if( strcmp( data->ls[i]->kind, "<RadioItem>" ) == 0 ){
+			if( !flgGroup )
+				flgGroupSwitch = true;
+			flgGroup = true;
+		} else {
+			if( flgGroup )
+				flgGroupSwitch = true;
+			flgGroup = false;
+		}
+		if( flgGroupSwitch )
+			flgBtn |= WS_GROUP;
+
+		aBtnMenu[i]->SetButtonStyle( flgBtn, TRUE );
+#endif // D_MFC
+
 		// ˥塼ܥΥץѥƥ
 
 #ifdef D_WS
@@ -574,6 +672,19 @@ void GuiMenu::draw( draw_menu_t *data )
 		gtk_widget_show( aBtnMenu[i] );
 #endif // D_GTK
 
+#ifdef D_MFC
+		cAccelKey[i] = data->ls[i]->accel_key;
+
+		aBtnMenu[i]->SetWindowText( msg );
+
+		CClientDC dc( aBtnMenu[i] );
+		CSize size = dc.GetOutputTextExtent(
+				(char *)msg );
+		maxW = max_l( maxW, (long)(size.cx) );
+
+		aBtnMenu[i]->ShowWindow( SW_SHOW );
+#endif // D_MFC
+
 		// ǥեȤιܤ˥եư
 
 		if( i == data->sel_n ){
@@ -584,8 +695,17 @@ void GuiMenu::draw( draw_menu_t *data )
 #ifdef D_GTK
 			gtk_widget_grab_focus( aBtnMenu[i] );
 #endif // D_GTK
+
+#ifdef D_MFC
+			aBtnMenu[i]->SetFocus();
+#endif // D_MFC
 		}
 	}
+
+#ifdef D_MFC
+	long n = i;
+#endif // D_MFC
+
 	for( ; i < MENU_MAX_N_PER_PAGE; i++ ){
 		// ;äܥɽˤ
 
@@ -600,8 +720,65 @@ void GuiMenu::draw( draw_menu_t *data )
 #ifdef D_GTK
 		gtk_widget_hide( aBtnMenu[i] );
 #endif // D_GTK
+
+#ifdef D_MFC
+		aBtnMenu[i]->ShowWindow( SW_HIDE );
+#endif // D_MFC
 	}
 
+	// ܥ򤽤
+
+#ifdef D_MFC
+	long y = 0;
+
+	CRect rect;
+	mMenuWin->m_BtnPrevPage.GetWindowRect( &rect );
+	y += rect.Height();
+
+	for( long j = 0; j < n; j++ ){
+		if( data->ls[j] == NULL )
+			break;
+		if( data->ls[j]->msg == NULL )
+			continue;
+		if( aBtnMenu[j] == NULL )
+			continue;
+
+		CRect rect;
+		aBtnMenu[j]->GetWindowRect( &rect );
+		aBtnMenu[j]->MoveWindow(
+				0, y,
+				maxW, rect.Height(),
+				TRUE );
+		y += rect.Height();
+	}
+#endif // D_MFC
+
+	// ɥΥܥ˹碌
+
+#ifdef D_MFC
+	if( n > 0 ){
+		CRect rectPrev, rectBtn, rectWnd;
+
+		mMenuWin->m_BtnPrevPage
+				.GetWindowRect( &rectPrev );
+		aBtnMenu[n - 1]->GetWindowRect( &rectBtn );
+		mMenuWin->GetWindowRect( &rectWnd );
+
+		CRect rectAdj( 0, 0,
+				maxW, (rectBtn.bottom - rectPrev.top) );
+		::AdjustWindowRectEx( &rectAdj,
+				mMenuWin->GetStyle(), FALSE,
+				mMenuWin->GetExStyle() );
+
+		mMenuWin->MoveWindow(
+				rectWnd.left,
+				rectWnd.top,
+				rectAdj.Width(),
+				rectAdj.Height(),
+				TRUE );
+	}
+#endif // D_MFC
+
 	// ˥塼ɥɽ
 
 #ifdef D_WS
@@ -611,6 +788,11 @@ void GuiMenu::draw( draw_menu_t *data )
 #ifdef D_GTK
 	showWin( mMenuWin, &nWinX, &nWinY, NULL, NULL );
 #endif // D_GTK
+
+#ifdef D_MFC
+	mMenuWin->ShowWindow( SW_SHOW );
+	mMenuWin->UpdateWindow();
+#endif // D_MFC
 }
 
 ////////////////////////////////////////////////////////////////
@@ -619,15 +801,24 @@ void GuiMenu::draw( draw_menu_t *data )
 
 void GuiMenu::wipe()
 {
-	newWin();
-
 #ifdef D_WS
+	if( mMenuWin == NULL )
+		return;
+
 	MenuWin->setVisible( false );
 #endif // D_WS
 
 #ifdef D_GTK
 	wipeWin( mMenuWin, &nWinX, &nWinY, &nWinW, &nWinH );
 #endif // D_GTK
+
+#ifdef D_MFC
+	if( mMenuWin == NULL )
+		return;
+
+	mMenuWin->ShowWindow( SW_HIDE );
+	mMenuWin->UpdateWindow();
+#endif // D_MFC
 }
 
 ////////////////////////////////////////////////////////////////
@@ -680,7 +871,7 @@ void GuiMenu::setMouseDfltMenu( long sel_n )
 
 ////////////////////////////////////////////////////////////////
 // ˥塼Υܥֹ椫饢졼Ѵ
-// WSCbase *obj : å줿ܥ
+// long n : ˥塼Υܥֹ
 ////////////////////////////////////////////////////////////////
 
 char	GuiMenu::getAccelKey( long n )
@@ -747,7 +938,7 @@ void handle_menu_win_destroy(
 #ifdef D_GTK
 
 void handle_menu_page_release(
-	GtkWidget *widget, GdkEventButton *event, gpointer *data
+	GtkWidget *widget, GdkEventButton *event, gpointer data
 )
 {
 	long d = (long)data;
@@ -777,7 +968,7 @@ void handle_menu_page_release(
 #ifdef D_GTK
 
 void handle_menu_cancel_release(
-	GtkWidget *widget, GdkEventButton *event, gpointer *data
+	GtkWidget *widget, GdkEventButton *event, gpointer data
 )
 {
 	gKey.setString( "0" );
@@ -795,7 +986,7 @@ void handle_menu_cancel_release(
 #ifdef D_GTK
 
 void handle_menu_cancel_all_release(
-	GtkWidget *widget, GdkEventButton *event, gpointer *data
+	GtkWidget *widget, GdkEventButton *event, gpointer data
 )
 {
 	gKey.setString( "/" );
@@ -812,7 +1003,7 @@ void handle_menu_cancel_all_release(
 #ifdef D_GTK
 
 void handle_menu_button_clicked(
-	GtkWidget *widget, gpointer *data
+	GtkWidget *widget, gpointer data
 )
 {
 	gKey.setChar( gGuiMenu.getAccelKey( (long)data ) );
@@ -830,7 +1021,7 @@ void handle_menu_button_clicked(
 #ifdef D_GTK
 
 void handle_menu_button_press(
-	GtkWidget *widget, GdkEventButton *event, gpointer *data
+	GtkWidget *widget, GdkEventButton *event, gpointer data
 )
 {
 	gGuiMenu.nClickedButton = (long)data;
@@ -849,7 +1040,7 @@ void handle_menu_button_press(
 #ifdef D_GTK
 
 void handle_menu_button_release(
-	GtkWidget *widget, GdkEventButton *event, gpointer *data
+	GtkWidget *widget, GdkEventButton *event, gpointer data
 )
 {
 	if( !gGuiMenu.bFlagEnter )
@@ -874,7 +1065,7 @@ void handle_menu_button_release(
 #ifdef D_GTK
 
 void handle_menu_button_enter(
-	GtkWidget *widget, gpointer *data
+	GtkWidget *widget, gpointer data
 )
 {
 	if( gGuiMenu.nClickedButton == (long)data )
@@ -893,7 +1084,7 @@ void handle_menu_button_enter(
 #ifdef D_GTK
 
 void handle_menu_button_leave(
-	GtkWidget *widget, gpointer *data
+	GtkWidget *widget, gpointer data
 )
 {
 	gGuiMenu.bFlagEnter = FALSE;
