@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiMessage.h,v 1.10 2007/02/23 05:30:28 bowkenken Exp $
+* $Id: GuiMessage.h,v 1.17 2007/12/25 06:13:08 bowkenken Exp $
 ***************************************************************/
 
 #ifndef GUI_MESSAGE_H
@@ -53,16 +53,27 @@ private:
 #ifdef D_GTK
 	gint nPreX, nPreY, nPreW, nPreH;
 	GtkWidget *mMessageWin;
+	GtkWidget *mMessageDrawingArea;
 	GtkWidget *mMessageHScrollBar;
 	GtkWidget *mMessageVScrollBar;
+	GtkObject *mMessageHScrollBarAdjustment;
+	GtkObject *mMessageVScrollBarAdjustment;
 
 	GdkGC *mFgGc;
 	GdkGC *mBgGc;
+	GtkStyle *mStyle;
 #endif // D_GTK
 
+#ifdef D_MFC
+	void *mMessageWin;
+	CClientDC *pDc;
+#endif // D_MFC
+
 	//////// ѥ֥åСѿ ////////
 public:
 
+	// Դֳ
+	static const long LINE_INTERVAL = 1;
 	long mLsMessageDrawBeginN;
 	long mLsMessageDrawN;
 
@@ -70,51 +81,27 @@ public:
 #endif // D_WS
 
 #ifdef D_GTK
-	GtkWidget *mMessageDrawingArea;
-	GtkObject *mMessageHScrollBarAdjustment;
-	GtkObject *mMessageVScrollBarAdjustment;
-
-	GdkFont *mFont[1];
 #endif // D_GTK
 
 	//////// ѥ֥åСؿ ////////
 public:
 
-	GuiMessage()
-	{
-		flagMore = FALSE;
-
-#ifdef D_GTK
-		nPreX = -1;
-		nPreY = -1;
-		nPreW = -1;
-		nPreH = -1;
-
-		mMessageWin = NULL;
-		mMessageDrawingArea = NULL;
-		mMessageHScrollBarAdjustment = NULL;
-		mMessageVScrollBarAdjustment = NULL;
-
-		mFgGc = NULL;
-		mBgGc = NULL;
-#endif // D_GTK
-
-		mLsMessageDrawBeginN = 0;
-		mLsMessageDrawN = 0;
-	}
-	~GuiMessage()
-	{
-	}
+	GuiMessage();
+	~GuiMessage();
 
 	void init();
 	void destroy();
 
 	void setFlagMore( bool flag );
+
 	void redraw();
 	void draw( bool flagRedraw );
 	void wipe();
 	void drawScrollBar();
 
+	void hScroll( long n );
+	void vScroll( long n );
+
 	//////// ץ饤١ȡСؿ ////////
 private:
 
