@@ -25,20 +25,28 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiNum.cpp,v 1.5 2007/02/26 00:50:37 bowkenken Exp $
+* $Id: GuiNum.cpp,v 1.15 2007/12/10 06:52:36 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
 // ϥɥ
 ////////////////////////////////////////////////////////////////
 
+#include "gmain.h"
+#include "menu.h"
+#include "menu-prot.h"
 #include "GuiNum.h"
 #include "GlobalVar.h"
 
+#ifdef D_MFC
+# include "xlnl-dows/InputNumDlg.h"
+#endif // D_MFC
+
 ////////////////////////////////////////////////////////////////
 // ٥ȡϥɥ
 ////////////////////////////////////////////////////////////////
 
+#ifdef D_GTK
 void handle_num_destroy( GtkWidget *widget, gpointer user_data );
 gint handle_num_expose( GtkWidget *widget, GdkEventExpose *event );
 
@@ -51,6 +59,7 @@ void handle_num_up_clicked( GtkButton *button, gpointer user_data );
 void handle_num_down_clicked( GtkButton *button, gpointer user_data );
 
 void handle_num_ok_clicked( GtkButton *button, gpointer user_data );
+#endif // D_GTK
 
 ////////////////////////////////////////////////////////////////
 // ϥɥν
@@ -75,6 +84,8 @@ void GuiNum::newWin()
 #endif // D_WS
 
 #ifdef D_GTK
+	long	n;
+
 	// ϥɥκ
 
 	mNumWin = gtk_window_new( GTK_WINDOW_TOPLEVEL );
@@ -245,25 +256,25 @@ void GuiNum::newWin()
 
 		// ܥؤΥ٥ȡϥɥ
 
-		GtkLabel *lbl = get_label_from_button(
-				GTK_BUTTON( mButtonLabel[i] ) );
 		if( flagComma )
-			lbl = NULL;
+			n = -1;
+		else
+			n = i;
 
 		gtk_signal_connect( GTK_OBJECT( mButtonLabel[i] ),
 				"clicked",
 				GTK_SIGNAL_FUNC( handle_num_0_clicked ),
-				(gpointer)lbl );
+				(gpointer)n );
 
 		gtk_signal_connect( GTK_OBJECT( mButtonUp[i] ),
 				"clicked",
 				GTK_SIGNAL_FUNC( handle_num_up_clicked ),
-				(gpointer)lbl );
+				(gpointer)n );
 
 		gtk_signal_connect( GTK_OBJECT( mButtonDown[i] ),
 				"clicked",
 				GTK_SIGNAL_FUNC( handle_num_down_clicked ),
-				(gpointer)lbl );
+				(gpointer)n );
 
 		// ܥåˤΤ
 
@@ -375,6 +386,10 @@ void GuiNum::newWin()
 
 	gtk_widget_show( mNumWin );
 #endif	// D_GTK
+
+#ifdef D_MFC
+	mNumWin = (void *)(new CInputNumDlg);
+#endif // D_MFC
 }
 
 ////////////////////////////////////////////////////////////////
@@ -383,24 +398,30 @@ void GuiNum::newWin()
 
 void GuiNum::destroy()
 {
+	if( mNumWin == NULL )
+		return;
+
 #ifdef D_GTK
 	mNumWin = NULL;
 #endif // D_GTK
+
+#ifdef D_MFC
+	delete ((CInputNumDlg *)mNumWin);
+	mNumWin = NULL;
+#endif // D_MFC
 }
 
 ////////////////////////////////////////////////////////////////
 // ϥɥɽ
 ////////////////////////////////////////////////////////////////
 
-void GuiNum::draw( long *n, long min, long max, long figure )
+void GuiNum::draw( volatile long *n, long min, long max, long figure )
 {
 	if( n == NULL )
 		return;
 
-	newWin();
-
-	mN = *n;
 	mPN = n;
+	mOrg = *n;
 	mMin = min;
 	mMax = max;
 	mFigure = figure;
@@ -414,16 +435,33 @@ void GuiNum::draw( long *n, long min, long max, long figure )
 
 void GuiNum::redraw()
 {
-	newWin();
+	if( mNumWin == NULL ){
+		newWin();
+	} else {
+#ifdef D_MFC
+		CInputNumDlg *dlg = (CInputNumDlg *)mNumWin;
+
+		WSCstring str;
+		str = (long)*mPN;
+		dlg->m_Edit.SetWindowText( str );
+
+		dlg->SetSldrPos( *mPN );
+
+		return;
+#endif // D_MFC
+	}
+
+	if( mPN == NULL )
+		return;
 
 #ifdef D_GTK
 	GtkAdjustment *adj;
 
 	adj = GTK_ADJUSTMENT( mHscaleAdjustment );
-	if( adj->value != mN ){
+	if( adj->value != *mPN ){
 		long incPage = 1;
 
-		adj->value = mN;
+		adj->value = *mPN;
 		adj->lower = mMin;
 		adj->upper = mMax + incPage;
 		adj->step_increment = 1;
@@ -434,10 +472,10 @@ void GuiNum::redraw()
 	}
 
 	adj = GTK_ADJUSTMENT( mNumAdjustment );
-	if( adj->value != mN ){
+	if( adj->value != *mPN ){
 		long incPage = 1;
 
-		adj->value = mN;
+		adj->value = *mPN;
 		adj->lower = mMin;
 		adj->upper = mMax + incPage;
 		adj->step_increment = 1;
@@ -450,6 +488,18 @@ void GuiNum::redraw()
 	cvUpDownFromN();
 	gtk_widget_show( mNumWin );
 #endif // D_GTK
+
+#ifdef D_MFC
+	CInputNumDlg *dlg = (CInputNumDlg *)mNumWin;
+	dlg->m_Min = mMin;
+	dlg->m_Max = mMax;
+	dlg->m_Org = *mPN;
+	dlg->m_Cur = mPN;
+
+	dlg->DoModal();
+
+	destroy();
+#endif // D_MFC
 }
 
 ////////////////////////////////////////////////////////////////
@@ -459,8 +509,15 @@ void GuiNum::redraw()
 void GuiNum::wipe()
 {
 #ifdef D_GTK
+	if( mNumWin == NULL )
+		return;
+
 	gtk_widget_hide( mNumWin );
 #endif // D_GTK
+
+#ifdef D_MFC
+	destroy();
+#endif // D_MFC
 }
 
 ////////////////////////////////////////////////////////////////
@@ -469,29 +526,47 @@ void GuiNum::wipe()
 
 void GuiNum::valueChanged( long n )
 {
-	mN = n;
+	if( mPN == NULL )
+		return;
+
+	*mPN = n;
+	gKey.setChar( '|' );
 
 	redraw();
 }
 
 ////////////////////////////////////////////////////////////////
 // ٥οͤ
-// void *lbl : ٥
+// long n : ٥ֹ
 // long d : +1, -1 ξ0 ξ 0 ꥢ
 ////////////////////////////////////////////////////////////////
 
-
-void GuiNum::up_down_num_label( void *lbl, long d )
+void GuiNum::up_down_num_label( long n, long d )
 {
-	if( lbl == NULL )
+	if( n <= -1 )
+		return;
+	if( n >= GUI_NUM_BUTTON_MAX_N )
 		return;
 
-	char *str = NULL;
 #ifdef D_WS
 #endif // D_WS
+
 #ifdef D_GTK
-	gtk_label_get( GTK_LABEL( lbl ), &str );
+	char *str = NULL;
+
+	GtkLabel *lbl = get_label_from_button(
+			GTK_BUTTON( gGuiNum.mButtonLabel[n] ) );
+
+	gtk_label_get( lbl, &str );
 #endif // D_GTK
+
+#ifdef D_MFC
+	char str[4 + 1];
+
+	((CInputNumDlg *)mNumWin)->m_Clr[n]
+			.GetWindowText( str, 1 + 1 );
+#endif // D_MFC
+
 	if( str == NULL )
 		return;
 
@@ -502,12 +577,23 @@ void GuiNum::up_down_num_label( void *lbl, long d )
 	num[0] = c;
 	num[1] = '\0';
 
+	if( (c == '+') || (c == '-') )
+		gKey.setChar( KEY_MENU_NUM_SGN );
+	else
+		gKey.setChar( 'A' + (n - n / 4) );
+
 #ifdef D_WS
 #endif // D_WS
+
 #ifdef D_GTK
-	gtk_label_set_text( GTK_LABEL( lbl ), num );
+	gtk_label_set_text( lbl, num );
 #endif // D_GTK
 
+#ifdef D_MFC
+	((CInputNumDlg *)mNumWin)->m_Clr[n]
+			.SetWindowText( num );
+#endif // D_MFC
+
 	cvUpDownToN();
 	redraw();
 }
@@ -530,8 +616,8 @@ char GuiNum::up_down_num_char( char c, long d )
 			c = '0';
 		} else {
 			long n = c - '0';
-			n = (n + d + 10) % 10;
-			c = n + '0';
+			n = ((n + d) % 10 + 10) % 10;
+			c = (char)n + '0';
 		}
 	} else {
 		c = '0';
@@ -575,6 +661,13 @@ void GuiNum::cvUpDownToN()
 		c = str[0];
 #endif // D_GTK
 
+#ifdef D_MFC
+		char str[1 + 1];
+		((CInputNumDlg *)mNumWin)->m_Clr[i]
+				.GetWindowText( str, 1 + 1 );
+		c = str[0];
+#endif // D_MFC
+
 		if( c == '+' ){
 			break;
 		} else if( c == '-' ){
@@ -587,7 +680,11 @@ void GuiNum::cvUpDownToN()
 		base *= 10;
 	}
 
-	mN = n;
+	if( mPN == NULL )
+		return;
+
+	*mPN = n;
+	gKey.setChar( '|' );
 }
 
 ////////////////////////////////////////////////////////////////
@@ -598,13 +695,16 @@ void GuiNum::cvUpDownFromN()
 {
 	newWin();
 
+	if( mPN == NULL )
+		return;
+
 #ifdef D_GTK
 	gtk_widget_show( mNumWin );
 
 	GtkLabel *lbl;
 	gchar str[1 + 1]  = "";
 
-	long n = labs( mN );
+	long n = labs( *mPN );
 	long f = 0;
 	long i = 0;
 	for( ; i < GUI_NUM_BUTTON_MAX_N; i++ ){
@@ -638,7 +738,7 @@ void GuiNum::cvUpDownFromN()
 		lbl = get_label_from_button(
 				GTK_BUTTON( mButtonLabel[i] ) );
 		if( lbl != NULL ){
-			if( sgn_l( mN ) <= -1 )
+			if( sgn_l( *mPN ) <= -1 )
 				gtk_label_set_text( lbl, "-" );
 			else
 				gtk_label_set_text( lbl, "+" );
@@ -667,6 +767,55 @@ void GuiNum::cvUpDownFromN()
 		gtk_widget_hide( mButtonDown[i] );
 	}
 #endif // D_GTK
+
+#ifdef D_MFC
+	char str[1 + 1]  = "";
+	CInputNumDlg *dlg = (CInputNumDlg *)mNumWin;
+
+	long n = labs( *mPN );
+	long f = 0;
+	long i = 0;
+	for( ; i < NUM_BTN_MAX; i++ ){
+		if( f >= mFigure )
+			break;
+
+		if( (i % 4) == 3 ){
+			dlg->m_Clr[i].SetWindowText( "," );
+		} else {
+			str[0] = '0' + (char)(n % 10);
+			str[1] = '\0';
+			dlg->m_Clr[i].SetWindowText( str );
+
+			f++;
+			n /= 10;
+		}
+
+		dlg->m_Clr[i].ShowWindow( SW_SHOW );
+		dlg->m_Inc[i].ShowWindow( SW_SHOW );
+		dlg->m_Dec[i].ShowWindow( SW_SHOW );
+	}
+
+	if( i < NUM_BTN_MAX ){
+		if( sgn_l( *mPN ) <= -1 )
+			dlg->m_Clr[i].SetWindowText( "-" );
+		else
+			dlg->m_Clr[i].SetWindowText( "+" );
+
+		dlg->m_Clr[i].ShowWindow( SW_SHOW );
+		dlg->m_Inc[i].ShowWindow( SW_SHOW );
+		dlg->m_Dec[i].ShowWindow( SW_SHOW );
+
+		i++;
+	}
+
+	for( ; i < NUM_BTN_MAX; i++ ){
+		dlg->m_Clr[i].SetWindowText( "0" );
+
+		dlg->m_Clr[i].ShowWindow( SW_HIDE );
+		dlg->m_Inc[i].ShowWindow( SW_HIDE );
+		dlg->m_Dec[i].ShowWindow( SW_HIDE );
+	}
+#endif // D_MFC
 }
 
 ////////////////////////////////////////////////////////////////
@@ -676,25 +825,35 @@ void GuiNum::cvUpDownFromN()
 
 void GuiNum::okClicked( menu_num_t n )
 {
+	if( mPN == NULL )
+		return;
+
 	switch( n ){
 	case MENU_NUM_MIN:
-		mN = mMin;
+		*mPN = mMin;
+		gKey.setChar( KEY_MENU_NUM_MIN );
 		break;
 	case MENU_NUM_CLR:
-		mN = *mPN;
+		*mPN = mOrg;
+		gKey.setChar( KEY_MENU_NUM_CLR );
 		break;
 	case MENU_NUM_MAX:
-		mN = mMax;
+		*mPN = mMax;
+		gKey.setChar( KEY_MENU_NUM_MAX );
 		break;
 	case MENU_NUM_OK:
-		*mPN = mN;
 		gKey.setChar( '|' );
-		wipe();
+		gKey.setChar( KEY_MENU_NUM_OK );
 		break;
 	case MENU_NUM_MAX_N:
-		break;
+		return;
 	}
 
+	if( get_flg_space_select() )
+		gKey.setChar( ' ' );
+	else
+		gKey.setChar( '\n' );
+
 	redraw();
 }
 
@@ -702,10 +861,12 @@ void GuiNum::okClicked( menu_num_t n )
 // ϥɥνλΥϥɥ
 ////////////////////////////////////////////////////////////////
 
+#ifdef D_GTK
 void handle_num_destroy( GtkWidget *widget, gpointer user_data )
 {
 	gGuiNum.destroy();
 }
+#endif // D_GTK
 
 ////////////////////////////////////////////////////////////////
 // ϥɥ襤٥Ȥν
@@ -714,12 +875,14 @@ void handle_num_destroy( GtkWidget *widget, gpointer user_data )
 // return : ?
 ////////////////////////////////////////////////////////////////
 
+#ifdef D_GTK
 gint handle_num_expose( GtkWidget *widget, GdkEventExpose *event )
 {
 	gGuiNum.redraw();
 
 	return TRUE;
 }
+#endif // D_GTK
 
 ////////////////////////////////////////////////////////////////
 // ʿĴѲΥϥɥ
@@ -727,15 +890,15 @@ gint handle_num_expose( GtkWidget *widget, GdkEventExpose *event )
 // gpointer user_data : ߡ
 ////////////////////////////////////////////////////////////////
 
+#ifdef D_GTK
 void handle_num_hscale_changed( GtkAdjustment *adj, gpointer user_data )
 {
-#ifdef D_GTK
 	if( adj == NULL )
 		return;
 
 	gGuiNum.valueChanged( (long)(adj->value) );
-#endif // D_GTK
 }
+#endif // D_GTK
 
 ////////////////////////////////////////////////////////////////
 // ԥ󡦥ܥĴѲΥϥɥ
@@ -743,48 +906,54 @@ void handle_num_hscale_changed( GtkAdjustment *adj, gpointer user_data )
 // gpointer user_data : ߡ
 ////////////////////////////////////////////////////////////////
 
+#ifdef D_GTK
 void handle_num_spin_changed( GtkAdjustment *adj, gpointer user_data )
 {
-#ifdef D_GTK
 	if( adj == NULL )
 		return;
 
 	gGuiNum.valueChanged( (long)(adj->value) );
-#endif // D_GTK
 }
+#endif // D_GTK
 
 ////////////////////////////////////////////////////////////////
 // ꥢܥΥåΥϥɥ
 // GtkButton *button : ܥ
-// gpointer user_data : ٥
+// gpointer user_data : ܥֹ
 ////////////////////////////////////////////////////////////////
 
+#ifdef D_GTK
 void handle_num_0_clicked( GtkButton *button, gpointer user_data )
 {
-	gGuiNum.up_down_num_label( user_data, +-0 );
+	gGuiNum.up_down_num_label( (long)user_data, +-0 );
 }
+#endif // D_GTK
 
 ////////////////////////////////////////////////////////////////
 // ܥΥåΥϥɥ
 // GtkButton *button : ܥ
-// gpointer user_data : ٥
+// gpointer user_data : ܥֹ
 ////////////////////////////////////////////////////////////////
 
+#ifdef D_GTK
 void handle_num_up_clicked( GtkButton *button, gpointer user_data )
 {
-	gGuiNum.up_down_num_label( user_data, +1 );
+	gGuiNum.up_down_num_label( (long)user_data, +1 );
 }
+#endif // D_GTK
 
 ////////////////////////////////////////////////////////////////
 // ܥΥåΥϥɥ
 // GtkButton *button : ܥ
-// gpointer user_data : ٥
+// gpointer user_data : ܥֹ
 ////////////////////////////////////////////////////////////////
 
+#ifdef D_GTK
 void handle_num_down_clicked( GtkButton *button, gpointer user_data )
 {
-	gGuiNum.up_down_num_label( user_data, -1 );
+	gGuiNum.up_down_num_label( (long)user_data, -1 );
 }
+#endif // D_GTK
 
 ////////////////////////////////////////////////////////////////
 // ǾܥΥåΥϥɥ
@@ -792,7 +961,9 @@ void handle_num_down_clicked( GtkButton *button, gpointer user_data )
 // gpointer user_data : ܥμ
 ////////////////////////////////////////////////////////////////
 
+#ifdef D_GTK
 void handle_num_ok_clicked( GtkButton *button, gpointer user_data )
 {
 	gGuiNum.okClicked( (menu_num_t)(int)user_data );
 }
+#endif // D_GTK
