@@ -25,63 +25,11 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiStat.cpp,v 1.5 2007/02/28 15:21:47 bowkenken Exp $
+* $Id: GuiStat.cpp,v 1.11 2007/12/11 09:21:44 bowkenken Exp $
 ***************************************************************/
 
-#include	"gmain.h"
-#include	"misc.h"
-//#include	"turn.h"
-//#include	"dun.h"
-//#include	"town.h"
-//#include	"item.h"
-//#include	"spell.h"
-//#include	"chr.h"
-#include	"party.h"
-//#include	"mnstr.h"
-//#include	"pet.h"
-//#include	"fight.h"
-//#include	"fx.h"
-//#include	"trap.h"
-#include	"draw.h"
-//#include	"curs.h"
-//#include	"menu.h"
-//#include	"amenu.h"
-//#include	"request.h"
-//#include	"gfile.h"
-#include	"msg.h"
-//#include	"ver.h"
-#include	"gmain-prot.h"
-#include	"misc-prot.h"
-//#include	"turn-prot.h"
-//#include	"dun-prot.h"
-//#include	"town-prot.h"
-//#include	"item-prot.h"
-//#include	"spell-prot.h"
-//#include	"chr-prot.h"
-#include	"party-prot.h"
-//#include	"mnstr-prot.h"
-//#include	"pet-prot.h"
-//#include	"fight-prot.h"
-//#include	"fx-prot.h"
-//#include	"trap-prot.h"
-#include	"draw-prot.h"
-//#include	"curs-prot.h"
-//#include	"menu-prot.h"
-//#include	"tmenu-prot.h"
-//#include	"amenu-prot.h"
-//#include	"request-prot.h"
-//#include	"gfile-prot.h"
-//#include	"msg-prot.h"
-
-////////////////////////////////////////////////////////////////
-
-# include <gtk/gtk.h>
-# include <gdk/gdk.h>
-
-#include "GuiStat.h"
-#include "GlobalVar.h"
-
-#include "main-gtk-prot.h"
+#define GUI_STAT_CPP
+#include "inc.h"
 
 ////////////////////////////////////////////////////////////////
 
@@ -98,6 +46,7 @@
 
 ////////////////////////////////////////////////////////////////
 
+#ifdef D_GTK
 void handle_stat_win_destroy(
 	GtkWidget *widget, gpointer data
 );
@@ -114,6 +63,7 @@ void handle_stat_name_clicked(
 void handle_stat_stat_clicked(
 	GtkWidget *widget, gpointer data
 );
+#endif // D_GTK
 
 ////////////////////////////////////////////////////////////////
 // ơν
@@ -134,6 +84,7 @@ void GuiStat::newWin()
 	if( mStatWin != NULL )
 		return;
 
+#ifdef D_GTK
 	// ơɥκ
 
 	mStatWin = gtk_window_new( GTK_WINDOW_TOPLEVEL );
@@ -174,6 +125,11 @@ void GuiStat::newWin()
 	//
 
 	gtk_widget_show( mStatWin );
+#endif // D_GTK
+
+#ifdef D_MFC
+	mStatWin = &(theApp.m_StatWnd);
+#endif // D_MFC
 }
 
 ////////////////////////////////////////////////////////////////
@@ -182,6 +138,7 @@ void GuiStat::newWin()
 // GtkWidget *vBox : 
 ////////////////////////////////////////////////////////////////
 
+#ifdef D_GTK
 void GuiStat::newWinMbr( mbr_t *mbr, GtkWidget *vBox )
 {
 	if( mbr == NULL )
@@ -314,6 +271,7 @@ void GuiStat::newWinMbr( mbr_t *mbr, GtkWidget *vBox )
 			GTK_SIGNAL_FUNC( handle_stat_stat_clicked ),
 			(gpointer)n );
 }
+#endif // D_GTK
 
 ////////////////////////////////////////////////////////////////
 // ơɥκ
@@ -321,6 +279,10 @@ void GuiStat::newWinMbr( mbr_t *mbr, GtkWidget *vBox )
 
 void GuiStat::destroy()
 {
+	if( mStatWin == NULL )
+		return;
+
+#ifdef D_GTK
 	for( long i = 0; i < MBR_MAX_N; i++ ){
 		gtk_widget_destroy( btnName[i] );
 		gtk_widget_destroy( labelAct[i] );
@@ -338,6 +300,11 @@ void GuiStat::destroy()
 	gtk_widget_destroy( vBox );
 
 	mStatWin = NULL;
+#endif // D_GTK
+
+#ifdef D_MFC
+	mStatWin = (CStatWnd *)NULL;
+#endif // D_MFC
 }
 
 ////////////////////////////////////////////////////////////////
@@ -345,15 +312,26 @@ void GuiStat::destroy()
 // long mbrN : Сֹ
 ////////////////////////////////////////////////////////////////
 
-void GuiStat::redraw()
+void GuiStat::redraw( bool flagAdj )
 {
 	for( long i = 0; i < MBR_MAX_N; i++ )
 		draw( i );
 
+#ifdef D_GTK
 	g_object_set( GTK_WINDOW( mStatWin ),
 			"allow-shrink", FALSE,
 			"allow-grow", FALSE,
 			NULL );
+#endif // D_GTK
+
+#ifdef D_MFC
+	if( mStatWin != NULL ){
+		mStatWin->ShowWindow( SW_SHOW );
+		mStatWin->UpdateWindow();
+		if( flagAdj )
+			mStatWin->AdjustWnd();
+	}
+#endif // D_MFC
 }
 
 ////////////////////////////////////////////////////////////////
@@ -382,7 +360,7 @@ void GuiStat::draw( long n )
 	} else {
 		sName = mbr->name;
 		sAct = mbr->act.msg;
-		sStat = "";
+		sStat = getStatStr( mbr );
 		nHp = mbr->abl.hp.n;
 		nMp = mbr->abl.mp.n;
 		nMaxHp = mbr->abl.hp.max;
@@ -396,6 +374,7 @@ void GuiStat::draw( long n )
 	sHp = bufHp;
 	sMp = bufMp;
 
+#ifdef D_GTK
 	// ٥
 
 	set_label_text_button( GTK_BUTTON( btnName[n] ),
@@ -413,8 +392,53 @@ void GuiStat::draw( long n )
 	gtk_misc_set_alignment( GTK_MISC( labelMp[n] ), 0.0, 0.5 );
 	gtk_label_set_text( GTK_LABEL( labelMp[n] ), (char *)sMp );
 
-	// HP, MP
+	// HP/MP ΥС
 
+	drawHpMp( n, true );
+	drawHpMp( n, false );
+#endif // D_GTK
+
+#ifdef D_MFC
+	// ٥
+
+	mStatWin->m_BtnName[n].SetWindowText( sName );
+	mStatWin->m_LabelAct[n].SetWindowText( sAct );
+	mStatWin->m_BtnStat[n].SetWindowText( sStat );
+	mStatWin->m_LabelHp[n].SetWindowText( sHp );
+	mStatWin->m_LabelMp[n].SetWindowText( sMp );
+
+	// HP/MP ΥС
+
+	drawHpMp( n, true );
+	drawHpMp( n, false );
+#endif // D_MFC
+}
+
+////////////////////////////////////////////////////////////////
+// ơɥ HP/MP ΥС
+// long n : Сֹ
+// bool flagHp : HP 褫? : true => HP, false => MP
+////////////////////////////////////////////////////////////////
+
+void GuiStat::drawHpMp( long n, bool flagHp )
+{
+	party_t *pty = get_party();
+	mbr_t *mbr = pty->mbr[n];
+
+	long nHpMp, nMaxHpMp;
+	if( flagHp ){
+		nHpMp = mbr->abl.hp.n;
+		nMaxHpMp = mbr->abl.hp.max;
+	} else {
+		nHpMp = mbr->abl.mp.n;
+		nMaxHpMp = mbr->abl.mp.max;
+	}
+
+#ifdef D_GTK
+	if( mDrawingAreaHp[n] == NULL)
+		return;
+	if( mDrawingAreaMp[n] == NULL)
+		return;
 	if( mDrawingAreaHp[n]->window == NULL)
 		return;
 	if( mDrawingAreaMp[n]->window == NULL)
@@ -424,236 +448,390 @@ void GuiStat::draw( long n )
 		mFgGcHp[n] = gdk_gc_new( mDrawingAreaHp[n]->window );
 	if( mBgGcHp[n] == NULL )
 		mBgGcHp[n] = gdk_gc_new( mDrawingAreaHp[n]->window );
-	GdkDrawable *gdHp = GDK_DRAWABLE( mDrawingAreaHp[n]->window );
 
 	if( mFgGcMp[n] == NULL )
 		mFgGcMp[n] = gdk_gc_new( mDrawingAreaMp[n]->window );
 	if( mBgGcMp[n] == NULL )
 		mBgGcMp[n] = gdk_gc_new( mDrawingAreaMp[n]->window );
-	GdkDrawable *gdMp = GDK_DRAWABLE( mDrawingAreaMp[n]->window );
 
-	//
+	GdkDrawable *gdHpMp = NULL;
+	if( flagHp ){
+		mFgGcHpMp = mFgGcHp[n];
+		mBgGcHpMp = mBgGcHp[n];
+		gdHpMp = GDK_DRAWABLE( mDrawingAreaHp[n]->window );
+	} else {
+		mFgGcHpMp = mFgGcMp[n];
+		mBgGcHpMp = mBgGcMp[n];
+		gdHpMp = GDK_DRAWABLE( mDrawingAreaMp[n]->window );
+	}
 
-	GdkColor colorFg1;
-	GdkColor colorFg2;
-	GdkColor colorFg3;
+	GdkColor colorFg[3];
 	GdkColor colorBg;
 	long maxW = 1;
 	long w = 1;
 
-	// HP
+	// 
 
-	rate_t nHpRate = 0;
+	rate_t nHpMpRate = 0;
 
-	if( nMaxHp > 0 ){
-		nHpRate = nHp * 100;
-		nHpRate /= nMaxHp;
+	if( nMaxHpMp > 0 ){
+		nHpMpRate = nHpMp * 100;
+		nHpMpRate /= nMaxHpMp;
 
 		colorBg.red = 0x0000;
 		colorBg.green = 0x0000;
 		colorBg.blue = 0x0000;
 	} else {
-		nHpRate = 0;
+		nHpMpRate = 0;
 
 		colorBg.red = 0x8888;
 		colorBg.green = 0x8888;
 		colorBg.blue = 0x8888;
 	}
 
-	if( nHpRate <= WARNING_HP_RATE_RED ){
-		colorFg1.red = 0xeeee;
-		colorFg1.green = 0x0000;
-		colorFg1.blue = 0x0000;
-
-		colorFg2.red = 0xcccc;
-		colorFg2.green = 0x0000;
-		colorFg2.blue = 0x0000;
-
-		colorFg3.red = 0xaaaa;
-		colorFg3.green = 0x0000;
-		colorFg3.blue = 0x0000;
-	} else if( nHpRate <= WARNING_HP_RATE_YELLOW ){
-		colorFg1.red = 0xaaaa;
-		colorFg1.green = 0xaaaa;
-		colorFg1.blue = 0x0000;
-
-		colorFg2.red = 0x8888;
-		colorFg2.green = 0x8888;
-		colorFg2.blue = 0x0000;
-
-		colorFg3.red = 0x6666;
-		colorFg3.green = 0x6666;
-		colorFg3.blue = 0x0000;
-	} else if( nHpRate <= WARNING_HP_RATE_GREEN ){
-		colorFg1.red = 0x0000;
-		colorFg1.green = 0xcccc;
-		colorFg1.blue = 0x0000;
-
-		colorFg2.red = 0x0000;
-		colorFg2.green = 0xaaaa;
-		colorFg2.blue = 0x0000;
-
-		colorFg3.red = 0x0000;
-		colorFg3.green = 0x8888;
-		colorFg3.blue = 0x0000;
+	long nRateRed, nRateYellow, nRateGreen;
+	if( flagHp ){
+		nRateRed = WARNING_HP_RATE_RED;
+		nRateYellow = WARNING_HP_RATE_YELLOW;
+		nRateGreen = WARNING_HP_RATE_GREEN;
 	} else {
-		colorFg1.red = 0xffff;
-		colorFg1.green = 0xffff;
-		colorFg1.blue = 0xffff;
-
-		colorFg2.red = 0xffff;
-		colorFg2.green = 0xffff;
-		colorFg2.blue = 0xffff;
-
-		colorFg3.red = 0xffff;
-		colorFg3.green = 0xffff;
-		colorFg3.blue = 0xffff;
+		nRateRed = WARNING_MP_RATE_RED;
+		nRateYellow = WARNING_MP_RATE_YELLOW;
+		nRateGreen = WARNING_MP_RATE_GREEN;
 	}
 
+	if( nHpMpRate <= nRateRed ){
+		colorFg[0].red = 0xeeee;
+		colorFg[0].green = 0x0000;
+		colorFg[0].blue = 0x0000;
+
+		colorFg[1].red = 0xcccc;
+		colorFg[1].green = 0x0000;
+		colorFg[1].blue = 0x0000;
+
+		colorFg[2].red = 0xaaaa;
+		colorFg[2].green = 0x0000;
+		colorFg[2].blue = 0x0000;
+	} else if( nHpMpRate <= nRateYellow ){
+		colorFg[0].red = 0xaaaa;
+		colorFg[0].green = 0xaaaa;
+		colorFg[0].blue = 0x0000;
+
+		colorFg[1].red = 0x8888;
+		colorFg[1].green = 0x8888;
+		colorFg[1].blue = 0x0000;
+
+		colorFg[2].red = 0x6666;
+		colorFg[2].green = 0x6666;
+		colorFg[2].blue = 0x0000;
+	} else if( nHpMpRate <= nRateGreen ){
+		if( flagHp ){
+			colorFg[0].red = 0x0000;
+			colorFg[0].green = 0xcccc;
+			colorFg[0].blue = 0x0000;
+
+			colorFg[1].red = 0x0000;
+			colorFg[1].green = 0xaaaa;
+			colorFg[1].blue = 0x0000;
+
+			colorFg[2].red = 0x0000;
+			colorFg[2].green = 0x8888;
+			colorFg[2].blue = 0x0000;
+		} else {
+			colorFg[0].red = 0x0000;
+			colorFg[0].green = 0xcccc;
+			colorFg[0].blue = 0xcccc;
+
+			colorFg[1].red = 0x0000;
+			colorFg[1].green = 0xaaaa;
+			colorFg[1].blue = 0xaaaa;
+
+			colorFg[2].red = 0x0000;
+			colorFg[2].green = 0x8888;
+			colorFg[2].blue = 0x8888;
+		}
+	} else {
+		colorFg[0].red = 0xffff;
+		colorFg[0].green = 0xffff;
+		colorFg[0].blue = 0xffff;
+
+		colorFg[1].red = 0xffff;
+		colorFg[1].green = 0xffff;
+		colorFg[1].blue = 0xffff;
+
+		colorFg[2].red = 0xffff;
+		colorFg[2].green = 0xffff;
+		colorFg[2].blue = 0xffff;
+	}
+
+	// HP/MP ΥС
+
 	gdk_color_alloc( gdk_colormap_get_system(), &colorBg );
-	gdk_gc_set_background( mBgGcHp[n], &colorBg );
+	gdk_gc_set_background( mBgGcHpMp, &colorBg );
 
 	maxW = 128;
-	w = maxW * nHpRate / _100_PERCENT;
+	w = maxW * nHpMpRate / _100_PERCENT;
 
 	gdk_color_alloc( gdk_colormap_get_system(), &colorBg );
-	gdk_gc_set_foreground( mBgGcHp[n], &colorBg );
-	gdk_draw_rectangle( gdHp, mBgGcHp[n], TRUE,
+	gdk_gc_set_foreground( mBgGcHpMp, &colorBg );
+	gdk_draw_rectangle( gdHpMp, mBgGcHpMp, TRUE,
 			GUI_STAT_HP_MP_X,
 			GUI_STAT_HP_MP_Y,
 			maxW,
 			GUI_STAT_HP_MP_HEIGHT * 3 );
 
-	gdk_color_alloc( gdk_colormap_get_system(), &colorFg1 );
-	gdk_gc_set_foreground( mFgGcHp[n], &colorFg1 );
-	gdk_draw_rectangle( gdHp, mFgGcHp[n], TRUE,
-			GUI_STAT_HP_MP_X,
-			GUI_STAT_HP_MP_Y,
-			w,
-			GUI_STAT_HP_MP_HEIGHT );
+	for( long i = 0; i < 3; i++ ){
+		gdk_color_alloc( gdk_colormap_get_system(),
+				&colorFg[i] );
+		gdk_gc_set_foreground( mFgGcHpMp, &colorFg[i] );
+		gdk_draw_rectangle( gdHpMp, mFgGcHpMp, TRUE,
+				GUI_STAT_HP_MP_X,
+				GUI_STAT_HP_MP_Y + GUI_STAT_HP_MP_HEIGHT * i,
+				w,
+				GUI_STAT_HP_MP_HEIGHT );
+	}
+#endif // D_GTK
 
-	gdk_color_alloc( gdk_colormap_get_system(), &colorFg2 );
-	gdk_gc_set_foreground( mFgGcHp[n], &colorFg2 );
-	gdk_draw_rectangle( gdHp, mFgGcHp[n], TRUE,
-			GUI_STAT_HP_MP_X,
-			GUI_STAT_HP_MP_Y + GUI_STAT_HP_MP_HEIGHT,
-			w,
-			GUI_STAT_HP_MP_HEIGHT );
+#ifdef D_MFC
+	COLORREF colorFg[3];
+	COLORREF colorBg;
+	CClientDC dc( mStatWin );
+	CRect rcWin, rcAct, rcHpMp, rcBase, rcBg, rc;
+	long x = 0;
+	long y = 0;
+	long w = 1;
+	long h = 1;
+	long maxW = 1;
 
-	gdk_color_alloc( gdk_colormap_get_system(), &colorFg3 );
-	gdk_gc_set_foreground( mFgGcHp[n], &colorFg3 );
-	gdk_draw_rectangle( gdHp, mFgGcHp[n], TRUE,
-			GUI_STAT_HP_MP_X,
-			GUI_STAT_HP_MP_Y + GUI_STAT_HP_MP_HEIGHT * 2,
-			w,
-			GUI_STAT_HP_MP_HEIGHT );
+	// 
 
-	// MP
+	rate_t nHpMpRate = 0;
 
-	rate_t nMpRate = 0;
+	if( nMaxHpMp > 0 ){
+		nHpMpRate = nHpMp * 100;
+		nHpMpRate /= nMaxHpMp;
 
-	if( nMaxMp > 0 ){
-		nMpRate = nMp * 100;
-		nMpRate /= nMaxMp;
-
-		colorBg.red = 0x0000;
-		colorBg.green = 0x0000;
-		colorBg.blue = 0x0000;
+		colorBg = RGB( 0x0000, 0x0000, 0x0000 );
 	} else {
-		nMpRate = 0;
+		nHpMpRate = 0;
 
-		colorBg.red = 0x8888;
-		colorBg.green = 0x8888;
-		colorBg.blue = 0x8888;
+		colorBg = RGB( 0x8888, 0x8888, 0x8888 );
 	}
 
-	if( nMpRate <= WARNING_MP_RATE_RED ){
-		colorFg1.red = 0xeeee;
-		colorFg1.green = 0x0000;
-		colorFg1.blue = 0x0000;
-
-		colorFg2.red = 0xcccc;
-		colorFg2.green = 0x0000;
-		colorFg2.blue = 0x0000;
-
-		colorFg3.red = 0xaaaa;
-		colorFg3.green = 0x0000;
-		colorFg3.blue = 0x0000;
-	} else if( nMpRate <= WARNING_MP_RATE_YELLOW ){
-		colorFg1.red = 0xaaaa;
-		colorFg1.green = 0xaaaa;
-		colorFg1.blue = 0x0000;
-
-		colorFg2.red = 0x8888;
-		colorFg2.green = 0x8888;
-		colorFg2.blue = 0x0000;
-
-		colorFg3.red = 0x6666;
-		colorFg3.green = 0x6666;
-		colorFg3.blue = 0x0000;
-	} else if( nMpRate <= WARNING_MP_RATE_GREEN ){
-		colorFg1.red = 0x0000;
-		colorFg1.green = 0xcccc;
-		colorFg1.blue = 0xcccc;
-
-		colorFg2.red = 0x0000;
-		colorFg2.green = 0xaaaa;
-		colorFg2.blue = 0xaaaa;
-
-		colorFg3.red = 0x0000;
-		colorFg3.green = 0x8888;
-		colorFg3.blue = 0x8888;
+	long nRateRed, nRateYellow, nRateGreen;
+	if( flagHp ){
+		nRateRed = WARNING_HP_RATE_RED;
+		nRateYellow = WARNING_HP_RATE_YELLOW;
+		nRateGreen = WARNING_HP_RATE_GREEN;
 	} else {
-		colorFg1.red = 0xffff;
-		colorFg1.green = 0xffff;
-		colorFg1.blue = 0xffff;
-
-		colorFg2.red = 0xffff;
-		colorFg2.green = 0xffff;
-		colorFg2.blue = 0xffff;
-
-		colorFg3.red = 0xffff;
-		colorFg3.green = 0xffff;
-		colorFg3.blue = 0xffff;
+		nRateRed = WARNING_MP_RATE_RED;
+		nRateYellow = WARNING_MP_RATE_YELLOW;
+		nRateGreen = WARNING_MP_RATE_GREEN;
 	}
 
-	gdk_color_alloc( gdk_colormap_get_system(), &colorBg );
-	gdk_gc_set_background( mBgGcMp[n], &colorBg );
+	if( nHpMpRate <= nRateRed ){
+		colorFg[0] = RGB( 0xeeee, 0x0000, 0x0000 );
+		colorFg[1] = RGB( 0xcccc, 0x0000, 0x0000 );
+		colorFg[2] = RGB( 0xaaaa, 0x0000, 0x0000 );
+	} else if( nHpMpRate <= nRateYellow ){
+		colorFg[0] = RGB( 0xaaaa, 0xaaaa, 0x0000 );
+		colorFg[1] = RGB( 0x8888, 0x8888, 0x0000 );
+		colorFg[2] = RGB( 0x6666, 0x6666, 0x0000 );
+	} else if( nHpMpRate <= nRateGreen ){
+		if( flagHp ){
+			colorFg[0] = RGB( 0x0000, 0xcccc, 0x0000 );
+			colorFg[1] = RGB( 0x0000, 0xaaaa, 0x0000 );
+			colorFg[2] = RGB( 0x0000, 0x8888, 0x0000 );
+		} else {
+			colorFg[0] = RGB( 0x0000, 0xcccc, 0xcccc );
+			colorFg[1] = RGB( 0x0000, 0xaaaa, 0xaaaa );
+			colorFg[2] = RGB( 0x0000, 0x8888, 0x8888 );
+		}
+	} else {
+		colorFg[0] = RGB( 0xffff, 0xffff, 0xffff );
+		colorFg[1] = RGB( 0xffff, 0xffff, 0xffff );
+		colorFg[2] = RGB( 0xffff, 0xffff, 0xffff );
+	}
 
-	maxW = 128;
-	w = maxW * nMpRate / _100_PERCENT;
+	// ϰϤ
 
-	gdk_color_alloc( gdk_colormap_get_system(), &colorBg );
-	gdk_gc_set_foreground( mBgGcMp[n], &colorBg );
-	gdk_draw_rectangle( gdMp, mBgGcMp[n], TRUE,
-			GUI_STAT_HP_MP_X,
-			GUI_STAT_HP_MP_Y,
-			maxW,
-			GUI_STAT_HP_MP_HEIGHT * 3 );
+	mStatWin->GetWindowRect( &rcWin );
+	mStatWin->m_LabelAct[n].GetWindowRect( &rcAct );
+	if( flagHp ){
+		mStatWin->m_LabelHp[n].GetWindowRect( &rcHpMp );
+		mStatWin->m_LabelHp[n].GetWindowRect( &rcBase );
+	} else {
+		mStatWin->m_LabelMp[n].GetWindowRect( &rcHpMp );
+		mStatWin->m_LabelMp[n].GetWindowRect( &rcBase );
+	}
 
-	gdk_color_alloc( gdk_colormap_get_system(), &colorFg1 );
-	gdk_gc_set_foreground( mFgGcMp[n], &colorFg1 );
-	gdk_draw_rectangle( gdMp, mFgGcMp[n], TRUE,
-			GUI_STAT_HP_MP_X,
-			GUI_STAT_HP_MP_Y,
-			w,
-			GUI_STAT_HP_MP_HEIGHT );
+	// طʤ򥯥ꥢ
 
-	gdk_color_alloc( gdk_colormap_get_system(), &colorFg2 );
-	gdk_gc_set_foreground( mFgGcMp[n], &colorFg2 );
-	gdk_draw_rectangle( gdMp, mFgGcMp[n], TRUE,
-			GUI_STAT_HP_MP_X,
-			GUI_STAT_HP_MP_Y + GUI_STAT_HP_MP_HEIGHT,
-			w,
-			GUI_STAT_HP_MP_HEIGHT );
+	x = rcHpMp.right;
+	y = rcHpMp.top;
+	w = rcAct.Width() - rcHpMp.Width();
+	h = rcHpMp.Height();
+	rcBg.SetRect( x, y, x + w, y + h );
 
-	gdk_color_alloc( gdk_colormap_get_system(), &colorFg3 );
-	gdk_gc_set_foreground( mFgGcMp[n], &colorFg3 );
-	gdk_draw_rectangle( gdMp, mFgGcMp[n], TRUE,
-			GUI_STAT_HP_MP_X,
-			GUI_STAT_HP_MP_Y + GUI_STAT_HP_MP_HEIGHT * 2,
-			w,
-			GUI_STAT_HP_MP_HEIGHT );
+	::AdjustWindowRectEx( &rcBg,
+			mStatWin->GetStyle(), FALSE,
+			mStatWin->GetExStyle() );
+	rcBg.left -= rcWin.left;
+	rcBg.top -= rcWin.top;
+	rcBg.right = rcBg.left + w;
+	rcBg.bottom = rcBg.top + h;
+	dc.FillSolidRect( rcBg,
+			::GetSysColor( COLOR_BTNFACE ) );
+
+	// HP/MP ΥС
+
+	w = rcBase.Width();
+	h = rcBase.Height();
+	::AdjustWindowRectEx( &rcBase,
+			mStatWin->GetStyle(), FALSE,
+			mStatWin->GetExStyle() );
+	rcBase.left -= rcWin.left;
+	rcBase.top -= rcWin.top;
+	rcBase.right = rcBase.left + w;
+	rcBase.bottom = rcBase.top + h;
+
+	x = rcBase.right + GUI_STAT_HP_MP_X;
+	y = rcBase.top + GUI_STAT_HP_MP_Y;
+
+	maxW = rcAct.Width() - rcHpMp.Width();
+	maxW -= GUI_STAT_HP_MP_X * 2;
+	w = maxW * nHpMpRate / _100_PERCENT;
+
+	h = GUI_STAT_HP_MP_HEIGHT * 3;
+	rc.SetRect( x, y, x + maxW, y + h );
+	dc.FillSolidRect( rc, colorBg );
+
+	h = GUI_STAT_HP_MP_HEIGHT;
+	for( long i = 0; i < 3; i++ ){
+		long yy = y + GUI_STAT_HP_MP_HEIGHT * i;
+		rc.SetRect( x, yy, x + w, yy + h );
+		dc.FillSolidRect( rc, colorFg[i] );
+	}
+#endif // D_MFC
+}
+
+////////////////////////////////////////////////////////////////
+// ơʸ
+// mbr_t *mbr : С
+// return : ơʸ
+////////////////////////////////////////////////////////////////
+
+WSCstring GuiStat::getStatStr( mbr_t *mbr )
+{
+	WSCstring str;
+	WSCstring strSplit = "  ";
+
+	if( chk_flg( mbr->stat, FLG_STAT_DEAD ) ){
+		str += MSG_STAT_DEAD;
+		str += strSplit;
+	}
+
+	if( chk_flg( mbr->stat, FLG_STAT_STONE ) ){
+		str += MSG_STAT_STONE;
+		str += strSplit;
+	}
+
+	if( chk_flg( mbr->stat, FLG_STAT_FAINT ) ){
+		str += MSG_STAT_FAINT;
+		str += strSplit;
+	}
+
+	if( chk_flg( mbr->stat, FLG_STAT_PARALYZE ) ){
+		str += MSG_STAT_PARALYZE;
+		str += strSplit;
+	}
+
+	if( chk_flg( mbr->stat, FLG_STAT_POISON ) ){
+		str += MSG_STAT_POISON;
+		str += strSplit;
+	}
+
+	if( chk_flg( mbr->stat, FLG_STAT_CONFUSION ) ){
+		str += MSG_STAT_CONFUSION;
+		str += strSplit;
+	}
+
+	if( chk_flg( mbr->stat, FLG_STAT_BLIND ) ){
+		str += MSG_STAT_BLIND;
+		str += strSplit;
+	}
+
+	if( chk_flg( mbr->stat, FLG_STAT_SLEEP ) ){
+		str += MSG_STAT_SLEEP;
+		str += strSplit;
+	}
+
+	if( chk_flg( mbr->stat, FLG_STAT_SILENCE ) ){
+		str += MSG_STAT_SILENCE;
+		str += strSplit;
+	}
+
+	if( chk_flg( mbr->stat, FLG_STAT_CAUGHT ) ){
+		str += MSG_STAT_CAUGHT;
+		str += strSplit;
+	}
+
+	if( chk_flg( mbr->stat, FLG_STAT_FEAR ) ){
+		str += MSG_STAT_FEAR;
+		str += strSplit;
+	}
+
+	if( chk_flg( mbr->stat, FLG_STAT_HALLUCINATION ) ){
+		str += MSG_STAT_HALLUCINATION;
+		str += strSplit;
+	}
+
+	if( chk_flg( mbr->stat, FLG_STAT_CHARM ) ){
+		str += MSG_STAT_CHARM;
+		str += strSplit;
+	}
+
+	if( chk_flg( mbr->stat, FLG_STAT_DRUNK ) ){
+		str += MSG_STAT_DRUNK;
+		str += strSplit;
+	}
+
+	if( chk_flg( mbr->stat, FLG_STAT_FLY ) ){
+		str += MSG_STAT_FLY;
+		str += strSplit;
+	}
+
+	if( chk_flg( mbr->stat, FLG_STAT_VANISH ) ){
+		str += MSG_STAT_VANISH;
+		str += strSplit;
+	}
+
+	if( chk_flg( mbr->stat, FLG_STAT_IRON_BODY ) ){
+		str += MSG_STAT_IRON_BODY;
+		str += strSplit;
+	}
+
+	if( chk_flg( mbr->stat, FLG_STAT_PASSWALL ) ){
+		str += MSG_STAT_PASSWALL;
+		str += strSplit;
+	}
+
+	if( chk_flg( mbr->stat, FLG_STAT_SENSE_INVISIBLE ) ){
+		str += MSG_STAT_SENSE_INVISIBLE;
+		str += strSplit;
+	}
+
+	if( chk_flg( mbr->stat, FLG_STAT_STARVATION ) ){
+		str += MSG_STAT_STARVATION;
+		str += strSplit;
+	}
+
+	if( chk_flg( mbr->stat, FLG_STAT_HUNGRY ) ){
+		str += MSG_STAT_HUNGRY;
+		str += strSplit;
+	}
+
+	return str;
 }
 
 ////////////////////////////////////////////////////////////////
@@ -662,6 +840,7 @@ void GuiStat::draw( long n )
 // gpointer data : ϿϤ줿
 ////////////////////////////////////////////////////////////////
 
+#ifdef D_GTK
 void handle_stat_win_destroy(
 	GtkWidget *widget, gpointer data
 )
@@ -671,6 +850,7 @@ void handle_stat_win_destroy(
 
 	((GuiStat *)data)->destroy();
 }
+#endif // D_GTK
 
 ////////////////////////////////////////////////////////////////
 // ơɥ襤٥Ȥν
@@ -679,14 +859,16 @@ void handle_stat_win_destroy(
 // return : ?
 ////////////////////////////////////////////////////////////////
 
+#ifdef D_GTK
 gint handle_stat_win_expose(
 	GtkWidget *widget, GdkEventExpose *event
 )
 {
 	gGuiStat.redraw();
 
-	return true;
+	return TRUE;
 }
+#endif // D_GTK
 
 ////////////////////////////////////////////////////////////////
 // ơɥΥѹ٥Ȥν
@@ -695,6 +877,7 @@ gint handle_stat_win_expose(
 // return : ?
 ////////////////////////////////////////////////////////////////
 
+#ifdef D_GTK
 gint handle_stat_win_configure(
 	GtkWidget *widget, GdkEventConfigure *event
 )
@@ -703,6 +886,7 @@ gint handle_stat_win_configure(
 
 	return TRUE;
 }
+#endif // D_GTK
 
 ////////////////////////////////////////////////////////////////
 // 饯̾ܥκå٥Ƚ
@@ -710,6 +894,7 @@ gint handle_stat_win_configure(
 // gpointer data : ϿϤ줿ǡ
 ////////////////////////////////////////////////////////////////
 
+#ifdef D_GTK
 void handle_stat_name_clicked(
 	GtkWidget *widget, gpointer data
 )
@@ -720,13 +905,23 @@ void handle_stat_name_clicked(
 	sCmdMbr[0] = 'A' + n;
 	sCmdMbr[1] = '\0';
 
-	WSCstring sCmd = "0000000000000000@";
+	WSCstring sCmd = "";
+
+	// ˥塼򳫤ƤĤ
+	sCmd = "00000000000000000000000000000000";
+
+	// Сΰ֤˥ư
+	sCmd += ":/misc/cursor/cursor/move member\n";
 	sCmd += sCmdMbr;
+
+	// ˥塼򳫤
 	sCmd += "^M";
 
+	// ޥɤ
 	set_key_buf_str( sCmd );
 	set_flg_break_key( TRUE );
 }
+#endif // D_GTK
 
 ////////////////////////////////////////////////////////////////
 // 饯Υơܥκå٥Ƚ
@@ -734,6 +929,7 @@ void handle_stat_name_clicked(
 // gpointer data : ϿϤ줿ǡ
 ////////////////////////////////////////////////////////////////
 
+#ifdef D_GTK
 void handle_stat_stat_clicked(
 	GtkWidget *widget, gpointer data
 )
@@ -744,10 +940,21 @@ void handle_stat_stat_clicked(
 	sCmdMbr[0] = 'A' + n;
 	sCmdMbr[1] = '\0';
 
-	WSCstring sCmd = "0000000000000000@";
-	sCmd += sCmdMbr;
-	sCmd += "d";
+	WSCstring sCmd = "";
 
+	// ˥塼򳫤ƤĤ
+	sCmd = "00000000000000000000000000000000";
+
+	// Сΰ֤˥ư
+	sCmd += ":/misc/cursor/cursor/move member\n";
+	sCmd += sCmdMbr;
+
+	// 饯Ȥɽ
+//	sCmd += ":/misc/char data\n";
+	sCmd += "C";
+
+	// ޥɤ
 	set_key_buf_str( sCmd );
 	set_flg_break_key( TRUE );
 }
+#endif // D_GTK
