@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiStat.h,v 1.2 2007/02/25 02:13:11 bowkenken Exp $
+* $Id: GuiStat.h,v 1.6 2007/12/08 11:55:06 bowkenken Exp $
 ***************************************************************/
 
 #ifndef GUI_STAT_H
@@ -35,9 +35,15 @@
 // ơɥ
 ////////////////////////////////////////////////////////////////
 
-#include <gtk/gtk.h>
+#ifdef D_GTK
+# include <gtk/gtk.h>
+# include "GtkWSCstring.h"
+# include "party.h"
+#endif // D_GTK
 
-#include <party.h>
+#ifdef D_MFC
+# include "MfcWSCstring.h"
+#endif // D_MFC
 
 ////////////////////////////////////////////////////////////////
 
@@ -46,6 +52,7 @@ class GuiStat {
 // ץ饤١ȡСѿ
 private:
 
+#ifdef D_GTK
 	GtkWidget *mStatWin;
 	GtkWidget *vBox;
 	GtkWidget *btnName[MBR_MAX_N];
@@ -60,8 +67,16 @@ private:
 	GdkGC *mFgGcMp[MBR_MAX_N];
 	GdkGC *mBgGcHp[MBR_MAX_N];
 	GdkGC *mBgGcMp[MBR_MAX_N];
+	GdkGC *mFgGcHpMp;
+	GdkGC *mBgGcHpMp;
+
 	GtkWidget *mDrawingAreaHp[MBR_MAX_N];
 	GtkWidget *mDrawingAreaMp[MBR_MAX_N];
+#endif // D_GTK
+
+#ifdef D_MFC
+	CStatWnd *mStatWin;
+#endif // D_MFC
 
 // ѥ֥åСѿ
 public:
@@ -72,6 +87,8 @@ public:
 	GuiStat()
 	{
 		mStatWin = NULL;
+
+#ifdef D_GTK
 		vBox = NULL;
 		for( long i = 0; i < MBR_MAX_N; i++ ){
 			mFgGcHp[i] = NULL;
@@ -79,6 +96,9 @@ public:
 			mFgGcMp[i] = NULL;
 			mBgGcMp[i] = NULL;
 		}
+		mFgGcHpMp = NULL;
+		mBgGcHpMp = NULL;
+#endif // D_GTK
 	}
 	~GuiStat()
 	{
@@ -87,14 +107,19 @@ public:
 	void init();
 	void destroy();
 
-	void redraw();
+	void redraw( bool flagAdj = true );
 	void draw( long n );
+	WSCstring getStatStr( mbr_t *mbr );
 
 // ץ饤١ȡСؿ
 private:
 
 	void newWin();
+
+	void drawHpMp( long n, bool flagHp );
+#ifdef D_GTK
 	void newWinMbr( mbr_t *mbr, GtkWidget *vBox );
+#endif // D_GTK
 };
 
 #endif /* GUI_STAT_H */
