@@ -25,13 +25,16 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: Key.cpp,v 1.6 2007/02/20 01:55:22 bowkenken Exp $
+* $Id: Key.cpp,v 1.12 2007/12/25 02:15:53 bowkenken Exp $
 ***************************************************************/
 
 #include "gmain.h"
-#include "curs.h"
-#include "draw.h"
-#include "draw-prot.h"
+#include "dun.h"
+#include "replay.h"
+#include "menu.h"
+#include "dun-prot.h"
+#include "replay-prot.h"
+#include "mmenu-prot.h"
 
 #include "Key.h"
 #include "GlobalVar.h"
@@ -232,6 +235,14 @@ static WSCbool handler( long keyCode, WSCbool flagOn )
 
 #endif // D_WS
 
+////////////////////////////////////////////////////////////////
+// GTK+ Υϥɥ
+// GtkWidget *widget : ?
+// GdkEventKey *event : ٥
+// gpointer user_data : ϥɥϿǡ
+// return : ?
+////////////////////////////////////////////////////////////////
+
 #ifdef D_GTK
 
 gboolean handleKeyPress(
@@ -447,6 +458,175 @@ gboolean handleKeyPress(
 
 #endif // D_GTK
 
+////////////////////////////////////////////////////////////////
+// MFC Υϥɥ
+// UINT nChar : ۥ
+// UINT nRepCnt : ԡȲ
+// UINT nFlags : ֥ե饰
+////////////////////////////////////////////////////////////////
+
+#ifdef D_MFC
+
+void Key::handleKeyDown(
+	UINT nChar, UINT nRepCnt, UINT nFlags
+)
+{
+	long key = '\0';
+
+	switch( nChar ){
+//	case VK_BACK:
+//		key = 'H' - '@';
+//		break;
+//	case VK_TAB:
+//		key = '\t';
+//		break;
+
+//	case VK_CLEAR:
+//		break;
+//	case VK_RETURN:
+//		key = 'M' - '@';
+//		break;
+
+//	case VK_SHIFT
+//	case VK_CONTROL
+//	case VK_MENU
+//	case VK_PAUSE
+//	case VK_CAPITAL
+//		break;
+
+//	case VK_KANA:
+//	case VK_HANGEUL:
+//	case VK_HANGUL:
+//	case VK_JUNJA:
+//	case VK_FINAL:
+//	case VK_HANJA:
+//	case VK_KANJI:
+//		break;
+
+	case VK_ESCAPE:
+		key = 'H' - '@';
+		break;
+
+//	case VK_CONVERT:
+//	case VK_NONCONVERT:
+//	case VK_ACCEPT:
+//	case VK_MODECHANGE:
+//		break;
+
+//	case VK_SPACE:
+//		key = ' ';
+//		break;
+	case VK_PRIOR:
+		key = '-';
+		break;
+	case VK_NEXT:
+		key = '+';
+		break;
+	case VK_END:
+		key = '.';
+		break;
+	case VK_HOME:
+		key = '*';
+		break;
+	case VK_LEFT:
+		key = '4';
+		break;
+	case VK_UP:
+		key = '8';
+		break;
+	case VK_RIGHT:
+		key = '6';
+		break;
+	case VK_DOWN:
+		key = '2';
+		break;
+//	case VK_SELECT:
+//	case VK_PRINT:
+//	case VK_EXECUTE:
+//	case VK_SNAPSHOT:
+//		break;
+	case VK_INSERT:
+		key = '/';
+		break;
+	case VK_DELETE:
+		key = '0';
+		break;
+//	case VK_HELP:
+//		break;
+
+//	case VK_LWIN:
+//	case VK_RWIN:
+//	case VK_APPS:
+//		break;
+
+//	case VK_SLEEP:
+//		break;
+
+//	case VK_NUMPAD0:
+//	case VK_NUMPAD1:
+//	case VK_NUMPAD2:
+//	case VK_NUMPAD3:
+//	case VK_NUMPAD4:
+//	case VK_NUMPAD5:
+//	case VK_NUMPAD6:
+//	case VK_NUMPAD7:
+//	case VK_NUMPAD8:
+//	case VK_NUMPAD9:
+//		key = '0' + nChar - VK_NUMPAD0;
+//		break;
+//	case VK_MULTIPLY:
+//		key = '*';
+//		break;
+//	case VK_ADD:
+//		key = '+';
+//		break;
+//	case VK_SEPARATOR:
+//		break;
+//	case VK_SUBTRACT:
+//		key = '-';
+//		break;
+//	case VK_DECIMAL:
+//		break;
+//	case VK_DIVIDE:
+//		key = '/';
+//		break;
+	case VK_F1:
+	case VK_F2:
+	case VK_F3:
+	case VK_F4:
+	case VK_F5:
+	case VK_F6:
+	case VK_F7:
+	case VK_F8:
+	case VK_F9:
+	case VK_F10:
+	case VK_F11:
+	case VK_F12:
+	case VK_F13:
+	case VK_F14:
+	case VK_F15:
+	case VK_F16:
+	case VK_F17:
+	case VK_F18:
+	case VK_F19:
+	case VK_F20:
+	case VK_F21:
+	case VK_F22:
+	case VK_F23:
+	case VK_F24:
+		char buf[15 + 1];
+		sprintf( buf, "&%2ld", key - VK_F1 + 1 );
+		setString( buf, true );
+
+		return;
+	}
+
+	if( key != '\0' )
+		setChar( key, true );
+}
+
+#endif // D_MFC
+
 ////////////////////////////////////////////////////////////////
 // Х롦եåΥϥɥϿ
 ////////////////////////////////////////////////////////////////
@@ -498,7 +678,7 @@ long Key::getChar()
 void Key::setChar( long c, bool flagCheckClear )
 {
 	char s[4 + 1] = "";
-	s[0] = c;
+	s[0] = (char)c;
 	s[1] = '\0';
 
 	setString( s, flagCheckClear );
@@ -519,7 +699,7 @@ void Key::setString( WSCstring s, bool flagCheckClear )
 		if( get_key_buf_char() == '\0' )
 			gPreChar = -1;
 
-		for( long i = 0; i < s.getChars(); i++ ){
+		for( int i = 0; i < s.getChars(); i++ ){
 			if( s[i] == gPreChar ){
 				s.deleteChar( i );
 				i--;
@@ -583,3 +763,43 @@ void Key::setStringKeyTab( WSCstring s )
 
 	set_flg_break_key( TRUE );
 }
+
+////////////////////////////////////////////////////////////////
+// Хåե˥ޤäƤ뤫Ĵ٤
+// return : ޤäƤ뤫?
+////////////////////////////////////////////////////////////////
+
+bool Key::chkBuf()
+{
+	return( buf.getChars() > 0 );
+}
+
+////////////////////////////////////////////////////////////////
+// кɸꤷƥư
+// long mapX : X ɸ
+// long mapY : Y ɸ
+// return : ꤷɸޤǰư줿
+////////////////////////////////////////////////////////////////
+
+bool Key::moveCrsrAbs( long mapX, long mapY )
+{
+	if( !clip_pos( mapX, mapY ) )
+		return false;
+
+	if( !g_flg_gui )
+		return true;
+	if( get_flg_play_replay() )
+		return true;
+
+	pos_t *crsr = get_crsr();
+	if( crsr == NULL )
+		return false;
+	if( (crsr->x == mapX) && (crsr->y == mapY) )
+		return true;
+
+	crsr->x = mapX;
+	crsr->y = mapY;
+	setString( "|", true );
+
+	return true;
+}
