@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: Key.h,v 1.4 2007/01/11 17:32:28 bowkenken Exp $
+* $Id: Key.h,v 1.9 2007/12/25 02:15:53 bowkenken Exp $
 ***************************************************************/
 
 #ifndef KEY_H
@@ -44,6 +44,9 @@
 # include "GtkWSCstring.h"
 #endif // D_GTK
 
+#ifdef D_MFC
+# include "MfcWSCstring.h"
+#endif // D_MFC
 
 ////////////////////////////////////////////////////////////////
 // Ϥδ
@@ -67,9 +70,20 @@ public:
 	void init();
 
 	long getChar();
+
 	void setChar( long c, bool flagCheckClear = false );
 	void setString( WSCstring s, bool flagCheckClear = false );
 	void setStringKeyTab( WSCstring s );
+
+	bool chkBuf();
+
+	bool moveCrsrAbs( long mapX, long mapY );
+
+#ifdef D_MFC
+	void handleKeyDown(
+		UINT nChar, UINT nRepCnt, UINT nFlags
+	);
+#endif // D_MFC
 };
 
 #endif /* KEY_H */
