@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: MouseMap.h,v 1.2 2007/01/11 17:32:28 bowkenken Exp $
+* $Id: MouseMap.h,v 1.3 2007/10/26 05:31:53 bowkenken Exp $
 ***************************************************************/
 
 #ifndef MOUSE_MAP_H
@@ -35,42 +35,47 @@
 
 void initMouseMotionFunc();
 void funcMotionPoint(
-	MouseMotion::MouseButtonN n,
+	long m,
 	long nBgnX, long nBgnY,
 	long nCurX, long nCurY
 );
 void funcMotionDragL(
-	MouseMotion::MouseButtonN n,
+	long m,
 	long nBgnX, long nBgnY,
 	long nCurX, long nCurY
 );
 void funcMotionLeftR(
-	MouseMotion::MouseButtonN n,
+	long m,
 	long nBgnX, long nBgnY,
 	long nCurX, long nCurY
 );
 void funcMotionRightR(
-	MouseMotion::MouseButtonN n,
+	long m,
 	long nBgnX, long nBgnY,
 	long nCurX, long nCurY
 );
 void funcMotionUpR(
-	MouseMotion::MouseButtonN n,
+	long m,
 	long nBgnX, long nBgnY,
 	long nCurX, long nCurY
 );
 void funcMotionDownR(
-	MouseMotion::MouseButtonN n,
+	long m,
 	long nBgnX, long nBgnY,
 	long nCurX, long nCurY
 );
 void funcMotionClick(
-	MouseMotion::MouseButtonN n,
+	long m,
 	long nBgnX, long nBgnY,
 	long nCurX, long nCurY
 );
 void funcMotionClickLR(
-	MouseMotion::MouseButtonN n,
+	long m,
+	long nBgnX, long nBgnY,
+	long nCurX, long nCurY
+);
+void funcMotionScroll(
+	long m,
 	long nBgnX, long nBgnY,
 	long nCurX, long nCurY
 );
