@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: MouseMotion.h,v 1.3 2007/01/11 17:32:28 bowkenken Exp $
+* $Id: MouseMotion.h,v 1.4 2007/10/26 05:31:53 bowkenken Exp $
 ***************************************************************/
 
 #ifndef MOUSE_MOTION_H
@@ -91,9 +91,25 @@ public:
 		nMotionKindMinN = nMotionDrag,
 	};
 
+	// μ
+	enum ScrollKind {
+		// 
+		nScrollLeft,
+		// 
+		nScrollRight,
+		// 她
+		nScrollUp,
+		// 
+		nScrollDown,
+
+		nScrollKindMaxN,
+
+		nScrollKindMinN = nScrollLeft,
+	};
+
 	// Хåؿη
 	typedef void (*tFunc)(
-			MouseButtonN n,
+			long n,
 			long nBgnX, long nBgnY,
 			long nCurX, long nCurY );
 
@@ -117,6 +133,8 @@ private:
 	tFunc pFuncClickLR;
 	// +åΥХåؿ
 	tFunc pFuncClickRL;
+	// ΥХåؿ
+	tFunc pFuncScroll[nScrollKindMaxN];
 
 public:
 	MouseMotion();
@@ -129,6 +147,7 @@ public:
 	void setFuncClickLR(
 			MouseButtonN btnPress,
 			tFunc func );
+	void setFuncScroll( ScrollKind dir, tFunc func );
 
 	void setRegionSize(
 			long dxr, long dyr,
@@ -148,6 +167,7 @@ public:
 			MouseButtonN pressN,
 			MouseButtonN clickN,
 			long x, long y );
+	bool mouseScroll( ScrollKind dir );
 };
 
 #endif /* MOUSE_MOTION_H */
