@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: Pcg.h,v 1.5 2007/01/30 02:57:05 bowkenken Exp $
+* $Id: Pcg.h,v 1.11 2007/11/12 18:24:01 bowkenken Exp $
 ***************************************************************/
 
 #ifndef PCG_H
@@ -47,6 +47,12 @@
 # include "GtkWSCstring.h"
 #endif // D_GTK
 
+#ifdef D_MFC
+# include "MfcWSDimage.h"
+# include "MfcWSDmwindowDev.h"
+# include "MfcWSCstring.h"
+#endif // D_MFC
+
 class Pcg {
 private:
 	// ǽԤκԤ֤Υǥեȡʥߥá
@@ -54,7 +60,6 @@ private:
 
 	// եåѥ
 	WSDimage *pImage;
-//@@@	WSDmwindowDev *pMDev;
 
 public:
 	// ǽԤκԤ֡ʥߥá
@@ -66,22 +71,14 @@ public:
 		nWaitReadyMSec = nWaitReadyMSecDflt;
 
 		pImage = NULL;
-//@@@		pMDev = NULL;
 	}
 	~Pcg()
 	{
 		if( pImage != NULL ){
 			pImage->destroyImage();
+			delete pImage;
 			pImage = NULL;
 		}
-
-#if 0
-//@@@
-		if( pMDev != NULL ){
-			delete pMDev;
-			pMDev = NULL;
-		}
-#endif
 	}
 
 	void init( WSCstring path );
@@ -92,6 +89,10 @@ public:
 	long getHeight();
 
 	bool waitReady( WSDmwindowDev *mDev );
+
+	bool beginAlpha();
+	bool endAlpha();
+
 	bool draw( WSDmwindowDev *mDev,
 			long x, long y, long dx, long dy );
 	bool drawFix( WSDmwindowDev *mDev,
