@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: PcgDun.h,v 1.13 2007/02/19 08:42:00 bowkenken Exp $
+* $Id: PcgDun.h,v 1.33 2007/12/24 16:37:22 bowkenken Exp $
 ***************************************************************/
 
 #ifndef PCG_DUN_H
@@ -42,6 +42,7 @@
 #include "party.h"
 #include "mnstr.h"
 
+#include "GraphConf.h"
 #include "Pcg.h"
 
 #ifdef D_WS
@@ -52,10 +53,31 @@
 # include "GtkWSCstring.h"
 #endif //D_GTK
 
+#ifdef D_MFC
+# include "MfcWSCstring.h"
+# include "xlnl-dows/Dir3d.h"
+#endif //D_MFC
+
 ////////////////////////////////////////////////////////////////
 
 // ѥΥե̾γĥ
-#define	STR_GRAPH_FILE_EXT	"png jpg gif bmp"
+#if	defined( D_GTK )
+# define	STR_GRAPH_FILE_EXT	\
+		"png xpm jpg jpeg tif pnm bmp gif " \
+		"PNG XPM JPG JPEG TIF PNM BMP GIF"
+#elif	defined( D_WS )
+# define	STR_GRAPH_FILE_EXT	\
+		"png jpg jpeg bmp " \
+		"PNG JPG JPEG BMP"
+#elif	defined( D_MFC )
+# define	STR_GRAPH_FILE_EXT	\
+		"png jpg jpeg bmp " \
+		"PNG JPG JPEG BMP"
+#else
+# define	STR_GRAPH_FILE_EXT	\
+		"png jpg jpeg bmp " \
+		"PNG JPG JPEG BMP"
+#endif
 
 // ѥΥХꥨμ
 typedef char PcgMap;
@@ -85,6 +107,8 @@ public:
 	rate_t nTileSizeRate;
 
 private:
+	//// 롦⡼ ////
+
 	// ѥδॵ
 	long nTileSizeX, nTileSizeY;
 
@@ -97,6 +121,8 @@ private:
 	static const long PCG_FLOOR_MAX_N = 8;
 	// ɤΥѥΥХꥨκ
 	static const long PCG_WALL_MAX_N = 8;
+	// ĤΥѥΥХꥨκ
+	static const long PCG_SIGNBOARD_MAX_N = 4;
 	// ʤΥѥΥХꥨκ
 	static const long PCG_STAIRS_MAX_N = 4;
 	// ɥΥѥΥХꥨκ
@@ -105,7 +131,7 @@ private:
 	// ΥѥΥХꥨκ
 	static const long PCG_CRSR_MAX_N = 1;
 	// 󥫡ΥѥΥХꥨκ
-	static const long PCG_SQUARE_MAX_N = 8;
+	static const long PCG_SQUARE_MAX_N = 4;
 
 	// ƥΥѥΥХꥨκ
 	static const long PCG_ITEM_MAX_N = 48;
@@ -118,6 +144,9 @@ private:
 	// 󥹥ΥѥΥХꥨκ
 	static const long PCG_MNSTR_MAX_N = MNSTR_KIND_MAX_N;
 
+	// ȥβ
+	Pcg pcgTitle;
+
 	// Υѥ
 	Pcg aNullTown[PCG_NULL_MAX_N][PCG_LS_MAX_N];
 	Pcg aNullDun[PCG_NULL_MAX_N][PCG_LS_MAX_N];
@@ -127,6 +156,8 @@ private:
 	// ɤΥѥ
 	Pcg aWallTown[PCG_WALL_MAX_N][PCG_LS_MAX_N];
 	Pcg aWallDun[PCG_WALL_MAX_N][PCG_LS_MAX_N];
+	// ĤΥѥ
+	Pcg aSignboard[PCG_SIGNBOARD_MAX_N][PCG_LS_MAX_N];
 	// ʤΥѥ
 	Pcg aStairsUpTown[PCG_STAIRS_MAX_N][PCG_LS_MAX_N];
 	Pcg aStairsUpDun[PCG_STAIRS_MAX_N][PCG_LS_MAX_N];
@@ -142,7 +173,7 @@ private:
 	Pcg aCrsr[PCG_CRSR_MAX_N][PCG_LS_MAX_N];
 	Pcg aCrsrSub[PCG_CRSR_MAX_N][PCG_LS_MAX_N];
 	// 󥫡ΥѥΥХꥨκ
-	Pcg aSquare[PCG_SQUARE_MAX_N];
+	Pcg aSquare[PCG_SQUARE_MAX_N][PCG_LS_MAX_N];
 
 	// ƥΥѥ
 	Pcg aItem[PCG_ITEM_MAX_N][PCG_LS_MAX_N];
@@ -154,6 +185,11 @@ private:
 	// 󥹥Υѥ
 	Pcg aMnstr[MNSTR_KIND_MAX_N][PCG_LS_MAX_N];
 
+	// Ф줿ȥΥեֹ
+	long nTitleRandmSelN;
+	// ȥΥե
+	long nTitleN;
+
 	// ѥΥե
 	long nNullTownN[PCG_NULL_MAX_N];
 	long nNullDunN[PCG_NULL_MAX_N];
@@ -161,6 +197,7 @@ private:
 	long nFloorDunN[PCG_FLOOR_MAX_N];
 	long nWallTownN[PCG_WALL_MAX_N];
 	long nWallDunN[PCG_WALL_MAX_N];
+	long nSignboardN[PCG_SIGNBOARD_MAX_N];
 	long nStairsUpTownN[PCG_STAIRS_MAX_N];
 	long nStairsUpDunN[PCG_STAIRS_MAX_N];
 	long nStairsDownTownN[PCG_STAIRS_MAX_N];
@@ -171,7 +208,7 @@ private:
 	long nDoorOpenDunN[PCG_DOOR_MAX_N];
 	long nCrsrN[PCG_CRSR_MAX_N];
 	long nCrsrSubN[PCG_CRSR_MAX_N];
-	long nSquareN;
+	long nSquareN[PCG_SQUARE_MAX_N];
 	long nItemN[PCG_ITEM_MAX_N];
 	long nTrapN[PCG_TRAP_MAX_N];
 	long nMnstrN[MNSTR_KIND_MAX_N];
@@ -180,6 +217,7 @@ private:
 	PcgMap aaMapNull[MAP_MAX_Y][MAP_MAX_X];
 	PcgMap aaMapFloor[MAP_MAX_Y][MAP_MAX_X];
 	PcgMap aaMapWall[MAP_MAX_Y][MAP_MAX_X];
+	PcgMap aaMapSignboard[MAP_MAX_Y][MAP_MAX_X];
 	PcgMap aaMapStairsUp[MAP_MAX_Y][MAP_MAX_X];
 	PcgMap aaMapStairsDown[MAP_MAX_Y][MAP_MAX_X];
 	PcgMap aaMapDoorClose[MAP_MAX_Y][MAP_MAX_X];
@@ -195,61 +233,113 @@ private:
 	// ֥롦Хåե
 	WSDmwindowDev *pWBuf;
 
+	//// ĤΥե ////
+
+	// եȤΥݥ
+	long nSignboardPoint;
+
+	// եȤδॵ
+	long nSignboardSizeX, nSignboardSizeY;
+
+	// ʸֳ
+	long nSignboardIntervalWidth, nSignboardIntervalHeight;
+
+#ifdef D_GTK
+	// եȤΥ
+	GtkStyle *pSignboardStyle;
+
+	// եȤΥ
+	gint nSignboardLeftBearing, nSignboardRightBearing;
+	gint nSignboardWidth, nSignboardAscent, nSignboardDescent;
+#endif // D_GTK
+
+#ifdef D_MFC
+	// եȤΥ
+	void *pSignboardStyle;
+	LOGFONT mSignboardFontDesc;
+	CFont *pSignboardFont;
+
+	CDir3dText mD3Signboard;
+#endif // D_MFC
+
+	//// ƥȡ⡼ ////
+
+	// եȤΥǥեȤΥݥ
+	long nTextModeDefaultPoint;
+
+	// եȤδॵ
+	long nTextSizeX, nTextSizeY;
+
+	// ʸֳ
+	long nIntervalWidth, nIntervalHeight;
+
+#ifdef D_GTK
+	// եȤΥ
+	GtkStyle *pStyle;
+
+	// եȤΥ
+	gint nLeftBearing, nRightBearing;
+	gint nWidth, nAscent, nDescent;
+#endif // D_GTK
+
+#ifdef D_MFC
+	// եȤΥ
+	void *pStyle;
+	CClientDC *pDc;
+#endif // D_MFC
+
+	// ˥ޥåפ褹뤫?
+	bool bFlgEnaDrawTurn;
+
 public:
-	PcgDun()
-	{
-		resetUpdateFlg();
+	PcgDun();
+	~PcgDun();
 
-		pWBuf = NULL;
-
-		nTileSizeX = 32;
-		nTileSizeY = 32;
-		nTileSizeRate = _100_PERCENT;
-
-		nPtnDirMbr = N_PTN_DIR_CHR_1;
-		nPtnDirMnstr = N_PTN_DIR_CHR_1;
-	}
-	~PcgDun()
-	{
-	}
-
-	void init();
+	void initTitle();
+	void init( GraphConf *cnf );
+	void initGraphConf( GraphConf *cnf );
 	void reset();
 
+	void resetSignboardFont();
+	bool setSignboardFont( long pnt, WSCstring *pFontName );
+
+	long getTileSizeX( bool flgText = false );
+	long getTileSizeY( bool flgText = false );
+	long getTextModePoint();
+
 	WSDmwindowDev *getWBuf();
-
-	long getTileSizeX()
-	{
-		long n = nTileSizeX * nTileSizeRate / _100_PERCENT;
-		if( n < 1 )
-			n = 1;
-
-		return n;
-	}
-	long getTileSizeY()
-	{
-		long n = nTileSizeY * nTileSizeRate / _100_PERCENT;
-		if( n < 1 )
-			n = 1;
-
-		return n;
-	}
+	WSDmwindowDev *ReNewWBuf();
 
 	void scrollTile( long mapX, long mapY );
 	void scrollMap( long x, long y );
 	bool chkScroll( long x, long y, long w, long h );
 	bool drawScroll( long x, long y, long w, long h );
+	long getScrollBarX();
+	long getScrollBarY();
+	long getScrollBarW();
+	long getScrollBarH();
+	long getScrollBarMaxX();
+	long getScrollBarMaxY();
+	void setScrollBarX( long x );
+	void setScrollBarY( long y );
 
 	bool clipWin( long mapX, long mapY );
 	bool clipWinX( long mapX );
 	bool clipWinY( long mapY );
-	void redraw();
-	bool draw( long mapX, long mapY, long mapW, long mapH );
+
+	void redraw( bool flgForce = false );
+	bool draw( long mapX, long mapY, long mapW, long mapH,
+		bool flgForce = false );
+	void drawTurn();
+	bool drawSub( long mapX, long mapY, long mapW, long mapH );
 	void flush( long mapX, long mapY, long mapW, long mapH );
 
-	void resetUpdateFlg();
-	void setUpdateFlg( long mapX, long mapY, bool flg );
-	bool getUpdateFlg( long mapX, long mapY );
+	void initText();
+	bool drawText( long mapX, long mapY, long mapW, long mapH );
+
+#ifdef D_GTK
+	bool user_select_font( GdkFont **font );
+#endif // D_GTK
 
 	Pcg *getChrPcg( chr_t *chr );
 
@@ -258,30 +348,61 @@ public:
 	long getChrDrawTop( chr_t *chr, Pcg *pPcg, bool flagPre );
 	long getChrDrawBottom( chr_t *chr, Pcg *pPcg, bool flagPre );
 
+	long getObjDrawLeft( long mapX, Pcg *pPcg );
+	long getObjDrawRight( long mapX, Pcg *pPcg );
+	long getObjDrawWidth( long mapX, Pcg *pPcg );
+	long getObjDrawTop( long mapY, Pcg *pPcg );
+	long getObjDrawBottom( long mapY, Pcg *pPcg );
+	long getObjDrawHeight( long mapY, Pcg *pPcg );
+
+	bool drawTitle();
+
 private:
+#ifdef D_MFC
+	void getScrollInfo( SCROLLINFO *info, int sb );
+	void setScrollInfoPos( int sb, int pos );
+#endif // D_MFC
+
 	void resetMap( PcgTab tab[],
-			PcgMap map[MAP_MAX_Y][MAP_MAX_X] );
+		PcgMap map[MAP_MAX_Y][MAP_MAX_X] );
+
+	void resetUpdateFlg();
+	void setUpdateFlgRange(
+		long mapX, long mapY,
+		long mapW, long mapH,
+		bool flg );
+	void setUpdateFlg( long mapX, long mapY, bool flg );
+	bool getUpdateFlg( long mapX, long mapY );
 
 	bool drawTile( long mapX, long mapY, bool flgFlush );
 	bool drawObj( long mapX, long mapY );
 	bool drawNull( long mapX, long mapY );
 	bool drawFloor( long mapX, long mapY );
 	bool drawWall( long mapX, long mapY );
+	bool drawSignboard( long mapX, long mapY );
 	bool drawStairsUp( long mapX, long mapY );
 	bool drawStairsDown( long mapX, long mapY );
 	bool drawDoorClose( long mapX, long mapY );
 	bool drawDoorOpen( long mapX, long mapY );
+	bool drawTrap( long mapX, long mapY );
+	bool drawTrapSanctuary(
+		long mapX, long mapY,
+		trap_t *trap, trap_tab_t *tab,
+		long nPcg );
 	bool drawCrsrAll( long mapX, long mapY );
 	bool drawCrsr( long mapX, long mapY );
 	bool drawCrsrSub( long mapX, long mapY );
 	bool drawSquare( long mapX, long mapY );
 	bool drawItemAll( long mapX, long mapY );
 	bool drawItem( long mapX, long mapY, char mjr, char mnr );
+	void drawChrListAll( long x, long y, long w, long h );
 	bool drawChrList( long mapX, long mapY, bool flagOneTile );
 	bool drawChr( long mapX, long mapY, chr_t *chr, Pcg *pPcg,
-			bool flagOneTile );
+		bool flagOneTile );
 
 	bool chkDrawWall( long mapX, long mapY );
+	bool chkDrawSignboard( long mapX, long mapY );
+	bool chkDrawSanctuary( long mapX, long mapY, trap_t *trap );
 	bool chkDrawCrsr( long mapX, long mapY );
 	bool chkDrawCrsrSub( long mapX, long mapY );
 	bool chkDrawSquare( long mapX, long mapY );
