@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: PcgDunTab.h,v 1.8 2007/02/05 05:15:45 bowkenken Exp $
+* $Id: PcgDunTab.h,v 1.14 2007/12/10 06:52:36 bowkenken Exp $
 ***************************************************************/
 
 #ifndef PCG_DUN_TAB_H
@@ -79,7 +79,7 @@ PcgTab gPcgTabFloorTown[] = {
 		// 夿ޤ
 		MNSTR_KIND_NULL,
 		FACE_MJR_NULL, FACE_MNR_NULL,
-		10,
+		5,
 		"floor/town/puddle/",
 	},
 	{
@@ -109,7 +109,7 @@ PcgTab gPcgTabFloorDun[] = {
 		// 夿ޤ
 		MNSTR_KIND_NULL,
 		FACE_MJR_NULL, FACE_MNR_NULL,
-		10,
+		1,
 		"floor/dungeon/puddle/",
 	},
 	{
@@ -139,7 +139,7 @@ PcgTab gPcgTabWallTown[] = {
 		// 
 		MNSTR_KIND_NULL,
 		FACE_MJR_NULL, FACE_MNR_NULL,
-		10,
+		30,
 		"wall/town/moss/",
 	},
 	{
@@ -162,7 +162,7 @@ PcgTab gPcgTabWallDun[] = {
 		// 
 		MNSTR_KIND_NULL,
 		FACE_MJR_NULL, FACE_MNR_NULL,
-		10,
+		30,
 		"wall/dungeon/moss/",
 	},
 	{
@@ -173,6 +173,22 @@ PcgTab gPcgTabWallDun[] = {
 	},
 };
 
+PcgTab gPcgTabSignboard[] = {
+	{
+		// 
+		MNSTR_KIND_NULL,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		100,
+		"signboard",
+	},
+	{
+		MNSTR_KIND_NULL,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		-1,
+		"",
+	},
+};
+
 PcgTab gPcgTabStairsUpTown[] = {
 	{
 		// 
@@ -301,7 +317,93 @@ PcgTab gPcgTabDoorOpenDun[] = {
 	},
 };
 
+PcgTab gPcgTabTrap[] = {
+	{
+		// ̤
+		MNSTR_KIND_NULL,
+		FACE_MJR_TRAP, FACE_MNR_NULL,
+		100,
+		"trap/",
+	},
+	{
+		// ̲
+		MNSTR_KIND_NULL,
+		FACE_MJR_TRAP, FACE_MNR_TRAP_SLEEP,
+		100,
+		"trap/sleep/",
+	},
+	{
+		// 
+		MNSTR_KIND_NULL,
+		FACE_MJR_TRAP, FACE_MNR_TRAP_ARW,
+		100,
+		"trap/arw/",
+	},
+	{
+		// ǥĤ
+		MNSTR_KIND_NULL,
+		FACE_MJR_TRAP, FACE_MNR_TRAP_POISON_DARTS,
+		100,
+		"trap/poison_darts/",
+	},
+	{
+		// Ƥ
+		MNSTR_KIND_NULL,
+		FACE_MJR_TRAP, FACE_MNR_TRAP_BOMB,
+		100,
+		"trap/bomb/",
+	},
+	{
+		// ѡƥְִư
+		MNSTR_KIND_NULL,
+		FACE_MJR_TRAP, FACE_MNR_TRAP_TELEPORT_PARTY,
+		100,
+		"trap/teleport_party/",
+	},
+	{
+		// ְִư
+		MNSTR_KIND_NULL,
+		FACE_MJR_TRAP, FACE_MNR_TRAP_TELEPORT,
+		100,
+		"trap/teleport/",
+	},
+	{
+		// 
+		MNSTR_KIND_NULL,
+		FACE_MJR_TRAP, FACE_MNR_TRAP_PIT,
+		100,
+		"trap/pit/",
+	},
+	{
+		// 塼
+		MNSTR_KIND_NULL,
+		FACE_MJR_TRAP, FACE_MNR_TRAP_CHUTE,
+		100,
+		"trap/chute/",
+	},
+	{
+		// 
+		MNSTR_KIND_NULL,
+		FACE_MJR_TRAP, FACE_MNR_TRAP_SANCTUARY,
+		100,
+		"trap/sanctuary/",
+	},
+	{
+		MNSTR_KIND_NULL,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		-1,
+		"",
+	},
+};
+
 PcgTab gPcgTabCrsr[] = {
+	{
+		// 
+		MNSTR_KIND_NULL,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		100,
+		"cursor/",
+	},
 	{
 		// 
 		MNSTR_KIND_NULL,
@@ -333,11 +435,37 @@ PcgTab gPcgTabCrsrSub[] = {
 	},
 };
 
-PcgTab gPcgTabSquare = {
-	MNSTR_KIND_NULL,
-	FACE_MJR_NULL, FACE_MNR_NULL,
-	100,
-	"anchor/",
+PcgTab gPcgTabSquare[] = {
+	{
+		MNSTR_KIND_NULL,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		100,
+		"anchor/north",
+	},
+	{
+		MNSTR_KIND_NULL,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		100,
+		"anchor/east",
+	},
+	{
+		MNSTR_KIND_NULL,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		100,
+		"anchor/south",
+	},
+	{
+		MNSTR_KIND_NULL,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		100,
+		"anchor/west",
+	},
+	{
+		MNSTR_KIND_NULL,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		-1,
+		"",
+	},
 };
 
 PcgTab gPcgTabItem[] = {
