@@ -25,11 +25,11 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: amenu.c,v 1.63 2007/02/21 05:24:44 bowkenken Exp $
+* $Id: amenu.c,v 1.70 2007/06/05 07:33:35 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
-* ưޡ
+* (ưޡ)
 ***************************************************************/
 
 #define	AMENU_C
@@ -444,6 +444,21 @@ void	init_auto_mark_mbr( long ls_mbr_n )
 			MSG_TTL_AUTO_MARK_MAX_LEN );
 }
 
+/***************************************************************
+* Сν
+* long ls_mbr_n : СΥꥹֹ
+***************************************************************/
+
+void	init_auto_mark_new_mbr( long ls_mbr_n )
+{
+	long	j;
+
+	/*  */
+
+	for( j = 0; j < AUTO_MARK_MAX_N; j++ )
+		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_clear;
+}
+
 /***************************************************************
 * ΥСʥå
 * long ls_mbr_n : СΥꥹֹ
@@ -643,11 +658,13 @@ void	set_menu_auto_mark( menu_t **dflt )
 {
 	long	left_max_len;
 	menu_t	*p;
-	char	buf[MSG_TTL_AUTO_MARK_MAX_LEN * 2 + 16 + 1];
+	char	buf[MSG_TTL_AUTO_MARK_MAX_LEN * 3 + 16 + 1];
+	char	key;
 	long	i, k;
 
 	p = ls_menu_auto_mark;
 	k = 0;
+	key = 'A';
 
 	str_nz_cpy( p[k].path, "/auto mark", MENU_PATH_MAX_LEN );
 	str_nz_cpy( p[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
@@ -677,31 +694,50 @@ void	set_menu_auto_mark( menu_t **dflt )
 		len = str_len_draw( get_msg_ttl_auto_mark_info( i ) );
 		left_max_len = max_l( left_max_len, len );
 	}
+	if( left_max_len > MSG_TTL_AUTO_MARK_INFO_MAX_LEN )
+		left_max_len = MSG_TTL_AUTO_MARK_INFO_MAX_LEN;
 
 	for( i = 0; i < AUTO_MARK_MAX_N; i++ ){
 		long	kk;
 
-		kk = k;
-
 		if( i == auto_mark_cur_n )
 			*dflt = &(p[k]);
 
+		if( (i != 0) && ((i % AUTO_MARK_N_PER_PAGE) == 0) ){
+			str_nz_cpy( p[k].path, "/auto mark/--",
+					MENU_PATH_MAX_LEN );
+			str_nz_cpy( p[k].kind, "<PageSeparator>",
+					MENU_KIND_MAX_LEN );
+			p[k].accel_key = '\0';
+			p[k].short_key[0] = '\0';
+			p[k].n_msg = N_MSG_NULL;
+			p[k].msg[0] = '\0';
+			p[k].call_back = NULL;
+			p[k].arg = NULL;
+			p[k].flg = FLG_NULL;
+			k++;
+
+			key = 'A';
+		}
+
+		kk = k;
+
 		sprintf( buf, "%*s%s%s",
 				(int)left_max_len,
 				get_msg_ttl_auto_mark_info( i ),
 				STR_TTL_AUTO_MARK_SPLIT_NAME,
-
 				get_msg_ttl_auto_mark_hint( i ) );
 
 		sprintf( p[k].path, "/auto mark/%ld", i );
 		str_nz_cpy( p[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
-		p[k].accel_key = (char)('A' + i);
+		p[k].accel_key = key;
 		p[k].short_key[0] = '\0';
 		str_nz_cpy( p[k].msg, buf, MENU_MSG_MAX_LEN );
 		p[k].call_back = NULL;
 		p[k].arg = NULL;
 		p[k].flg = FLG_NULL;
 		k++;
+		key++;
 
 		sprintf( p[k].path, "%s/exec", p[kk].path );
 		str_nz_cpy( p[k].kind, "<Item>", MENU_KIND_MAX_LEN );
@@ -950,6 +986,18 @@ bool_t	exec_menu_auto_mark_mnstr( mbr_t *mbr )
 	case AUTO_MARK_COND_STAGGER:
 	case AUTO_MARK_COND_OWN:
 		return FALSE;
+	case AUTO_MARK_COND_HP_MIN:
+		mnstr = get_mnstr_hp_min( mbr->x, mbr->y );
+		break;
+	case AUTO_MARK_COND_HP_MAX:
+		mnstr = get_mnstr_hp_max( mbr->x, mbr->y );
+		break;
+	case AUTO_MARK_COND_MP_MIN:
+		mnstr = get_mnstr_mp_min( mbr->x, mbr->y );
+		break;
+	case AUTO_MARK_COND_MP_MAX:
+		mnstr = get_mnstr_mp_max( mbr->x, mbr->y );
+		break;
 	}
 	if( mnstr == NULL )
 		return FALSE;
@@ -1043,6 +1091,11 @@ bool_t	exec_menu_auto_mark_item( mbr_t *mbr )
 	case AUTO_MARK_COND_OWN:
 		item = get_item_own( mbr, act_kind, TRUE );
 		break;
+	case AUTO_MARK_COND_HP_MIN:
+	case AUTO_MARK_COND_HP_MAX:
+	case AUTO_MARK_COND_MP_MIN:
+	case AUTO_MARK_COND_MP_MAX:
+		return FALSE;
 	}
 	if( item == NULL )
 		return FALSE;
@@ -1135,6 +1188,10 @@ bool_t	exec_menu_auto_mark_door( mbr_t *mbr )
 		break;
 	case AUTO_MARK_COND_STAGGER:
 	case AUTO_MARK_COND_OWN:
+	case AUTO_MARK_COND_HP_MIN:
+	case AUTO_MARK_COND_HP_MAX:
+	case AUTO_MARK_COND_MP_MIN:
+	case AUTO_MARK_COND_MP_MAX:
 		return FALSE;
 	}
 	if( door == NULL )
@@ -1199,6 +1256,18 @@ bool_t	exec_menu_auto_mark_mbr( mbr_t *mbr )
 		break;
 	case AUTO_MARK_COND_OWN:
 		return FALSE;
+	case AUTO_MARK_COND_HP_MIN:
+		p = get_mbr_hp_min();
+		break;
+	case AUTO_MARK_COND_HP_MAX:
+		p = get_mbr_hp_max();
+		break;
+	case AUTO_MARK_COND_MP_MIN:
+		p = get_mbr_mp_min();
+		break;
+	case AUTO_MARK_COND_MP_MAX:
+		p = get_mbr_mp_max();
+		break;
 	}
 	if( p == NULL )
 		return FALSE;
@@ -1308,7 +1377,7 @@ char	*cb_menu_auto_mark_edit_init(
 	if( p == NULL )
 		return STR_MENU_ERR;
 	sprintf( p->msg, MSG_TTL_MENU_AUTO_MARK_EDIT,
-			get_msg_ttl_auto_mark_name( auto_mark_cur_n ),
+			get_msg_ttl_auto_mark_info( auto_mark_cur_n ),
 			g_sel_mbr->name );
 
 	/* о */
@@ -1386,7 +1455,7 @@ char	*cb_menu_auto_mark_trgt_init(
 	if( p == NULL )
 		return STR_MENU_ERR;
 	sprintf( p->msg, MSG_TTL_MENU_AUTO_MARK_TRGT,
-			get_msg_ttl_auto_mark_name( auto_mark_cur_n ),
+			get_msg_ttl_auto_mark_info( auto_mark_cur_n ),
 			g_sel_mbr->name );
 
 	s = NULL;
@@ -1489,7 +1558,7 @@ char	*cb_menu_auto_mark_dist_init(
 	if( p == NULL )
 		return STR_MENU_ERR;
 	sprintf( p->msg, MSG_TTL_MENU_AUTO_MARK_DIST,
-			get_msg_ttl_auto_mark_name( auto_mark_cur_n ),
+			get_msg_ttl_auto_mark_info( auto_mark_cur_n ),
 			g_sel_mbr->name );
 
 	s = NULL;
@@ -1552,7 +1621,7 @@ char	*cb_menu_auto_mark_act_init( menu_t **pp, menu_t **dflt )
 	if( p == NULL )
 		return STR_MENU_ERR;
 	sprintf( p->msg, MSG_TTL_MENU_AUTO_MARK_ACT,
-			get_msg_ttl_auto_mark_name( auto_mark_cur_n ),
+			get_msg_ttl_auto_mark_info( auto_mark_cur_n ),
 			g_sel_mbr->name );
 
 	s = NULL;
@@ -1702,7 +1771,7 @@ char	*cb_menu_auto_mark_cond_init(
 	if( p == NULL )
 		return STR_MENU_ERR;
 	sprintf( p->msg, MSG_TTL_MENU_AUTO_MARK_COND,
-			get_msg_ttl_auto_mark_name( auto_mark_cur_n ),
+			get_msg_ttl_auto_mark_info( auto_mark_cur_n ),
 			g_sel_mbr->name );
 
 	/* ǥեȤΥ */
@@ -1721,23 +1790,51 @@ char	*cb_menu_auto_mark_cond_init(
 	case AUTO_MARK_COND_OWN:
 		s = "own";
 		break;
+	case AUTO_MARK_COND_HP_MIN:
+		s = "hp min";
+		break;
+	case AUTO_MARK_COND_HP_MAX:
+		s = "hp max";
+		break;
+	case AUTO_MARK_COND_MP_MIN:
+		s = "mp min";
+		break;
+	case AUTO_MARK_COND_MP_MAX:
+		s = "mp max";
+		break;
 	}
 	*dflt = srch_menu( *pp, s );
 
 	/* оݤ˱ƥ˥塼ܤ̵ */
 
+	set_flg_menu( *pp, "hp min", FLG_MENU_HIDDEN );
+	set_flg_menu( *pp, "hp max", FLG_MENU_HIDDEN );
+	set_flg_menu( *pp, "mp min", FLG_MENU_HIDDEN );
+	set_flg_menu( *pp, "mp max", FLG_MENU_HIDDEN );
+
 	switch( ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n].trgt ){
 	case AUTO_MARK_TRGT_DOOR:
 	case AUTO_MARK_TRGT_TRAP:
-	case AUTO_MARK_TRGT_MNSTR:
 		set_flg_menu( *pp, "stagger", FLG_MENU_HIDDEN );
 		set_flg_menu( *pp, "own", FLG_MENU_HIDDEN );
 		break;
 	case AUTO_MARK_TRGT_ITEM:
 		set_flg_menu( *pp, "stagger", FLG_MENU_HIDDEN );
 		break;
+	case AUTO_MARK_TRGT_MNSTR:
+		set_flg_menu( *pp, "stagger", FLG_MENU_HIDDEN );
+		set_flg_menu( *pp, "own", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "hp min", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "hp max", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "mp min", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "mp max", FLG_MENU_HIDDEN );
+		break;
 	case AUTO_MARK_TRGT_MBR:
 		set_flg_menu( *pp, "own", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "hp min", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "hp max", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "mp min", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "mp max", FLG_MENU_HIDDEN );
 		break;
 	case AUTO_MARK_TRGT_UNCHANGE:
 	case AUTO_MARK_TRGT_CLEAR:
@@ -1751,7 +1848,7 @@ char	*cb_menu_auto_mark_cond_init(
 	if( p == NULL )
 		return STR_MENU_ERR;
 	sprintf( p->msg, MSG_TTL_MENU_AUTO_MARK_COND,
-			get_msg_ttl_auto_mark_name( auto_mark_cur_n ),
+			get_msg_ttl_auto_mark_info( auto_mark_cur_n ),
 			g_sel_mbr->name );
 
 	return NULL;
@@ -1766,24 +1863,8 @@ char	*cb_menu_auto_mark_cond_init(
 
 char	*cb_menu_auto_mark_cond( menu_t **pp, menu_t **dflt )
 {
-	switch( (auto_mark_cond_t)(long)((*pp)->arg) ){
-	case AUTO_MARK_COND_NEAREST:
-		ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n].cond
-				= AUTO_MARK_COND_NEAREST;
-		break;
-	case AUTO_MARK_COND_DISPERSE:
-		ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n].cond
-				= AUTO_MARK_COND_DISPERSE;
-		break;
-	case AUTO_MARK_COND_STAGGER:
-		ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n].cond
-				= AUTO_MARK_COND_STAGGER;
-		break;
-	case AUTO_MARK_COND_OWN:
-		ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n].cond
-				= AUTO_MARK_COND_OWN;
-		break;
-	}
+	ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n].cond
+			= (auto_mark_cond_t)(long)((*pp)->arg);
 
 	return NULL;
 }
@@ -1833,7 +1914,7 @@ char	*cb_menu_auto_mark_appoint_item(
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
 	sprintf( ls[k].msg, MSG_TTL_MENU_AUTO_MARK_APPOINT_ITEM_MJR,
-			get_msg_ttl_auto_mark_name( auto_mark_cur_n ),
+			get_msg_ttl_auto_mark_info( auto_mark_cur_n ),
 			g_sel_mbr->name );
 	ls[k].call_back = NULL;
 	ls[k].arg = NULL;
@@ -2223,15 +2304,15 @@ char	*cb_menu_auto_mark_paste_small( menu_t **pp, menu_t **dflt )
 char	*cb_menu_auto_mark_edit_name( menu_t **pp, menu_t **dflt )
 {
 	long	n;
-	static char	info[MSG_TTL_AUTO_MARK_MAX_LEN + 1];
-	static char	hint[MSG_TTL_AUTO_MARK_MAX_LEN + 1];
+	static char	info[MSG_TTL_AUTO_MARK_INFO_MAX_LEN + 1];
+	static char	hint[MSG_TTL_AUTO_MARK_HINT_MAX_LEN + 1];
 
 	n = (long)((*pp)->arg);
 
 	str_nz_cpy( info, get_msg_ttl_auto_mark_info( n ),
-			MSG_TTL_AUTO_MARK_MAX_LEN );
+			MSG_TTL_AUTO_MARK_INFO_MAX_LEN );
 	str_nz_cpy( hint, get_msg_ttl_auto_mark_hint( n ),
-			MSG_TTL_AUTO_MARK_MAX_LEN );
+			MSG_TTL_AUTO_MARK_HINT_MAX_LEN );
 
 	wipe_all();
 	gets_auto_mark_info( info );
@@ -2290,15 +2371,41 @@ char	*cb_menu_auto_mark_arrange_bottom( menu_t **pp, menu_t **dflt )
 
 /***************************************************************
 * ˥塼¤ٴ
-* menu_t **pp : ˥塼
-* menu_t **dflt : ˥塼Υǥե
+* long n : ϰ
+* long d : Ƭ(-1)/(+1)
 * return : ˥塼ΰư
 ***************************************************************/
 
 char	*menu_auto_mark_arrange( long n, long d )
 {
-	long	i, j;
+	if( !arrange_auto_mark( n, d ) )
+		return STR_MENU_ERR;
+
+	if( d <= -1 ){
+		print_msg( FLG_NULL,
+				MSG_MENU_AUTO_MARK_DONE_ARRANGE_TOP );
+	} else {
+		print_msg( FLG_NULL,
+				MSG_MENU_AUTO_MARK_DONE_ARRANGE_BOTTOM );
+	}
+
+	return "/auto mark";
+}
+
+/***************************************************************
+* ˥塼¤ٴ
+* long n : ϰ
+* long d : Ƭ(-1)/(+1)
+* return : ?
+***************************************************************/
+
+bool_t	arrange_auto_mark( long n, long d )
+{
+	long	i, j, k;
 	auto_mark_t	am;
+	auto_mark_appoint_item_t	item[AUTO_MARK_APPOINT_ITEM_MAX_N];
+	auto_mark_appoint_item_t	item_tmp;
+	const long	max_item = AUTO_MARK_APPOINT_ITEM_MAX_N;
 	char	buf[MSG_TTL_AUTO_MARK_MAX_LEN + 1];
 
 	if( d <= -1 )
@@ -2306,25 +2413,55 @@ char	*menu_auto_mark_arrange( long n, long d )
 	else if( d >= +1 )
 		d = +1;
 	else
-		return STR_MENU_ERR;
+		return FALSE;
 
 	for( i = 0; i < LS_MBR_MAX_N; i++ ){
 		am = ls_auto_mark[i][n];
 
+		for( k = 0; k < max_item; k++ ){
+			item[k] = auto_mark_appoint_item[i][n][k];
+		}
+
 		if( d <= -1 ){
 			for( j = n - 1; j >= 0; j-- ){
 				ls_auto_mark[i][j + 1]
 						= ls_auto_mark[i][j];
+
+				for( k = 0; k < max_item; k++ ){
+					item_tmp = auto_mark_appoint_item
+							[i][j][k];
+					auto_mark_appoint_item[i][j + 1][k]
+							= item_tmp;
+				}
 			}
 
 			ls_auto_mark[i][0] = am;
+
+			for( k = 0; k < max_item; k++ ){
+				auto_mark_appoint_item
+						[i][0][k]
+						= item[k];
+			}
 		} else {
 			for( j = n + 1; j < AUTO_MARK_MAX_N; j++ ){
 				ls_auto_mark[i][j - 1]
 						= ls_auto_mark[i][j];
+
+				for( k = 0; k < max_item; k++ ){
+					item_tmp = auto_mark_appoint_item
+							[i][j][k];
+					auto_mark_appoint_item[i][j - 1][k]
+							= item_tmp;
+				}
 			}
 
 			ls_auto_mark[i][AUTO_MARK_MAX_N - 1] = am;
+
+			for( k = 0; k < max_item; k++ ){
+				auto_mark_appoint_item
+						[i][AUTO_MARK_MAX_N - 1][k]
+						= item[k];
+			}
 		}
 	}
 
@@ -2357,15 +2494,96 @@ char	*menu_auto_mark_arrange( long n, long d )
 
 	auto_mark_cur_n = 0;
 
-	if( d <= -1 ){
-		print_msg( FLG_NULL,
-				MSG_MENU_AUTO_MARK_DONE_ARRANGE_TOP );
-	} else {
-		print_msg( FLG_NULL,
-				MSG_MENU_AUTO_MARK_DONE_ARRANGE_BOTTOM );
+	return TRUE;
+}
+
+/***************************************************************
+* ˥塼¤ٴ(Сñ)
+* long ls_mbr_n : С
+* long d : Ƭ(-1)/(+1)
+* return : ?
+***************************************************************/
+
+bool_t	arrange_auto_mark_mbr( long ls_mbr_n, long d )
+{
+	long	i, j, k;
+	auto_mark_t	am[AUTO_MARK_MAX_N];
+	auto_mark_appoint_item_t	item
+			[AUTO_MARK_MAX_N]
+			[AUTO_MARK_APPOINT_ITEM_MAX_N];
+	auto_mark_appoint_item_t	item_tmp;
+	const long	max_item = AUTO_MARK_APPOINT_ITEM_MAX_N;
+	mbr_t	**ls_mbr = get_ls_mbr();
+
+	if( d <= -1 )
+		d = -1;
+	else if( d >= +1 )
+		d = +1;
+	else
+		return FALSE;
+
+	ls_mbr = get_ls_mbr();
+
+	for( j = 0; j < AUTO_MARK_MAX_N; j++ ){
+		am[j] = ls_auto_mark[ls_mbr_n][j];
+
+		for( k = 0; k < max_item; k++ ){
+			item[j][k] = auto_mark_appoint_item[ls_mbr_n][j][k];
+		}
 	}
 
-	return "/auto mark";
+	if( d <= -1 ){
+		for( i = ls_mbr_n; i > 0; i-- ){
+			for( j = 0; j < AUTO_MARK_MAX_N; j++ ){
+				ls_auto_mark[i][j] = ls_auto_mark[i - 1][j];
+
+				for( k = 0; k < max_item; k++ ){
+					item_tmp = auto_mark_appoint_item
+							[i - 1][j][k];
+					auto_mark_appoint_item[i][j][k]
+							= item_tmp;
+				}
+			}
+		}
+	} else {
+		for( i = ls_mbr_n; i < LS_MBR_MAX_N - 1; i++ ){
+			if( chk_flg( ls_mbr[i + 1]->stat,
+					FLG_STAT_NOT_EXIST ) ){
+				break;
+			}
+			for( j = 0; j < AUTO_MARK_MAX_N; j++ ){
+				ls_auto_mark[i][j] = ls_auto_mark[i + 1][j];
+
+				for( k = 0; k < max_item; k++ ){
+					item_tmp = auto_mark_appoint_item
+							[i + 1][j][k];
+					auto_mark_appoint_item[i][j][k]
+							= item_tmp;
+				}
+			}
+		}
+	}
+
+	for( j = 0; j < AUTO_MARK_MAX_N; j++ ){
+		ls_auto_mark[i][j] = am[j];
+
+		for( k = 0; k < max_item; k++ ){
+			auto_mark_appoint_item[i][j][k] = item[j][k];
+		}
+	}
+
+	return TRUE;
+}
+
+/***************************************************************
+* ˥塼κ(Сñ)
+* long ls_mbr_n : С
+* return : ?
+***************************************************************/
+
+bool_t	remove_auto_mark_mbr( long ls_mbr_n )
+{
+	return arrange_auto_mark_mbr( ls_mbr_n, +1 );
 }
 
 /***************************************************************
@@ -2495,6 +2713,14 @@ char	*get_msg_menu_auto_mark_edit_cond( mbr_t *mbr )
 		return MSG_MENU_AUTO_MARK_COND_STAGGER;
 	case AUTO_MARK_COND_OWN:
 		return MSG_MENU_AUTO_MARK_COND_OWN;
+	case AUTO_MARK_COND_HP_MIN:
+		return MSG_MENU_AUTO_MARK_COND_HP_MIN;
+	case AUTO_MARK_COND_HP_MAX:
+		return MSG_MENU_AUTO_MARK_COND_HP_MAX;
+	case AUTO_MARK_COND_MP_MIN:
+		return MSG_MENU_AUTO_MARK_COND_MP_MIN;
+	case AUTO_MARK_COND_MP_MAX:
+		return MSG_MENU_AUTO_MARK_COND_MP_MAX;
 	}
 
 	return MSG_NOT_NULL;
@@ -2567,22 +2793,22 @@ char	*get_msg_ttl_auto_mark_name( long n )
 
 char	*get_msg_ttl_auto_mark_info( long n )
 {
-	static char	str[MSG_TTL_AUTO_MARK_MAX_LEN + 1];
+	static char	str[MSG_TTL_AUTO_MARK_INFO_MAX_LEN + 1];
 	char	*ttl, *p;
 
 	ttl = msg_ttl_auto_mark[n];
 
 	p = strstr( ttl, STR_TTL_AUTO_MARK_SPLIT_CODE );
 	if( p == NULL ){
-		str_nz_cpy( str, ttl, MSG_TTL_AUTO_MARK_MAX_LEN );
+		str_nz_cpy( str, ttl, MSG_TTL_AUTO_MARK_INFO_MAX_LEN );
 	} else {
 		long	len;
 
 		len = p - ttl;
 		if( len < 0 )
 			len = 0;
-		if( len > MSG_TTL_AUTO_MARK_MAX_LEN )
-			len = MSG_TTL_AUTO_MARK_MAX_LEN;
+		if( len > MSG_TTL_AUTO_MARK_INFO_MAX_LEN )
+			len = MSG_TTL_AUTO_MARK_INFO_MAX_LEN;
 
 		str_nz_cpy( str, ttl, len );
 	}
@@ -2598,7 +2824,7 @@ char	*get_msg_ttl_auto_mark_info( long n )
 
 char	*get_msg_ttl_auto_mark_hint( long n )
 {
-	static char	str[MSG_TTL_AUTO_MARK_MAX_LEN + 1];
+	static char	str[MSG_TTL_AUTO_MARK_HINT_MAX_LEN + 1];
 	char	*ttl, *p;
 
 	ttl = msg_ttl_auto_mark[n];
@@ -2610,7 +2836,7 @@ char	*get_msg_ttl_auto_mark_hint( long n )
 		long	len;
 
 		len = str_len_std( STR_TTL_AUTO_MARK_SPLIT_CODE );
-		str_nz_cpy( str, &(p[len]), MSG_TTL_AUTO_MARK_MAX_LEN );
+		str_nz_cpy( str, &(p[len]), MSG_TTL_AUTO_MARK_HINT_MAX_LEN );
 	}
 
 	return str;
