@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: draw.h,v 1.53 2007/02/02 19:45:13 bowkenken Exp $
+* $Id: draw.h,v 1.56 2007/06/11 09:41:02 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	DRAW_H
@@ -83,13 +83,17 @@
 #define	WIN_MAP_DRAW_MIN_Y	0
 #define	WIN_MAP_DRAW_WIDTH	(WIN_MAP_WIDTH * 2)
 #define	WIN_MAP_DRAW_HEIGHT	WIN_MAP_HEIGHT
-#define	WIN_MAP_DRAW_MAX_X	(WIN_MAP_DRAW_MIN_X + WIN_MAP_DRAW_WIDTH - 1)
-#define	WIN_MAP_DRAW_MAX_Y	(WIN_MAP_DRAW_MIN_Y + WIN_MAP_DRAW_HEIGHT - 1)
+#define	WIN_MAP_DRAW_MAX_X	\
+		(WIN_MAP_DRAW_MIN_X + WIN_MAP_DRAW_WIDTH - 1)
+#define	WIN_MAP_DRAW_MAX_Y	\
+		(WIN_MAP_DRAW_MIN_Y + WIN_MAP_DRAW_HEIGHT - 1)
 
 #define	WIN_MENU_DRAW_MIN_X	SCREEN_MIN_X
 #define	WIN_MENU_DRAW_MIN_Y	SCREEN_MIN_Y
-#define	WIN_MENU_DRAW_WIDTH	(WIN_MENU_DRAW_MAX_X - WIN_MENU_DRAW_MIN_X)
-#define	WIN_MENU_DRAW_HEIGHT	(WIN_MENU_DRAW_MAX_Y - WIN_MENU_DRAW_MIN_Y)
+#define	WIN_MENU_DRAW_WIDTH	\
+		(WIN_MENU_DRAW_MAX_X - WIN_MENU_DRAW_MIN_X + 1)
+#define	WIN_MENU_DRAW_HEIGHT	\
+		(WIN_MENU_DRAW_MAX_Y - WIN_MENU_DRAW_MIN_Y + 1)
 #define	WIN_MENU_DRAW_MAX_X	SCREEN_MAX_X
 #define	WIN_MENU_DRAW_MAX_Y	(WIN_MSG_DRAW_MIN_Y - 1)
 
@@ -97,10 +101,13 @@
 #define	WIN_MSG_DRAW_MIN_Y	(WIN_MAP_DRAW_MAX_Y + 2)
 #define	WIN_MSG_DRAW_WIDTH	(SCREEN_WIDTH - 1)
 #define	WIN_MSG_DRAW_HEIGHT	1
-#define	WIN_MSG_DRAW_MAX_X	(WIN_MSG_DRAW_MIN_X + WIN_MSG_DRAW_WIDTH - 1)
-#define	WIN_MSG_DRAW_MAX_Y	(WIN_MSG_DRAW_MIN_Y + WIN_MSG_DRAW_HEIGHT - 1)
+#define	WIN_MSG_DRAW_MAX_X	\
+		(WIN_MSG_DRAW_MIN_X + WIN_MSG_DRAW_WIDTH - 1)
+#define	WIN_MSG_DRAW_MAX_Y	\
+		(WIN_MSG_DRAW_MIN_Y + WIN_MSG_DRAW_HEIGHT - 1)
 
-#define	WIN_MORE_DRAW_MIN_X	(WIN_MSG_DRAW_MAX_X - WIN_MORE_DRAW_WIDTH + 1)
+#define	WIN_MORE_DRAW_MIN_X	\
+		(WIN_MSG_DRAW_MAX_X - WIN_MORE_DRAW_WIDTH + 1)
 #define	WIN_MORE_DRAW_MIN_Y	WIN_MSG_DRAW_MIN_Y
 #define	WIN_MORE_DRAW_WIDTH	(str_len_draw( MSG_MORE ))
 
@@ -313,6 +320,38 @@ typedef enum {
 	DATA_N_BAR,
 	DATA_N_NIN,
 
+	DATA_N_ITEM_00,
+	DATA_N_ITEM_01,
+	DATA_N_ITEM_02,
+	DATA_N_ITEM_03,
+	DATA_N_ITEM_04,
+	DATA_N_ITEM_05,
+	DATA_N_ITEM_06,
+	DATA_N_ITEM_07,
+	DATA_N_ITEM_08,
+	DATA_N_ITEM_09,
+	DATA_N_ITEM_10,
+	DATA_N_ITEM_11,
+	DATA_N_ITEM_12,
+	DATA_N_ITEM_13,
+	DATA_N_ITEM_14,
+	DATA_N_ITEM_15,
+
+	DATA_N_EQUIP_WIELDING,
+	DATA_N_EQUIP_SHIELD,
+	DATA_N_EQUIP_BOW,
+	DATA_N_EQUIP_ARW,
+	DATA_N_EQUIP_HEAD,
+	DATA_N_EQUIP_NECK,
+	DATA_N_EQUIP_BODY,
+	DATA_N_EQUIP_ABOUT_BODY,
+	DATA_N_EQUIP_ARM,
+	DATA_N_EQUIP_RIGHT_HAND,
+	DATA_N_EQUIP_LEFT_HAND,
+	DATA_N_EQUIP_FEET,
+	DATA_N_EQUIP_LIGHT_SOURCE,
+
+	DATA_N_PREV_PAGE,
 	DATA_N_NEXT_PAGE,
 
 	DATA_N_MAX_N,
