@@ -62,7 +62,11 @@ bool_t	load_game_conf_menu_line(
 void	back_up_game_conf( void );
 bool_t	save_game_conf( void );
 bool_t	save_game_conf_ver_1( const ver_t *ver );
+bool_t	save_game_conf_contents( FILE *fp, const ver_t *ver );
+bool_t	save_game_conf_language( FILE *fp, const ver_t *ver );
+bool_t	save_game_conf_frame_rate( FILE *fp, const ver_t *ver );
 bool_t	save_game_conf_scroll( FILE *fp, const ver_t *ver );
+bool_t	save_game_conf_flg( FILE *fp, const ver_t *ver );
 bool_t	save_game_conf_vfx( FILE *fp, const ver_t *ver );
 bool_t	save_game_conf_color( FILE *fp, const ver_t *ver );
 bool_t	save_game_conf_color_sub(
@@ -173,6 +177,12 @@ bool_t	load_game_data_acce_material_ver_1(
 	FILE *fp, const ver_t *ver, bool_t flg_txt,
 	acce_kind_t kind
 );
+bool_t	load_game_data_potion_identified_ver_1(
+	FILE *fp, const ver_t *ver, bool_t flg_txt
+);
+bool_t	load_game_data_scroll_identified_ver_1(
+	FILE *fp, const ver_t *ver, bool_t flg_txt
+);
 bool_t	load_game_data_item_mbr_ver_1(
 	FILE *fp, const ver_t *ver, bool_t flg_txt,
 	long ls_mbr_n
@@ -289,6 +299,21 @@ bool_t	load_game_data_pet_formation_ver_1(
 bool_t	load_game_data_request_ver_1(
 	FILE *fp, const ver_t *ver, bool_t flg_txt
 );
+bool_t	load_game_replay( bool_t flg_txt_data, long n );
+void	reset_load_game_replay( long n );
+bool_t	load_game_replay_head_ver_1( FILE *fp, ver_t *ver, bool_t flg_txt );
+bool_t	load_game_replay_ver_1( FILE *fp, const ver_t *ver, bool_t flg_txt );
+bool_t	load_game_replay_parse_ver_1(
+	FILE *fp, const ver_t *ver, bool_t flg_txt
+);
+bool_t	load_game_replay_id_ver_1(
+	FILE *fp, const ver_t *ver, bool_t flg_txt,
+	char *id
+);
+bool_t	load_game_replay_str_ver_1(
+	FILE *fp, const ver_t *ver, bool_t flg_txt,
+	char *str
+);
 bool_t	load_game_data_n( FILE *fp, long *n );
 bool_t	load_game_data_s( FILE *fp, char *s, long len );
 bool_t	load_game_data_c( FILE *fp, char *c );
@@ -297,7 +322,15 @@ bool_t	load_game_data_skip_token( FILE *fp, rc_token_t c, bool_t flg_draw );
 bool_t	save_game_data( bool_t flg_txt, long n );
 bool_t	save_game_data_sub( bool_t flg_txt, long n );
 bool_t	save_game_data_ver_1( const ver_t *ver, bool_t flg_txt, long n );
-bool_t	save_game_data_cnf_ver_1( const ver_t *ver, long n );
+bool_t	save_game_data_contents(
+	FILE *fp, const ver_t *ver, bool_t flg_txt
+);
+bool_t	save_game_data_randm_seed_ver_1(
+	FILE *fp, const ver_t *ver, bool_t flg_txt
+);
+bool_t	save_game_data_dun_lev_ver_1(
+	FILE *fp, const ver_t *ver, bool_t flg_txt
+);
 bool_t	save_game_data_turn_ver_1(
 	FILE *fp, const ver_t *ver, bool_t flg_txt
 );
@@ -428,6 +461,12 @@ bool_t	save_game_data_acce_material_ver_1(
 	FILE *fp, const ver_t *ver, bool_t flg_txt,
 	acce_kind_t kind
 );
+bool_t	save_game_data_potion_identified_ver_1(
+	FILE *fp, const ver_t *ver, bool_t flg_txt
+);
+bool_t	save_game_data_scroll_identified_ver_1(
+	FILE *fp, const ver_t *ver, bool_t flg_txt
+);
 bool_t	save_game_data_auto_mark_ls_ver_1(
 	FILE *fp, const ver_t *ver, bool_t flg_txt
 );
@@ -458,10 +497,58 @@ bool_t	save_game_data_pet_formation_ver_1(
 bool_t	save_game_data_request_ver_1(
 	FILE *fp, const ver_t *ver, bool_t flg_txt
 );
+bool_t	save_game_data_cnf_ver_1( const ver_t *ver, long n );
+bool_t	save_game_data_cnf_contents(
+	FILE *fp, const ver_t *ver
+);
+bool_t	save_game_replay( void );
+bool_t	save_game_replay_slot( long n );
+bool_t	save_bug_repo_replay( void );
+bool_t	copy_file_bug_repo( void );
+bool_t	save_game_replay_ver_1( const ver_t *ver, long n );
+bool_t	save_game_replay_contents(
+	FILE *fp, const ver_t *ver, long n
+);
+bool_t	load_graph_conf( char *path );
+bool_t	load_graph_conf_head( FILE *fp, ver_t *ver );
+void	load_graph_conf_data_ver_1( FILE *fp, const ver_t *ver );
+bool_t	load_graph_conf_parse_ver_1( FILE *fp, const ver_t *ver );
+bool_t	load_graph_conf_block_begin(
+	FILE *fp, const ver_t *ver, bool_t flg_err_exit,
+	char *id, long val
+);
+bool_t	load_graph_conf_block_end(
+	FILE *fp, const ver_t *ver, bool_t flg_err_exit,
+	char *id, long val
+);
+bool_t	load_graph_conf_set_val(
+	FILE *fp, const ver_t *ver, bool_t flg_err_exit,
+	char *id, long val
+);
+bool_t	load_graph_conf_set_str(
+	FILE *fp, const ver_t *ver, bool_t flg_err_exit,
+	char *id, char *str
+);
+void	get_path_game_data_txt( char *path, long n );
+void	get_path_game_data_bin( char *path, long n );
+void	get_path_game_data_cnf( char *path, long n );
+void	get_path_game_data_rep( char *path, long n );
+void	get_path_bug_repo_txt( char *path );
+void	get_path_bug_repo_bin( char *path );
+void	get_path_bug_repo_cnf( char *path );
+void	get_path_bug_repo_rep( char *path );
 FILE	*open_game_data( char type, long n, bool_t flg_txt );
 FILE	*open_game_data_cnf( char type, long n );
-bool_t	get_save_load_ttl( char *msg, long n, bool_t flg_txt );
-bool_t	get_game_data_head_time( char *str, long n, bool_t flg_txt );
+FILE	*open_game_replay( char type, long n );
+void	remove_replay_file( long n );
+bool_t	get_save_load_ttl(
+	char *msg, long n,
+	bool_t flg_txt, bool_t flg_replay
+);
+bool_t	get_game_data_head_time(
+	char *str, long n,
+	bool_t flg_txt, bool_t flg_replay
+);
 long	load_char( FILE *fp, bool_t flg_chk_eof );
 char	*load_line_skip_spc( FILE *fp, bool_t flg_chk_eof );
 char	*load_line( FILE *fp, bool_t flg_chk_eof );
@@ -565,13 +652,15 @@ fx_kind_t	trans_idx_to_fx_kind( long idx );
 long	trans_fx_kind_to_idx( fx_kind_t k );
 request_kind_t	trans_idx_to_request_kind( long idx );
 long	trans_request_kind_to_idx( request_kind_t k );
+bool_t	copy_file( const char *src, const char *dst );
 char	*cat_path( char *path, char *file );
 bool_t	chk_exist_file( char *s );
 bool_t	chk_exist_dir( char *s );
 bool_t	make_dir( char *path );
 bool_t	make_dir_node( char *path );
-char	*cv_esc_c( const long c );
-char	*cv_esc_str( const char *str );
+char	*cv_esc_quote_c( const long c );
+char	*cv_esc_quote_str( const char *str );
+char	*cv_esc_ctrl_str( const char *str );
 long	srandm_crypt( long n );
 long	randm_crypt( long c );
 void	reset_load_save( char *path, bool_t flg_txt );
