@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: inc.h,v 1.34 2007/02/25 01:58:58 bowkenken Exp $
+* $Id: inc.h,v 1.69 2007/12/24 16:36:55 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	INC_H
@@ -39,6 +39,7 @@
 
 #include	"gmain.h"
 #include	"misc.h"
+/*#include	"scene.h"*/
 /*#include	"turn.h"*/
 /*#include	"dun.h"*/
 /*#include	"town.h"*/
@@ -51,6 +52,7 @@
 /*#include	"fight.h"*/
 /*#include	"fx.h"*/
 /*#include	"trap.h"*/
+/*#include	"replay.h"*/
 #include	"draw.h"
 #include	"curs.h"
 #include	"menu.h"
@@ -61,6 +63,7 @@
 /*#include	"ver.h"*/
 #include	"gmain-prot.h"
 #include	"misc-prot.h"
+/*#include	"scene-prot.h"*/
 /*#include	"turn-prot.h"*/
 #include	"dun-prot.h"
 /*#include	"town-prot.h"*/
@@ -73,6 +76,7 @@
 /*#include	"fight-prot.h"*/
 /*#include	"fx-prot.h"*/
 /*#include	"trap-prot.h"*/
+/*#include	"replay-prot.h"*/
 #include	"draw-prot.h"
 #include	"curs-prot.h"
 #include	"menu-prot.h"
@@ -92,6 +96,7 @@
 
 #include	"gmain.h"
 /*#include	"misc.h"*/
+/*#include	"scene.h"*/
 /*#include	"turn.h"*/
 /*#include	"dun.h"*/
 #include	"town.h"
@@ -104,6 +109,7 @@
 /*#include	"fight.h"*/
 /*#include	"fx.h"*/
 #include	"trap.h"
+/*#include	"replay.h"*/
 #include	"draw.h"
 #include	"curs.h"
 #include	"menu.h"
@@ -114,6 +120,7 @@
 /*#include	"ver.h"*/
 #include	"gmain-prot.h"
 #include	"misc-prot.h"
+/*#include	"scene-prot.h"*/
 #include	"turn-prot.h"
 #include	"dun-prot.h"
 #include	"town-prot.h"
@@ -126,6 +133,7 @@
 #include	"fight-prot.h"
 #include	"fx-prot.h"
 #include	"trap-prot.h"
+/*#include	"replay-prot.h"*/
 #include	"draw-prot.h"
 #include	"curs-prot.h"
 /*#include	"menu-prot.h"*/
@@ -147,6 +155,7 @@
 
 #include	"gmain.h"
 #include	"misc.h"
+/*#include	"scene.h"*/
 /*#include	"turn.h"*/
 /*#include	"dun.h"*/
 /*#include	"town.h"*/
@@ -159,6 +168,7 @@
 /*#include	"fight.h"*/
 /*#include	"fx.h"*/
 /*#include	"trap.h"*/
+/*#include	"replay.h"*/
 #include	"draw.h"
 #include	"curs.h"
 /*#include	"menu.h"*/
@@ -169,6 +179,7 @@
 /*#include	"ver.h"*/
 #include	"gmain-prot.h"
 #include	"misc-prot.h"
+/*#include	"scene-prot.h"*/
 /*#include	"turn-prot.h"*/
 /*#include	"dun-prot.h"*/
 /*#include	"town-prot.h"*/
@@ -181,6 +192,7 @@
 /*#include	"fight-prot.h"*/
 /*#include	"fx-prot.h"*/
 /*#include	"trap-prot.h"*/
+/*#include	"replay-prot.h"*/
 #include	"draw-prot.h"
 #include	"curs-prot.h"
 /*#include	"menu-prot.h"*/
@@ -195,29 +207,85 @@
 #include	"call-prot.h"
 
 # ifdef	D_DOS
-#  include	<windows.h>
-#  include	<conio.h>
-#  ifndef	D_WS
-#   ifdef	D_WIN
-#    include	"../lnl-dos/stdafx.h"
-#   else
-#    include	"lnl-dos/stdafx.h"
-#   endif
+#  ifndef	_WINDOWS_
+#   include	<windows.h>
 #  endif
-# endif
+#  include	<conio.h>
+#  ifndef D_DOWS
+#   include	"lnl-dos/stdafx.h"
+#  endif
+# endif /* D_DOS */
 
 #endif	/* CURS_C */
 
 /***************************************************************/
 
+#ifdef	REPLAY_C
+
+#include	"gmain.h"
+#include	"misc.h"
+/*#include	"scene.h"*/
+#include	"turn.h"
+/*#include	"dun.h"*/
+#include	"town.h"
+/*#include	"item.h"*/
+/*#include	"spell.h"*/
+/*#include	"chr.h"*/
+/*#include	"party.h"*/
+/*#include	"mnstr.h"*/
+/*#include	"pet.h"*/
+/*#include	"fight.h"*/
+/*#include	"fx.h"*/
+/*#include	"trap.h"*/
+#include	"replay.h"
+#include	"draw.h"
+/*#include	"curs.h"*/
+#include	"menu.h"
+#include	"amenu.h"
+/*#include	"request.h"*/
+#include	"gfile.h"
+#include	"msg.h"
+/*#include	"ver.h"*/
+#include	"gmain-prot.h"
+#include	"misc-prot.h"
+/*#include	"scene-prot.h"*/
+#include	"turn-prot.h"
+/*#include	"dun-prot.h"*/
+/*#include	"town-prot.h"*/
+/*#include	"item-prot.h"*/
+/*#include	"spell-prot.h"*/
+/*#include	"chr-prot.h"*/
+/*#include	"party-prot.h"*/
+/*#include	"mnstr-prot.h"*/
+/*#include	"pet-prot.h"*/
+/*#include	"fight-prot.h"*/
+/*#include	"fx-prot.h"*/
+/*#include	"trap-prot.h"*/
+#include	"replay-prot.h"
+#include	"draw-prot.h"
+/*#include	"curs-prot.h"*/
+/*#include	"menu-prot.h"*/
+/*#include	"mmenu-prot.h"*/
+#include	"imenu-prot.h"
+/*#include	"tmenu-prot.h"*/
+/*#include	"amenu-prot.h"*/
+/*#include	"request-prot.h"*/
+#include	"gfile-prot.h"
+#include	"msg-prot.h"
+
+#endif	/* REPLAY_C */
+
+/***************************************************************/
+
 #ifdef	DRAW_C
 
 #include	"gmain.h"
 /*#include	"misc.h"*/
+/*#include	"scene.h"*/
 /*#include	"turn.h"*/
 /*#include	"dun.h"*/
 #include	"town.h"
-/*#include	"item.h"*/
+#include	"item.h"
 #include	"spell.h"
 /*#include	"chr.h"*/
 /*#include	"party.h"*/
@@ -226,6 +294,7 @@
 /*#include	"fight.h"*/
 #include	"fx.h"
 /*#include	"trap.h"*/
+#include	"replay.h"
 #include	"draw.h"
 /*#include	"curs.h"*/
 /*#include	"menu.h"*/
@@ -236,10 +305,11 @@
 /*#include	"ver.h"*/
 #include	"gmain-prot.h"
 #include	"misc-prot.h"
+/*#include	"scene-prot.h"*/
 #include	"turn-prot.h"
 #include	"dun-prot.h"
 /*#include	"town-prot.h"*/
-/*#include	"item-prot.h"*/
+#include	"item-prot.h"
 #include	"spell-prot.h"
 #include	"chr-prot.h"
 #include	"party-prot.h"
@@ -248,6 +318,7 @@
 #include	"fight-prot.h"
 #include	"fx-prot.h"
 /*#include	"trap-prot.h"*/
+#include	"replay-prot.h"
 #include	"draw-prot.h"
 #include	"curs-prot.h"
 #include	"menu-prot.h"
@@ -279,6 +350,7 @@
 
 #include	"gmain.h"
 /*#include	"misc.h"*/
+/*#include	"scene.h"*/
 /*#include	"turn.h"*/
 #include	"dun.h"
 #include	"town.h"
@@ -291,6 +363,7 @@
 /*#include	"fight.h"*/
 /*#include	"fx.h"*/
 /*#include	"trap.h"*/
+/*#include	"replay.h"*/
 #include	"draw.h"
 /*#include	"curs.h"*/
 #include	"menu.h"
@@ -301,6 +374,7 @@
 /*#include	"ver.h"*/
 #include	"gmain-prot.h"
 #include	"misc-prot.h"
+/*#include	"scene-prot.h"*/
 /*#include	"turn-prot.h"*/
 #include	"dun-prot.h"
 #include	"town-prot.h"
@@ -313,6 +387,7 @@
 /*#include	"fight-prot.h"*/
 #include	"fx-prot.h"
 #include	"trap-prot.h"
+/*#include	"replay-prot.h"*/
 #include	"draw-prot.h"
 #include	"curs-prot.h"
 #include	"menu-prot.h"
@@ -337,6 +412,7 @@
 
 #include	"gmain.h"
 /*#include	"misc.h"*/
+/*#include	"scene.h"*/
 /*#include	"turn.h"*/
 /*#include	"dun.h"*/
 /*#include	"town.h"*/
@@ -349,6 +425,7 @@
 #include	"fight.h"
 /*#include	"fx.h"*/
 /*#include	"trap.h"*/
+/*#include	"replay.h"*/
 #include	"draw.h"
 /*#include	"curs.h"*/
 /*#include	"menu.h"*/
@@ -359,6 +436,7 @@
 /*#include	"ver.h"*/
 #include	"gmain-prot.h"
 #include	"misc-prot.h"
+/*#include	"scene-prot.h"*/
 /*#include	"turn-prot.h"*/
 #include	"dun-prot.h"
 /*#include	"town-prot.h"*/
@@ -371,6 +449,7 @@
 #include	"fight-prot.h"
 #include	"fx-prot.h"
 #include	"trap-prot.h"
+/*#include	"replay-prot.h"*/
 #include	"draw-prot.h"
 #include	"curs-prot.h"
 /*#include	"menu-prot.h"*/
@@ -390,6 +469,7 @@
 
 #include	"gmain.h"
 /*#include	"misc.h"*/
+/*#include	"scene.h"*/
 #include	"turn.h"
 /*#include	"dun.h"*/
 /*#include	"town.h"*/
@@ -402,6 +482,7 @@
 /*#include	"fight.h"*/
 #include	"fx.h"
 /*#include	"trap.h"*/
+/*#include	"replay.h"*/
 #include	"draw.h"
 /*#include	"curs.h"*/
 /*#include	"menu.h"*/
@@ -412,6 +493,7 @@
 /*#include	"ver.h"*/
 #include	"gmain-prot.h"
 #include	"misc-prot.h"
+/*#include	"scene-prot.h"*/
 #include	"turn-prot.h"
 #include	"dun-prot.h"
 /*#include	"town-prot.h"*/
@@ -424,6 +506,7 @@
 #include	"fight-prot.h"
 #include	"fx-prot.h"
 #include	"trap-prot.h"
+/*#include	"replay-prot.h"*/
 #include	"draw-prot.h"
 #include	"curs-prot.h"
 #include	"menu-prot.h"
@@ -443,7 +526,9 @@
 
 #include	"gmain.h"
 /*#include	"misc.h"*/
+/*#include	"scene.h"*/
 #include	"turn.h"
+#include	"dun.h"
 #include	"town.h"
 #include	"item.h"
 #include	"spell.h"
@@ -454,6 +539,7 @@
 /*#include	"fight.h"*/
 #include	"fx.h"
 #include	"trap.h"
+#include	"replay.h"
 #include	"draw.h"
 #include	"curs.h"
 #include	"menu.h"
@@ -461,9 +547,10 @@
 #include	"request.h"
 #include	"gfile.h"
 #include	"msg.h"
-/*#include	"ver.h"*/
+#include	"ver.h"
 #include	"gmain-prot.h"
 #include	"misc-prot.h"
+/*#include	"scene-prot.h"*/
 #include	"turn-prot.h"
 #include	"dun-prot.h"
 #include	"town-prot.h"
@@ -476,6 +563,7 @@
 /*#include	"fight-prot.h"*/
 #include	"fx-prot.h"
 #include	"trap-prot.h"
+#include	"replay-prot.h"
 #include	"draw-prot.h"
 #include	"curs-prot.h"
 #include	"menu-prot.h"
@@ -487,6 +575,12 @@
 #include	"gfile-prot.h"
 #include	"msg-prot.h"
 
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+# include	"GraphConfToken.h"
+#endif
+
+#include	"call-prot.h"
+
 #endif	/* GFILE_C */
 
 /***************************************************************/
@@ -495,6 +589,7 @@
 
 #include	"gmain.h"
 #include	"misc.h"
+#include	"scene.h"
 #include	"turn.h"
 #include	"town.h"
 #include	"item.h"
@@ -506,6 +601,7 @@
 #include	"fight.h"
 #include	"fx.h"
 #include	"trap.h"
+#include	"replay.h"
 #include	"draw.h"
 #include	"curs.h"
 #include	"menu.h"
@@ -516,6 +612,7 @@
 #include	"ver.h"
 #include	"gmain-prot.h"
 #include	"misc-prot.h"
+#include	"scene-prot.h"
 #include	"turn-prot.h"
 #include	"dun-prot.h"
 #include	"town-prot.h"
@@ -528,6 +625,7 @@
 #include	"fight-prot.h"
 #include	"fx-prot.h"
 #include	"trap-prot.h"
+#include	"replay-prot.h"
 #include	"draw-prot.h"
 #include	"curs-prot.h"
 #include	"menu-prot.h"
@@ -553,6 +651,18 @@
 
 #include	"main-prot.h"
 
+#ifdef	D_GTK
+# include	"main-x-prot.h"
+#endif	/* D_GTK */
+
+#ifdef	D_WS
+# include	"main-x-prot.h"
+#endif	/* D_WS */
+
+#ifdef	D_MFC
+# include	"main-dows-prot.h"
+#endif	/* D_MFC */
+
 #include	"call-prot.h"
 
 #endif	/* GMAIN_C */
@@ -563,6 +673,7 @@
 
 #include	"gmain.h"
 #include	"misc.h"
+/*#include	"scene.h"*/
 #include	"turn.h"
 #include	"dun.h"
 #include	"town.h"
@@ -575,6 +686,7 @@
 /*#include	"fight.h"*/
 /*#include	"fx.h"*/
 #include	"trap.h"
+/*#include	"replay.h"*/
 #include	"draw.h"
 #include	"curs.h"
 #include	"menu.h"
@@ -585,6 +697,7 @@
 /*#include	"ver.h"*/
 #include	"gmain-prot.h"
 #include	"misc-prot.h"
+/*#include	"scene-prot.h"*/
 #include	"turn-prot.h"
 #include	"dun-prot.h"
 #include	"town-prot.h"
@@ -597,6 +710,7 @@
 /*#include	"fight-prot.h"*/
 /*#include	"fx-prot.h"*/
 #include	"trap-prot.h"
+/*#include	"replay-prot.h"*/
 #include	"draw-prot.h"
 #include	"curs-prot.h"
 #include	"menu-prot.h"
@@ -618,6 +732,7 @@
 
 #include	"gmain.h"
 /*#include	"misc.h"*/
+/*#include	"scene.h"*/
 /*#include	"turn.h"*/
 /*#include	"dun.h"*/
 /*#include	"town.h"*/
@@ -630,6 +745,7 @@
 /*#include	"fight.h"*/
 /*#include	"fx.h"*/
 /*#include	"trap.h"*/
+/*#include	"replay.h"*/
 #include	"draw.h"
 #include	"curs.h"
 /*#include	"menu.h"*/
@@ -640,6 +756,7 @@
 /*#include	"ver.h"*/
 #include	"gmain-prot.h"
 #include	"misc-prot.h"
+/*#include	"scene-prot.h"*/
 /*#include	"turn-prot.h"*/
 #include	"dun-prot.h"
 /*#include	"town-prot.h"*/
@@ -652,6 +769,7 @@
 /*#include	"fight-prot.h"*/
 #include	"fx-prot.h"
 #include	"trap-prot.h"
+/*#include	"replay-prot.h"*/
 #include	"draw-prot.h"
 #include	"curs-prot.h"
 /*#include	"menu-prot.h"*/
@@ -671,8 +789,8 @@
 
 #include	"gmain.h"
 /*#include	"misc.h"*/
+/*#include	"scene.h"*/
 /*#include	"turn.h"*/
-/*#include	"misc.h"*/
 /*#include	"dun.h"*/
 /*#include	"town.h"*/
 /*#include	"item.h"*/
@@ -684,6 +802,7 @@
 /*#include	"fight.h"*/
 /*#include	"fx.h"*/
 /*#include	"trap.h"*/
+/*#include	"replay.h"*/
 #include	"draw.h"
 #include	"curs.h"
 /*#include	"menu.h"*/
@@ -694,6 +813,7 @@
 #include	"ver.h"
 #include	"gmain-prot.h"
 /*#include	"misc-prot.h"*/
+/*#include	"scene-prot.h"*/
 /*#include	"turn-prot.h"*/
 /*#include	"dun-prot.h"*/
 /*#include	"town-prot.h"*/
@@ -706,6 +826,7 @@
 /*#include	"fight-prot.h"*/
 /*#include	"fx-prot.h"*/
 /*#include	"trap-prot.h"*/
+/*#include	"replay-prot.h"*/
 #include	"draw-prot.h"
 #include	"curs-prot.h"
 /*#include	"menu-prot.h"*/
@@ -727,8 +848,8 @@
 
 #include	"gmain.h"
 /*#include	"misc.h"*/
+/*#include	"scene.h"*/
 /*#include	"turn.h"*/
-/*#include	"misc.h"*/
 /*#include	"dun.h"*/
 /*#include	"town.h"*/
 /*#include	"item.h"*/
@@ -740,6 +861,7 @@
 /*#include	"fight.h"*/
 /*#include	"fx.h"*/
 /*#include	"trap.h"*/
+/*#include	"replay.h"*/
 #include	"draw.h"
 /*#include	"curs.h"*/
 /*#include	"menu.h"*/
@@ -750,6 +872,7 @@
 #include	"ver.h"
 #include	"gmain-prot.h"
 /*#include	"misc-prot.h"*/
+/*#include	"scene-prot.h"*/
 /*#include	"turn-prot.h"*/
 /*#include	"dun-prot.h"*/
 /*#include	"town-prot.h"*/
@@ -762,6 +885,7 @@
 /*#include	"fight-prot.h"*/
 /*#include	"fx-prot.h"*/
 /*#include	"trap-prot.h"*/
+/*#include	"replay-prot.h"*/
 #include	"draw-prot.h"
 /*#include	"curs-prot.h"*/
 /*#include	"menu-prot.h"*/
@@ -784,6 +908,7 @@
 
 #include	"gmain.h"
 #include	"misc.h"
+/*#include	"scene.h"*/
 /*#include	"turn.h"*/
 /*#include	"dun.h"*/
 /*#include	"town.h"*/
@@ -796,6 +921,7 @@
 /*#include	"fight.h"*/
 /*#include	"fx.h"*/
 /*#include	"trap.h"*/
+/*#include	"replay.h"*/
 #include	"draw.h"
 /*#include	"curs.h"*/
 #include	"menu.h"
@@ -806,6 +932,7 @@
 /*#include	"ver.h"*/
 /*#include	"gmain-prot.h"*/
 #include	"misc-prot.h"
+/*#include	"scene-prot.h"*/
 /*#include	"turn-prot.h"*/
 /*#include	"dun-prot.h"*/
 /*#include	"town-prot.h"*/
@@ -818,6 +945,7 @@
 /*#include	"fight-prot.h"*/
 /*#include	"fx-prot.h"*/
 /*#include	"trap-prot.h"*/
+/*#include	"replay-prot.h"*/
 #include	"draw-prot.h"
 /*#include	"curs-prot.h"*/
 #include	"menu-prot.h"
@@ -829,6 +957,9 @@
 /*#include	"gfile-prot.h"*/
 /*#include	"msg-prot.h"*/
 
+#include	"nest-flg.h"
+#include	"nest-flg-prot.h"
+
 #include	"call-prot.h"
 
 #endif	/* MENU_C */
@@ -839,6 +970,7 @@
 
 #include	"gmain.h"
 #include	"misc.h"
+/*#include	"scene.h"*/
 /*#include	"turn.h"*/
 /*#include	"dun.h"*/
 /*#include	"town.h"*/
@@ -851,6 +983,7 @@
 /*#include	"fight.h"*/
 /*#include	"fx.h"*/
 /*#include	"trap.h"*/
+/*#include	"replay.h"*/
 #include	"draw.h"
 /*#include	"curs.h"*/
 /*#include	"menu.h"*/
@@ -861,6 +994,7 @@
 /*#include	"ver.h"*/
 #include	"gmain-prot.h"
 #include	"misc-prot.h"
+/*#include	"scene-prot.h"*/
 /*#include	"turn-prot.h"*/
 /*#include	"dun-prot.h"*/
 /*#include	"town-prot.h"*/
@@ -873,6 +1007,7 @@
 /*#include	"fight-prot.h"*/
 /*#include	"fx-prot.h"*/
 /*#include	"trap-prot.h"*/
+/*#include	"replay-prot.h"*/
 #include	"draw-prot.h"
 /*#include	"curs-prot.h"*/
 /*#include	"menu-prot.h"*/
@@ -892,6 +1027,7 @@
 
 #include	"gmain.h"
 /*#include	"misc.h"*/
+/*#include	"scene.h"*/
 #include	"turn.h"
 /*#include	"dun.h"*/
 #include	"town.h"
@@ -904,6 +1040,7 @@
 /*#include	"fight.h"*/
 /*#include	"fx.h"*/
 /*#include	"trap.h"*/
+#include	"replay.h"
 #include	"draw.h"
 /*#include	"curs.h"*/
 #include	"menu.h"
@@ -914,6 +1051,7 @@
 /*#include	"ver.h"*/
 #include	"gmain-prot.h"
 #include	"misc-prot.h"
+/*#include	"scene-prot.h"*/
 #include	"turn-prot.h"
 #include	"dun-prot.h"
 #include	"town-prot.h"
@@ -926,6 +1064,7 @@
 /*#include	"fight-prot.h"*/
 #include	"fx-prot.h"
 #include	"trap-prot.h"
+#include	"replay-prot.h"
 #include	"draw-prot.h"
 #include	"curs-prot.h"
 #include	"menu-prot.h"
@@ -947,6 +1086,7 @@
 
 #include	"gmain.h"
 #include	"misc.h"
+/*#include	"scene.h"*/
 #include	"turn.h"
 #include	"dun.h"
 #include	"town.h"
@@ -959,6 +1099,7 @@
 /*#include	"fight.h"*/
 #include	"fx.h"
 /*#include	"trap.h"*/
+/*#include	"replay.h"*/
 #include	"draw.h"
 /*#include	"curs.h"*/
 /*#include	"menu.h"*/
@@ -969,6 +1110,7 @@
 /*#include	"ver.h"*/
 /*#include	"gmain-prot.h"*/
 #include	"misc-prot.h"
+/*#include	"scene-prot.h"*/
 #include	"turn-prot.h"
 #include	"dun-prot.h"
 #include	"town-prot.h"
@@ -982,6 +1124,7 @@
 /*#include	"fight-prot.h"*/
 #include	"fx-prot.h"
 /*#include	"trap-prot.h"*/
+/*#include	"replay-prot.h"*/
 #include	"draw-prot.h"
 /*#include	"curs-prot.h"*/
 /*#include	"menu-prot.h"*/
@@ -1001,6 +1144,7 @@
 
 #include	"gmain.h"
 /*#include	"misc.h"*/
+/*#include	"scene.h"*/
 /*#include	"turn.h"*/
 /*#include	"dun.h"*/
 /*#include	"town.h"*/
@@ -1013,6 +1157,7 @@
 /*#include	"fight.h"*/
 /*#include	"fx.h"*/
 #include	"trap.h"
+/*#include	"replay.h"*/
 #include	"draw.h"
 #include	"curs.h"
 /*#include	"menu.h"*/
@@ -1023,6 +1168,7 @@
 /*#include	"ver.h"*/
 #include	"gmain-prot.h"
 #include	"misc-prot.h"
+/*#include	"scene-prot.h"*/
 /*#include	"turn-prot.h"*/
 #include	"dun-prot.h"
 /*#include	"town-prot.h"*/
@@ -1035,6 +1181,7 @@
 #include	"fight-prot.h"
 #include	"fx-prot.h"
 #include	"trap-prot.h"
+/*#include	"replay-prot.h"*/
 #include	"draw-prot.h"
 #include	"curs-prot.h"
 /*#include	"menu-prot.h"*/
@@ -1054,6 +1201,7 @@
 
 #include	"gmain.h"
 /*#include	"misc.h"*/
+/*#include	"scene.h"*/
 /*#include	"turn.h"*/
 /*#include	"dun.h"*/
 /*#include	"town.h"*/
@@ -1066,6 +1214,7 @@
 /*#include	"fight.h"*/
 /*#include	"fx.h"*/
 /*#include	"trap.h"*/
+/*#include	"replay.h"*/
 #include	"draw.h"
 /*#include	"curs.h"*/
 /*#include	"menu.h"*/
@@ -1076,6 +1225,7 @@
 /*#include	"ver.h"*/
 #include	"gmain-prot.h"
 /*#include	"misc-prot.h"*/
+/*#include	"scene-prot.h"*/
 /*#include	"turn-prot.h"*/
 /*#include	"dun-prot.h"*/
 /*#include	"town-prot.h"*/
@@ -1088,6 +1238,7 @@
 /*#include	"fight-prot.h"*/
 /*#include	"fx-prot.h"*/
 /*#include	"trap-prot.h"*/
+/*#include	"replay-prot.h"*/
 #include	"draw-prot.h"
 /*#include	"curs-prot.h"*/
 /*#include	"menu-prot.h"*/
@@ -1107,6 +1258,7 @@
 
 #include	"gmain.h"
 /*#include	"misc.h"*/
+/*#include	"scene.h"*/
 /*#include	"turn.h"*/
 /*#include	"dun.h"*/
 #include	"town.h"
@@ -1119,6 +1271,7 @@
 /*#include	"fight.h"*/
 /*#include	"fx.h"*/
 /*#include	"trap.h"*/
+/*#include	"replay.h"*/
 #include	"draw.h"
 /*#include	"curs.h"*/
 #include	"menu.h"
@@ -1129,6 +1282,7 @@
 /*#include	"ver.h"*/
 #include	"gmain-prot.h"
 #include	"misc-prot.h"
+/*#include	"scene-prot.h"*/
 /*#include	"turn-prot.h"*/
 #include	"dun-prot.h"
 #include	"town-prot.h"
@@ -1141,6 +1295,7 @@
 #include	"fight-prot.h"
 #include	"fx-prot.h"
 #include	"trap-prot.h"
+/*#include	"replay-prot.h"*/
 #include	"draw-prot.h"
 #include	"curs-prot.h"
 #include	"menu-prot.h"
@@ -1160,6 +1315,7 @@
 
 #include	"gmain.h"
 #include	"misc.h"
+/*#include	"scene.h"*/
 /*#include	"turn.h"*/
 #include	"dun.h"
 /*#include	"town.h"*/
@@ -1172,6 +1328,7 @@
 /*#include	"fight.h"*/
 #include	"fx.h"
 #include	"trap.h"
+/*#include	"replay.h"*/
 #include	"draw.h"
 /*#include	"curs.h"*/
 /*#include	"menu.h"*/
@@ -1182,6 +1339,7 @@
 /*#include	"ver.h"*/
 #include	"gmain-prot.h"
 #include	"misc-prot.h"
+/*#include	"scene-prot.h"*/
 /*#include	"turn-prot.h"*/
 #include	"dun-prot.h"
 /*#include	"town-prot.h"*/
@@ -1195,6 +1353,7 @@
 /*#include	"fight-prot.h"*/
 #include	"fx-prot.h"
 #include	"trap-prot.h"
+/*#include	"replay-prot.h"*/
 #include	"draw-prot.h"
 /*#include	"curs-prot.h"*/
 /*#include	"menu-prot.h"*/
@@ -1214,6 +1373,7 @@
 
 #include	"gmain.h"
 #include	"misc.h"
+/*#include	"scene.h"*/
 #include	"turn.h"
 #include	"dun.h"
 /*#include	"town.h"*/
@@ -1226,6 +1386,7 @@
 /*#include	"fight.h"*/
 #include	"fx.h"
 /*#include	"trap.h"*/
+/*#include	"replay.h"*/
 #include	"draw.h"
 #include	"curs.h"
 #include	"menu.h"
@@ -1236,6 +1397,7 @@
 /*#include	"ver.h"*/
 /*#include	"gmain-prot.h"*/
 #include	"misc-prot.h"
+/*#include	"scene-prot.h"*/
 #include	"turn-prot.h"
 #include	"dun-prot.h"
 /*#include	"town-prot.h"*/
@@ -1248,6 +1410,7 @@
 /*#include	"fight-prot.h"*/
 #include	"fx-prot.h"
 /*#include	"trap-prot.h"*/
+/*#include	"replay-prot.h"*/
 #include	"draw-prot.h"
 #include	"curs-prot.h"
 #include	"menu-prot.h"
@@ -1267,6 +1430,7 @@
 
 #include	"gmain.h"
 /*#include	"misc.h"*/
+/*#include	"scene.h"*/
 /*#include	"turn.h"*/
 /*#include	"dun.h"*/
 /*#include	"town.h"*/
@@ -1279,6 +1443,7 @@
 /*#include	"fight.h"*/
 /*#include	"fx.h"*/
 /*#include	"trap.h"*/
+/*#include	"replay.h"*/
 #include	"draw.h"
 #include	"curs.h"
 #include	"menu.h"
@@ -1289,6 +1454,7 @@
 /*#include	"ver.h"*/
 #include	"gmain-prot.h"
 #include	"misc-prot.h"
+/*#include	"scene-prot.h"*/
 /*#include	"turn-prot.h"*/
 #include	"dun-prot.h"
 /*#include	"town-prot.h"*/
@@ -1301,6 +1467,7 @@
 /*#include	"fight-prot.h"*/
 #include	"fx-prot.h"
 #include	"trap-prot.h"
+/*#include	"replay-prot.h"*/
 #include	"draw-prot.h"
 #include	"curs-prot.h"
 #include	"menu-prot.h"
@@ -1320,6 +1487,7 @@
 
 #include	"gmain.h"
 /*#include	"misc.h"*/
+/*#include	"scene.h"*/
 #include	"turn.h"
 /*#include	"dun.h"*/
 #include	"town.h"
@@ -1332,6 +1500,7 @@
 /*#include	"fight.h"*/
 /*#include	"fx.h"*/
 /*#include	"trap.h"*/
+/*#include	"replay.h"*/
 #include	"draw.h"
 #include	"curs.h"
 #include	"menu.h"
@@ -1342,6 +1511,7 @@
 /*#include	"ver.h"*/
 #include	"gmain-prot.h"
 #include	"misc-prot.h"
+/*#include	"scene-prot.h"*/
 #include	"turn-prot.h"
 #include	"dun-prot.h"
 #include	"town-prot.h"
@@ -1354,13 +1524,14 @@
 /*#include	"fight-prot.h"*/
 #include	"fx-prot.h"
 /*#include	"trap-prot.h"*/
+/*#include	"replay-prot.h"*/
 #include	"draw-prot.h"
 #include	"curs-prot.h"
 #include	"menu-prot.h"
 #include	"mmenu-prot.h"
 #include	"imenu-prot.h"
 /*#include	"tmenu-prot.h"*/
-/*#include	"amenu-prot.h"*/
+#include	"amenu-prot.h"
 /*#include	"request-prot.h"*/
 #include	"gfile-prot.h"
 /*#include	"msg-prot.h"*/
@@ -1373,6 +1544,7 @@
 
 #include	"gmain.h"
 /*#include	"misc.h"*/
+/*#include	"scene.h"*/
 #include	"turn.h"
 /*#include	"dun.h"*/
 #include	"town.h"
@@ -1385,6 +1557,7 @@
 /*#include	"fight.h"*/
 /*#include	"fx.h"*/
 /*#include	"trap.h"*/
+/*#include	"replay.h"*/
 #include	"draw.h"
 /*#include	"curs.h"*/
 #include	"menu.h"
@@ -1395,6 +1568,7 @@
 /*#include	"ver.h"*/
 #include	"gmain-prot.h"
 #include	"misc-prot.h"
+/*#include	"scene-prot.h"*/
 #include	"turn-prot.h"
 #include	"dun-prot.h"
 #include	"town-prot.h"
@@ -1407,6 +1581,7 @@
 /*#include	"fight-prot.h"*/
 #include	"fx-prot.h"
 /*#include	"trap-prot.h"*/
+/*#include	"replay-prot.h"*/
 #include	"draw-prot.h"
 /*#include	"curs-prot.h"*/
 #include	"menu-prot.h"
@@ -1426,6 +1601,7 @@
 
 #include	"gmain.h"
 /*#include	"misc.h"*/
+/*#include	"scene.h"*/
 /*#include	"turn.h"*/
 #include	"dun.h"
 /*#include	"town.h"*/
@@ -1438,6 +1614,7 @@
 #include	"fight.h"
 #include	"fx.h"
 #include	"trap.h"
+/*#include	"replay.h"*/
 #include	"draw.h"
 #include	"curs.h"
 #include	"menu.h"
@@ -1448,6 +1625,7 @@
 /*#include	"ver.h"*/
 #include	"gmain-prot.h"
 #include	"misc-prot.h"
+/*#include	"scene-prot.h"*/
 /*#include	"turn-prot.h"*/
 #include	"dun-prot.h"
 /*#include	"town-prot.h"*/
@@ -1460,6 +1638,7 @@
 #include	"fight-prot.h"
 #include	"fx-prot.h"
 #include	"trap-prot.h"
+/*#include	"replay-prot.h"*/
 #include	"draw-prot.h"
 #include	"curs-prot.h"
 #include	"menu-prot.h"
@@ -1479,6 +1658,7 @@
 
 #include	"gmain.h"
 #include	"misc.h"
+/*#include	"scene.h"*/
 #include	"turn.h"
 /*#include	"dun.h"*/
 #include	"town.h"
@@ -1491,6 +1671,7 @@
 /*#include	"fight.h"*/
 #include	"fx.h"
 /*#include	"trap.h"*/
+/*#include	"replay.h"*/
 #include	"draw.h"
 /*#include	"curs.h"*/
 #include	"menu.h"
@@ -1501,6 +1682,7 @@
 /*#include	"ver.h"*/
 /*#include	"gmain-prot.h"*/
 #include	"misc-prot.h"
+/*#include	"scene-prot.h"*/
 #include	"turn-prot.h"
 /*#include	"dun-prot.h"*/
 #include	"town-prot.h"
@@ -1513,6 +1695,7 @@
 /*#include	"fight-prot.h"*/
 #include	"fx-prot.h"
 /*#include	"trap-prot.h"*/
+/*#include	"replay-prot.h"*/
 #include	"draw-prot.h"
 /*#include	"curs-prot.h"*/
 /*#include	"menu-prot.h"*/
@@ -1526,14 +1709,13 @@
 
 #endif	/* TURN_C */
 
-/***************************************************************
-* xlnl
-***************************************************************/
+/***************************************************************/
 
-#ifdef	MAIN_X_C
+#ifdef	SCENE_C
 
 #include	"gmain.h"
 /*#include	"misc.h"*/
+#include	"scene.h"
 /*#include	"turn.h"*/
 /*#include	"dun.h"*/
 /*#include	"town.h"*/
@@ -1546,16 +1728,18 @@
 /*#include	"fight.h"*/
 /*#include	"fx.h"*/
 /*#include	"trap.h"*/
-#include	"draw.h"
+/*#include	"replay.h"*/
+/*#include	"draw.h"*/
 /*#include	"curs.h"*/
 /*#include	"menu.h"*/
 /*#include	"amenu.h"*/
 /*#include	"request.h"*/
 /*#include	"gfile.h"*/
-#include	"msg.h"
-#include	"ver.h"
-#include	"gmain-prot.h"
+/*#include	"msg.h"*/
+/*#include	"ver.h"*/
+/*#include	"gmain-prot.h"*/
 /*#include	"misc-prot.h"*/
+#include	"scene-prot.h"
 /*#include	"turn-prot.h"*/
 /*#include	"dun-prot.h"*/
 /*#include	"town-prot.h"*/
@@ -1568,6 +1752,66 @@
 /*#include	"fight-prot.h"*/
 /*#include	"fx-prot.h"*/
 /*#include	"trap-prot.h"*/
+/*#include	"replay-prot.h"*/
+/*#include	"draw-prot.h"*/
+/*#include	"curs-prot.h"*/
+/*#include	"menu-prot.h"*/
+/*#include	"mmenu-prot.h"*/
+/*#include	"imenu-prot.h"*/
+/*#include	"tmenu-prot.h"*/
+/*#include	"amenu-prot.h"*/
+/*#include	"request-prot.h"*/
+/*#include	"gfile-prot.h"*/
+/*#include	"msg-prot.h"*/
+
+#endif	/* SCENE_C */
+
+/***************************************************************
+* xlnl
+***************************************************************/
+
+#ifdef	MAIN_X_C
+
+#include	"gmain.h"
+/*#include	"misc.h"*/
+/*#include	"scene.h"*/
+/*#include	"turn.h"*/
+/*#include	"dun.h"*/
+/*#include	"town.h"*/
+/*#include	"item.h"*/
+/*#include	"spell.h"*/
+/*#include	"chr.h"*/
+/*#include	"party.h"*/
+/*#include	"mnstr.h"*/
+/*#include	"pet.h"*/
+/*#include	"fight.h"*/
+/*#include	"fx.h"*/
+/*#include	"trap.h"*/
+/*#include	"replay.h"*/
+#include	"draw.h"
+/*#include	"curs.h"*/
+/*#include	"menu.h"*/
+/*#include	"amenu.h"*/
+/*#include	"request.h"*/
+/*#include	"gfile.h"*/
+#include	"msg.h"
+#include	"ver.h"
+#include	"gmain-prot.h"
+/*#include	"misc-prot.h"*/
+/*#include	"scene-prot.h"*/
+/*#include	"turn-prot.h"*/
+/*#include	"dun-prot.h"*/
+/*#include	"town-prot.h"*/
+/*#include	"item-prot.h"*/
+/*#include	"spell-prot.h"*/
+/*#include	"chr-prot.h"*/
+/*#include	"party-prot.h"*/
+/*#include	"mnstr-prot.h"*/
+/*#include	"pet-prot.h"*/
+/*#include	"fight-prot.h"*/
+/*#include	"fx-prot.h"*/
+/*#include	"trap-prot.h"*/
+/*#include	"replay-prot.h"*/
 #include	"draw-prot.h"
 /*#include	"curs-prot.h"*/
 /*#include	"menu-prot.h"*/
@@ -1582,14 +1826,17 @@
 #include	"main-x-prot.h"
 #include	"call-prot.h"
 
+#include	<gtk/gtk.h>
+
 #endif	/* MAIN_X_C */
 
 /***************************************************************/
 
-#ifdef	MAIN_WIN_C
+#ifdef	MAIN_DOWS_CPP
 
 #include	"gmain.h"
 /*#include	"misc.h"*/
+#include	"scene.h"
 /*#include	"turn.h"*/
 /*#include	"dun.h"*/
 /*#include	"town.h"*/
@@ -1602,9 +1849,10 @@
 /*#include	"fight.h"*/
 /*#include	"fx.h"*/
 /*#include	"trap.h"*/
+/*#include	"replay.h"*/
 #include	"draw.h"
 /*#include	"curs.h"*/
-/*#include	"menu.h"*/
+#include	"menu.h"
 /*#include	"amenu.h"*/
 /*#include	"request.h"*/
 /*#include	"gfile.h"*/
@@ -1612,6 +1860,7 @@
 #include	"ver.h"
 #include	"gmain-prot.h"
 /*#include	"misc-prot.h"*/
+#include	"scene-prot.h"
 /*#include	"turn-prot.h"*/
 /*#include	"dun-prot.h"*/
 /*#include	"town-prot.h"*/
@@ -1624,21 +1873,29 @@
 /*#include	"fight-prot.h"*/
 /*#include	"fx-prot.h"*/
 /*#include	"trap-prot.h"*/
-#include	"draw-prot.h"
+/*#include	"replay-prot.h"*/
+/*#include	"draw-prot.h"*/
 /*#include	"curs-prot.h"*/
 /*#include	"menu-prot.h"*/
 /*#include	"mmenu-prot.h"*/
-/*#include	"imenu-prot.h"*/
+#include	"imenu-prot.h"
 /*#include	"tmenu-prot.h"*/
 /*#include	"amenu-prot.h"*/
 /*#include	"request-prot.h"*/
 /*#include	"gfile-prot.h"*/
 /*#include	"msg-prot.h"*/
 
-#include	"main-win-prot.h"
+#include	"MouseMap.h"
+#include	"GlobalVar.h"
+
+#include	"main-dows-prot.h"
 #include	"call-prot.h"
 
-#endif	/* MAIN_WIN_C */
+#include	"xlnl-dows/stdafx.h"
+#include	"xlnl-dows/xlnl-dows.h"
+#include	"xlnl-dows/MainFrm.h"
+
+#endif	/* MAIN_DOWS_CPP */
 
 /***************************************************************/
 
@@ -1646,18 +1903,20 @@
 
 #include	"gmain.h"
 /*#include	"misc.h"*/
+#include	"scene.h"
 /*#include	"turn.h"*/
 /*#include	"dun.h"*/
 /*#include	"town.h"*/
 /*#include	"item.h"*/
 /*#include	"spell.h"*/
-/*#include	"chr.h"*/
+#include	"chr.h"
 /*#include	"party.h"*/
 /*#include	"mnstr.h"*/
 /*#include	"pet.h"*/
 /*#include	"fight.h"*/
 /*#include	"fx.h"*/
 /*#include	"trap.h"*/
+/*#include	"replay.h"*/
 #include	"draw.h"
 /*#include	"curs.h"*/
 #include	"menu.h"
@@ -1668,6 +1927,7 @@
 /*#include	"ver.h"*/
 #include	"gmain-prot.h"
 /*#include	"misc-prot.h"*/
+#include	"scene-prot.h"
 /*#include	"turn-prot.h"*/
 /*#include	"dun-prot.h"*/
 /*#include	"town-prot.h"*/
@@ -1680,7 +1940,8 @@
 /*#include	"fight-prot.h"*/
 /*#include	"fx-prot.h"*/
 /*#include	"trap-prot.h"*/
-#include	"draw-prot.h"
+/*#include	"replay-prot.h"*/
+/*#include	"draw-prot.h"*/
 /*#include	"curs-prot.h"*/
 /*#include	"menu-prot.h"*/
 /*#include	"mmenu-prot.h"*/
@@ -1694,14 +1955,14 @@
 #include	<gtk/gtk.h>
 #include	<gdk-pixbuf/gdk-pixbuf.h>
 
+#include	"MouseMap.h"
+#include	"GraphConf.h"
+#include	"GlobalVar.h"
+
 #include	"main-x-prot.h"
 #include	"main-gtk-prot.h"
 #include	"call-prot.h"
 
-#include	"MouseMap.h"
-
-#include	"GlobalVar.h"
-
 #endif	/* MAIN_GTK_CPP */
 
 /***************************************************************/
@@ -1718,11 +1979,11 @@
 #  include "GameThread.h"
 #  include "GuiMenu.h"
 #  include "PcgDun.h"
+#  include "GraphConfToken.h"
 #  include "GlobalVar.h"
 #  include "gmain-prot.h"
 #  include "chr-prot.h"
 #  include "draw-prot.h"
-#  include "call-prot.h"
 # elif	defined( D_GTK )
 #  include "gmain.h"
 #  include "misc.h"
@@ -1731,31 +1992,46 @@
 #  include "GameThread.h"
 #  include "GuiMenu.h"
 #  include "PcgDun.h"
+#  include "GraphConfToken.h"
+#  include "GlobalVar.h"
+#  include "gmain-prot.h"
+#  include "chr-prot.h"
+#  include "draw-prot.h"
+# elif	defined( D_MFC )
+#  include "gmain.h"
+#  include "misc.h"
+#  include "chr.h"
+#  include "draw.h"
+#  include "GameThread.h"
+#  include "GuiMenu.h"
+#  include "PcgDun.h"
+#  include "GraphConfToken.h"
 #  include "GlobalVar.h"
 #  include "gmain-prot.h"
 #  include "chr-prot.h"
 #  include "draw-prot.h"
-#  include "call-prot.h"
 # else
 #  include "gmain.h"
 #  include "misc.h"
 #  include "chr.h"
 #  include "draw.h"
 #  include "chr-prot.h"
-#  include "call-prot.h"
 # endif
 
+# include "call-prot.h"
+
 #endif	/* CALL_CPP */
 
 /***************************************************************/
 
-#ifdef	GUI_MESSAGE_CPP
+#ifdef	SEL_CONF_CPP
 
 #include	"gmain.h"
-#include	"misc.h"
+/*#include	"misc.h"*/
+/*#include	"scene.h"*/
 /*#include	"turn.h"*/
 /*#include	"dun.h"*/
-/*#include	"town.h"*/
+#include	"town.h"
 /*#include	"item.h"*/
 /*#include	"spell.h"*/
 /*#include	"chr.h"*/
@@ -1765,16 +2041,18 @@
 /*#include	"fight.h"*/
 /*#include	"fx.h"*/
 /*#include	"trap.h"*/
+/*#include	"replay.h"*/
 #include	"draw.h"
-#include	"curs.h"
-/*#include	"menu.h"*/
-/*#include	"amenu.h"*/
+/*#include	"curs.h"*/
+#include	"menu.h"
+#include	"amenu.h"
 /*#include	"request.h"*/
-/*#include	"gfile.h"*/
+#include	"gfile.h"
 /*#include	"msg.h"*/
 /*#include	"ver.h"*/
-#include	"gmain-prot.h"
+/*#include	"gmain-prot.h"*/
 /*#include	"misc-prot.h"*/
+/*#include	"scene-prot.h"*/
 /*#include	"turn-prot.h"*/
 /*#include	"dun-prot.h"*/
 /*#include	"town-prot.h"*/
@@ -1787,6 +2065,97 @@
 /*#include	"fight-prot.h"*/
 /*#include	"fx-prot.h"*/
 /*#include	"trap-prot.h"*/
+/*#include	"replay-prot.h"*/
+/*#include	"draw-prot.h"*/
+/*#include	"curs-prot.h"*/
+/*#include	"menu-prot.h"*/
+/*#include	"mmenu-prot.h"*/
+/*#include	"imenu-prot.h"*/
+/*#include	"tmenu-prot.h"*/
+/*#include	"amenu-prot.h"*/
+/*#include	"request-prot.h"*/
+#include	"gfile-prot.h"
+/*#include	"msg-prot.h"*/
+
+#include	"GraphConf.h"
+
+#ifdef D_WS
+# include <WSCwindow.h>
+# include <WSCbase.h>
+# include <WSCvbtn.h>
+# include <WSDmouse.h>
+#endif /* D_WS */
+
+#ifdef D_GTK
+# include <gtk/gtk.h>
+# include <gdk/gdk.h>
+# include "main-gtk-prot.h"
+#endif /* D_GTK */
+
+#include "SelConf.h"
+#include "GlobalVar.h"
+
+#ifdef D_MFC
+# include "xlnl-dows/stdafx.h"
+# include "xlnl-dows/SelConfDlg.h"
+# include "main-dows-prot.h"
+#endif /* D_MFC */
+
+#endif	/* SEL_CONF_CPP */
+
+/***************************************************************/
+
+#ifdef	GRAPH_CONF_CPP
+
+#include	"GraphConf.h"
+#include	"GlobalVar.h"
+
+#endif	/* GRAPH_CONF_CPP */
+
+/***************************************************************/
+
+#ifdef	GUI_MESSAGE_CPP
+
+#include	"gmain.h"
+#include	"misc.h"
+/*#include	"scene.h"*/
+/*#include	"turn.h"*/
+/*#include	"dun.h"*/
+/*#include	"town.h"*/
+/*#include	"item.h"*/
+/*#include	"spell.h"*/
+/*#include	"chr.h"*/
+/*#include	"party.h"*/
+/*#include	"mnstr.h"*/
+/*#include	"pet.h"*/
+/*#include	"fight.h"*/
+/*#include	"fx.h"*/
+/*#include	"trap.h"*/
+/*#include	"replay.h"*/
+#include	"draw.h"
+#include	"curs.h"
+/*#include	"menu.h"*/
+/*#include	"amenu.h"*/
+/*#include	"request.h"*/
+/*#include	"gfile.h"*/
+/*#include	"msg.h"*/
+/*#include	"ver.h"*/
+#include	"gmain-prot.h"
+/*#include	"misc-prot.h"*/
+/*#include	"scene-prot.h"*/
+/*#include	"turn-prot.h"*/
+/*#include	"dun-prot.h"*/
+/*#include	"town-prot.h"*/
+/*#include	"item-prot.h"*/
+/*#include	"spell-prot.h"*/
+/*#include	"chr-prot.h"*/
+/*#include	"party-prot.h"*/
+/*#include	"mnstr-prot.h"*/
+/*#include	"pet-prot.h"*/
+/*#include	"fight-prot.h"*/
+/*#include	"fx-prot.h"*/
+/*#include	"trap-prot.h"*/
+/*#include	"replay-prot.h"*/
 #include	"draw-prot.h"
 #include	"curs-prot.h"
 /*#include	"menu-prot.h"*/
@@ -1799,21 +2168,96 @@
 /*#include	"msg-prot.h"*/
 
 #ifdef D_WS
-#endif // D_WS
+#endif /* D_WS */
 
 #ifdef D_GTK
 # include <gtk/gtk.h>
 # include "GuiMisc.h"
-#endif // D_GTK
+#endif /* D_GTK */
+
+#ifdef D_MFC
+# include "xlnl-dows/stdafx.h"
+# include "GuiMisc.h"
+#endif /* D_MFC */
 
 #endif	/* GUI_MESSAGE_CPP */
 
 /***************************************************************/
 
+#ifdef	GUI_STAT_CPP
+
+#include	"gmain.h"
+#include	"misc.h"
+/*#include	"scene.h"*/
+/*#include	"turn.h"*/
+/*#include	"dun.h"*/
+/*#include	"town.h"*/
+/*#include	"item.h"*/
+/*#include	"spell.h"*/
+/*#include	"chr.h"*/
+#include	"party.h"
+/*#include	"mnstr.h"*/
+/*#include	"pet.h"*/
+/*#include	"fight.h"*/
+/*#include	"fx.h"*/
+/*#include	"trap.h"*/
+#include	"draw.h"
+/*#include	"curs.h"*/
+/*#include	"menu.h"*/
+/*#include	"amenu.h"*/
+/*#include	"request.h"*/
+/*#include	"gfile.h"*/
+#include	"msg.h"
+/*#include	"ver.h"*/
+#include	"gmain-prot.h"
+#include	"misc-prot.h"
+/*#include	"scene-prot.h"*/
+/*#include	"turn-prot.h"*/
+/*#include	"dun-prot.h"*/
+/*#include	"town-prot.h"*/
+/*#include	"item-prot.h"*/
+/*#include	"spell-prot.h"*/
+/*#include	"chr-prot.h"*/
+#include	"party-prot.h"
+/*#include	"mnstr-prot.h"*/
+/*#include	"pet-prot.h"*/
+/*#include	"fight-prot.h"*/
+/*#include	"fx-prot.h"*/
+/*#include	"trap-prot.h"*/
+#include	"draw-prot.h"
+/*#include	"curs-prot.h"*/
+/*#include	"menu-prot.h"*/
+/*#include	"tmenu-prot.h"*/
+/*#include	"amenu-prot.h"*/
+/*#include	"request-prot.h"*/
+/*#include	"gfile-prot.h"*/
+/*#include	"msg-prot.h"*/
+
+#ifdef D_GTK
+# include <gtk/gtk.h>
+# include <gdk/gdk.h>
+#endif /* D_GTK */
+
+#ifdef D_MFC
+# include "xlnl-dows/StatWnd.h"
+#endif /* D_MFC */
+
+#include "GuiStat.h"
+#include "GlobalVar.h"
+
+#ifdef D_GTK
+#include "main-gtk-prot.h"
+#endif /* D_GTK */
+
+#endif	/* GUI_STAT_CPP */
+
+/***************************************************************/
+
 #ifdef	GUI_NUM_CPP
 
 #include	"gmain.h"
 #include	"misc.h"
+/*#include	"scene.h"*/
 /*#include	"turn.h"*/
 /*#include	"dun.h"*/
 /*#include	"town.h"*/
@@ -1826,6 +2270,7 @@
 /*#include	"fight.h"*/
 /*#include	"fx.h"*/
 /*#include	"trap.h"*/
+/*#include	"replay.h"*/
 #include	"draw.h"
 /*#include	"curs.h"*/
 /*#include	"menu.h"*/
@@ -1836,6 +2281,7 @@
 /*#include	"ver.h"*/
 /*#include	"gmain-prot.h"*/
 #include	"misc-prot.h"
+/*#include	"scene-prot.h"*/
 /*#include	"turn-prot.h"*/
 /*#include	"dun-prot.h"*/
 /*#include	"town-prot.h"*/
@@ -1848,6 +2294,7 @@
 /*#include	"fight-prot.h"*/
 /*#include	"fx-prot.h"*/
 /*#include	"trap-prot.h"*/
+/*#include	"replay-prot.h"*/
 #include	"draw-prot.h"
 /*#include	"curs-prot.h"*/
 /*#include	"menu-prot.h"*/
@@ -1860,12 +2307,12 @@
 /*#include	"msg-prot.h"*/
 
 #ifdef D_WS
-#endif // D_WS
+#endif /* D_WS */
 
 #ifdef D_GTK
 # include <gtk/gtk.h>
 # include "GuiMisc.h"
-#endif // D_GTK
+#endif /* D_GTK */
 
 #endif	/* GUI_NUM_CPP */
 
@@ -1875,6 +2322,7 @@
 
 #include	"gmain.h"
 #include	"misc.h"
+/*#include	"scene.h"*/
 /*#include	"turn.h"*/
 /*#include	"dun.h"*/
 /*#include	"town.h"*/
@@ -1887,6 +2335,7 @@
 /*#include	"fight.h"*/
 /*#include	"fx.h"*/
 /*#include	"trap.h"*/
+/*#include	"replay.h"*/
 #include	"draw.h"
 /*#include	"curs.h"*/
 /*#include	"menu.h"*/
@@ -1897,6 +2346,7 @@
 /*#include	"ver.h"*/
 /*#include	"gmain-prot.h"*/
 /*#include	"misc-prot.h"*/
+/*#include	"scene-prot.h"*/
 /*#include	"turn-prot.h"*/
 /*#include	"dun-prot.h"*/
 /*#include	"town-prot.h"*/
@@ -1909,6 +2359,7 @@
 /*#include	"fight-prot.h"*/
 /*#include	"fx-prot.h"*/
 /*#include	"trap-prot.h"*/
+/*#include	"replay-prot.h"*/
 #include	"draw-prot.h"
 /*#include	"curs-prot.h"*/
 /*#include	"menu-prot.h"*/
@@ -1921,32 +2372,37 @@
 /*#include	"msg-prot.h"*/
 
 #ifdef D_WS
-//@@@
-//# include <WScom.h>
-//# include <WSDappDev.h>
-//# include <WSCmainWindow.h>
-//# include <WSCfunctionList.h>
-//# include <WSCbase.h>
-//# include <WSCwindow.h>
 # include <WSCvifield.h>
-#endif // D_WS
+# include "MapWin.h"
+#endif /* D_WS */
 
 #ifdef D_GTK
 # include <gtk/gtk.h>
 # include "GuiMisc.h"
-#endif // D_GTK
+#endif /* D_GTK */
+
+#include "GuiInputString.h"
+#include "GlobalVar.h"
+
+#ifdef D_MFC
+# include "xlnl-dows/InputLineDlg.h"
+#endif // D_MFC
 
 #endif	/* GUI_INPUT_STRING_CPP */
 
 /***************************************************************/
 
-#if	defined( D_WIN )
-# include	"main-win-prot.h"
+#if 0
+#if	defined( D_WS )
+# include	"main-ws-prot.h"
+#elif	defined( D_DOWS )
+# include	"main-dows-prot.h"
 #elif	defined( D_DOS )
 # include	"main-dos-prot.h"
 #else
 # include	"main-unix-prot.h"
 #endif
+#endif
 
 /***************************************************************/
 
