@@ -6,14 +6,20 @@ extern "C" {
 
 int	main( int argc, char **argv );
 void	init_gtk_win( int argc, char **argv );
+void	init_main_sel_conf( GraphConf *cnf );
+void	init_main_win( void );
 gint	handle_delete(
 	GtkWidget *widget, GdkEvent *event, gpointer user_data
 );
 void	handle_destroy(
 	GtkWidget *widget, gpointer user_data
 );
-gint	handle_map_expose( GtkWidget *widget, GdkEventExpose *event );
-gint	handle_map_configure( GtkWidget *widget, GdkEventConfigure *event );
+gint	handle_map_expose(
+	GtkWidget *widget, GdkEventExpose *event
+);
+gint	handle_map_configure(
+	GtkWidget *widget, GdkEventConfigure *event
+);
 void	handle_map_scroll_changed(
 	GtkAdjustment *adjustment,
 	gpointer user_data
@@ -35,6 +41,9 @@ gint	handle_map_button_press(
 gint	handle_map_button_release(
 	GtkWidget *widget, GdkEventMotion *event
 );
+gint	handle_map_scroll(
+	GtkWidget *widget, GdkEventScroll *event
+);
 void	showWin(
 	GtkWidget *mMenuWin,
 	gint *nPreX, gint *nPreY,
