@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: main-gtk.cpp,v 1.23 2007/02/26 00:50:37 bowkenken Exp $
+* $Id: main-gtk.cpp,v 1.32 2007/12/16 02:09:34 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -37,14 +37,16 @@
 
 ////////////////////////////////////////////////////////////////
 
-#define	TILE_X_SIZE	(gPcgDun.getTileSizeX())
-#define	TILE_Y_SIZE	(gPcgDun.getTileSizeY())
+#define	TILE_X_SIZE()	(gPcgDun.getTileSizeX( true ))
+#define	TILE_Y_SIZE()	(gPcgDun.getTileSizeY( true ))
 
-#define	MAP_PIX_MAX_X	(MAP_MAX_X * TILE_X_SIZE)
-#define	MAP_PIX_MAX_Y	(MAP_MAX_Y * TILE_Y_SIZE)
+#define	MAP_PIX_MAX_X()	(MAP_MAX_X * TILE_X_SIZE())
+#define	MAP_PIX_MAX_Y()	(MAP_MAX_Y * TILE_Y_SIZE())
 
-#define	MAP_WIN_INIT_WIDTH	(20 * TILE_X_SIZE)
-#define	MAP_WIN_INIT_HEIGHT	(20 * TILE_Y_SIZE)
+#define	MAP_WIN_INIT_WIDTH()	(20 * TILE_X_SIZE())
+#define	MAP_WIN_INIT_HEIGHT()	(20 * TILE_Y_SIZE())
+#define	MAP_WIN_MIN_WIDTH()	(1 * TILE_X_SIZE())
+#define	MAP_WIN_MIN_HEIGHT()	(1 * TILE_Y_SIZE())
 
 ////////////////////////////////////////////////////////////////
 
@@ -75,30 +77,26 @@ int	main( int argc, char **argv )
 
 	chk_arg( argc, argv );
 	init_game();
+	change_scene( SCENE_N_INIT );
 
 	if( g_flg_gui ){
 		init_gtk_win( argc, argv );
 
-		if( !call_game_thread_create( main_thread ) )
-			return EXIT_FAILURE;
-
-		// ᥤν򤷤ʤ
-
-		gPcgDun.reset();
-		chk_scroll( TRUE );
-		redraw_all();
-
 		// GUI Υᥤ󡦥롼פ򳫻
 
 		gtk_main();
+
+		close_game( EXIT_SUCCESS );
+		gtk_exit( EXIT_SUCCESS );
 	} else {
 		// CUI Υᥤ󡦥롼פ򳫻
 
 		game_main();
+
+		close_game( EXIT_SUCCESS );
 	}
 
-	close_game( EXIT_SUCCESS );
-	gtk_exit( EXIT_SUCCESS );
+	exit_game( EXIT_SUCCESS );
 	return EXIT_SUCCESS;
 }
 
@@ -110,20 +108,73 @@ int	main( int argc, char **argv )
 
 void	init_gtk_win( int argc, char **argv )
 {
-	GtkAttachOptions xOpt, yOpt;
-
 	// GTK+ 
 
 	g_thread_init( NULL );
 	gdk_threads_init();
 
 	gtk_init( &argc, &argv );
-
 	gdk_rgb_init();
 
 	gPcgDun.nTileSizeRate = g_graph_scale_rate;
 
-	// ᥤ󡦥ɥ
+	init_main_win();
+
+	// ե졼ࡦ졼Ȥ
+
+#if	0
+	gtk_timeout_add( 1000 * 1 / 60, handle_map_redraw,
+			gMapDrawingArea );
+#elif	0
+	gtk_timeout_add( 1000 * 20 / 60, handle_map_redraw,
+			gMapDrawingArea );
+#else
+//@@@
+#endif
+
+	// ȥ
+
+	gPcgDun.initTitle();
+	change_scene( SCENE_N_TITLE );
+	gPcgDun.drawTitle();
+
+	// եå
+
+	gSelConf.init();
+	gSelConf.draw();
+}
+
+////////////////////////////////////////////////////////////////
+// եåν
+////////////////////////////////////////////////////////////////
+
+void	init_main_sel_conf( GraphConf *cnf )
+{
+	// Ƽ
+
+	gPcgDun.init( cnf );
+
+	change_scene( SCENE_N_TOWN );
+
+	gGuiMenu.init();
+	gGuiMessage.init();
+	gGuiStat.init();
+	gKey.init();
+	initMouseMotionFunc();
+
+	gPcgDun.redraw();
+
+	if( !call_game_thread_create( main_thread ) )
+		exit_game( EXIT_FAILURE );
+}
+
+////////////////////////////////////////////////////////////////
+// ᥤ󡦥ɥ
+////////////////////////////////////////////////////////////////
+
+void	init_main_win( void )
+{
+	GtkAttachOptions xOpt, yOpt;
 
 	gMapWin = gtk_window_new( GTK_WINDOW_TOPLEVEL );
 	if( gMapWin == NULL ){
@@ -206,7 +257,8 @@ void	init_gtk_win( int argc, char **argv )
 		exit_game( EXIT_FAILURE );
 	}
 	gtk_drawing_area_size( GTK_DRAWING_AREA( gMapDrawingArea ),
-			MAP_WIN_INIT_WIDTH, MAP_WIN_INIT_HEIGHT );
+			MAP_WIN_INIT_WIDTH(),
+			MAP_WIN_INIT_HEIGHT() );
 	xOpt = (GtkAttachOptions)(GTK_EXPAND | GTK_SHRINK | GTK_FILL);
 	yOpt = (GtkAttachOptions)(GTK_EXPAND | GTK_SHRINK | GTK_FILL);
 	gtk_table_attach( GTK_TABLE( pTab ), gMapDrawingArea,
@@ -240,23 +292,27 @@ void	init_gtk_win( int argc, char **argv )
 			"button_release_event",
 			GTK_SIGNAL_FUNC( handle_map_button_release ),
 			NULL );
+	gtk_signal_connect( GTK_OBJECT( gMapDrawingArea ),
+			"scroll_event",
+			GTK_SIGNAL_FUNC( handle_map_scroll ),
+			NULL );
 	gtk_widget_set_events(
 			gMapDrawingArea,
 			(GDK_EXPOSURE_MASK
-//@@@			| GDK_LEAVE_NOTIFY_MASK
 			| GDK_BUTTON_PRESS_MASK
 			| GDK_BUTTON_RELEASE_MASK
 			| GDK_POINTER_MOTION_MASK
-			| GDK_POINTER_MOTION_HINT_MASK) );
+			| GDK_POINTER_MOTION_HINT_MASK
+			| GDK_SCROLL_MASK) );
 
 	// ʿ롦СĴ
 
 	gMapHScrollBarAdjustment = gtk_adjustment_new(
 			0,
-			0, MAP_PIX_MAX_Y,
-			1 * TILE_Y_SIZE,
-			AREA_MAX_Y * TILE_Y_SIZE / 2,
-			AREA_MAX_Y * TILE_Y_SIZE );
+			0, MAP_PIX_MAX_X(),
+			1 * TILE_X_SIZE(),
+			AREA_MAX_X * TILE_X_SIZE() / 2,
+			AREA_MAX_X * TILE_X_SIZE() );
 	if( gMapHScrollBarAdjustment == NULL ){
 		print_msg( FLG_MSG_ERR, "gtk_adjustment_new()" );
 		exit_game( EXIT_FAILURE );
@@ -294,10 +350,10 @@ void	init_gtk_win( int argc, char **argv )
 
 	gMapVScrollBarAdjustment = gtk_adjustment_new(
 			0,
-			0, MAP_PIX_MAX_X,
-			1 * TILE_X_SIZE,
-			AREA_MAX_X * TILE_X_SIZE / 2,
-			AREA_MAX_X * TILE_X_SIZE );
+			0, MAP_PIX_MAX_Y(),
+			1 * TILE_Y_SIZE(),
+			AREA_MAX_Y * TILE_Y_SIZE() / 2,
+			AREA_MAX_Y * TILE_Y_SIZE() );
 	if( gMapVScrollBarAdjustment == NULL ){
 		print_msg( FLG_MSG_ERR, "gtk_adjustment_new()" );
 		exit_game( EXIT_FAILURE );
@@ -335,41 +391,9 @@ void	init_gtk_win( int argc, char **argv )
 
 	gtk_widget_show( gMapWin );
 
-	// ֥롦Хåե
-
-#if	0
-//@@@
-	gPcgDun.getWBuf() = gdk_pixmap_new(
-			gMapWin->window,
-			MAP_PIX_MAX_X,
-			MAP_PIX_MAX_Y,
-			-1 );
-#endif
-
-	// ץ饤Ȥ
-
-	// ե졼ࡦ졼Ȥ
-
-#if	0
-	gtk_timeout_add( 1000 * 1 / 60, handle_map_redraw,
-			gMapDrawingArea );
-#elif	0
-	gtk_timeout_add( 1000 * 20 / 60, handle_map_redraw,
-			gMapDrawingArea );
-#else
-//@@@
-#endif
-
-	// Ƽ
-
-	gPcgDun.init();
-	gGuiMenu.init();
-	gGuiMessage.init();
-	gGuiStat.init();
-	gKey.init();
-	initMouseMotionFunc();
-
-	gPcgDun.redraw();
+	gtk_drawing_area_size( GTK_DRAWING_AREA( gMapDrawingArea ),
+			MAP_WIN_MIN_WIDTH(),
+			MAP_WIN_MIN_HEIGHT() );
 }
 
 ////////////////////////////////////////////////////////////////
@@ -403,7 +427,9 @@ void	handle_destroy(
 // return : ?
 ////////////////////////////////////////////////////////////////
 
-gint	handle_map_expose( GtkWidget *widget, GdkEventExpose *event )
+gint	handle_map_expose(
+	GtkWidget *widget, GdkEventExpose *event
+)
 {
 	GtkAdjustment *hAdj = GTK_ADJUSTMENT( gMapHScrollBarAdjustment );
 	GtkAdjustment *vAdj = GTK_ADJUSTMENT( gMapVScrollBarAdjustment );
@@ -436,7 +462,9 @@ gint	handle_map_expose( GtkWidget *widget, GdkEventExpose *event )
 // return : ?
 ////////////////////////////////////////////////////////////////
 
-gint	handle_map_configure( GtkWidget *widget, GdkEventConfigure *event )
+gint	handle_map_configure(
+	GtkWidget *widget, GdkEventConfigure *event
+)
 {
 	// ʿ롦СĴ
 
@@ -444,9 +472,9 @@ gint	handle_map_configure( GtkWidget *widget, GdkEventConfigure *event )
 	GtkAdjustment *hAdj = GTK_ADJUSTMENT( gMapHScrollBarAdjustment );
 
 	hAdj->lower = 0;
-	hAdj->upper = MAP_MAX_X * gPcgDun.getTileSizeX();
-	hAdj->step_increment = 1 * gPcgDun.getTileSizeX();
-	hAdj->page_increment = w / 2;
+	hAdj->upper = MAP_MAX_X * TILE_X_SIZE();
+	hAdj->step_increment = 1 * TILE_X_SIZE();
+	hAdj->page_increment = AREA_MAX_X * TILE_X_SIZE();
 	hAdj->page_size = w;
 	if( hAdj->value > hAdj->upper - w )
 		hAdj->value = hAdj->upper - w;
@@ -459,9 +487,9 @@ gint	handle_map_configure( GtkWidget *widget, GdkEventConfigure *event )
 	GtkAdjustment *vAdj = GTK_ADJUSTMENT( gMapVScrollBarAdjustment );
 
 	vAdj->lower = 0;
-	vAdj->upper = MAP_MAX_Y * gPcgDun.getTileSizeY();
-	vAdj->step_increment = 1 * gPcgDun.getTileSizeY();
-	vAdj->page_increment = h / 2;
+	vAdj->upper = MAP_MAX_Y * TILE_Y_SIZE();
+	vAdj->step_increment = 1 * TILE_Y_SIZE();
+	vAdj->page_increment = AREA_MAX_Y * TILE_Y_SIZE();
 	vAdj->page_size = h;
 	if( vAdj->value > vAdj->upper - h )
 		vAdj->value = vAdj->upper - h;
@@ -583,7 +611,7 @@ void	handle_cont_exec_toggled(
 )
 {
 	bool_t flg = gtk_toggle_button_get_active( btn );
-	if( !flg == !chk_continue_exec_mode() )
+	if( !flg == !get_continue_exec_mode() )
 		return;
 
 	if( gtk_toggle_button_get_active( btn ) )
@@ -616,8 +644,8 @@ gint	handle_map_button_press(
 	}
 
 	if( state & (GDK_BUTTON1_MASK | GDK_BUTTON2_MASK
-			| GDK_BUTTON3_MASK | GDK_BUTTON4_MASK
-			| GDK_BUTTON5_MASK) ){
+			| GDK_BUTTON3_MASK
+			| GDK_BUTTON4_MASK | GDK_BUTTON5_MASK) ){
 		GtkAdjustment *hAdj = GTK_ADJUSTMENT(
 				gMapHScrollBarAdjustment );
 		GtkAdjustment *vAdj = GTK_ADJUSTMENT(
@@ -680,6 +708,37 @@ gint	handle_map_button_release(
 	return TRUE;
 }
 
+////////////////////////////////////////////////////////////////
+// ޥåסɥΥޥ롦٥Ƚ
+// GtkWidget *widget : ޥåפΥɥ󥰡ꥢ
+// GdkEventMotion *event : ٥
+// return : ?
+////////////////////////////////////////////////////////////////
+
+gint	handle_map_scroll(
+	GtkWidget *widget, GdkEventScroll *event
+)
+{
+	GdkScrollDirection dir = event->direction;
+
+	switch( dir ){
+	case GDK_SCROLL_LEFT:
+		gMouseMotion.mouseScroll( MouseMotion::nScrollLeft );
+		break;
+	case GDK_SCROLL_RIGHT:
+		gMouseMotion.mouseScroll( MouseMotion::nScrollRight );
+		break;
+	case GDK_SCROLL_UP:
+		gMouseMotion.mouseScroll( MouseMotion::nScrollUp );
+		break;
+	case GDK_SCROLL_DOWN:
+		gMouseMotion.mouseScroll( MouseMotion::nScrollDown );
+		break;
+	}
+
+	return TRUE;
+}
+
 ////////////////////////////////////////////////////////////////
 // ¸ɸ˥ɥɽ
 // GtkWidget *widget : ɥ
