@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: tmenu.c,v 1.107 2007/02/28 21:40:49 bowkenken Exp $
+* $Id: tmenu.c,v 1.117 2007/12/14 23:24:19 bowkenken Exp $
 ***************************************************************/
 
 #define	TMENU_C
@@ -33,6 +33,9 @@
 
 /**/
 
+/* ˡȤʤƤ⥮ɤ뤫? */
+#define	FLG_CAN_ENTER_MAGIC_GUILD_NOT_LEARNED	TRUE
+
 /* ƥŹä˼̤뤫? */
 #define	FLG_IDENTIFY_ITEM_SALE	FALSE
 
@@ -940,6 +943,7 @@ char	*menu_town_mbr_data(
 	mbr_t	**mbr;
 	long	n;
 	long	page_n;
+	data_n_t	data_n;
 
 	if( flg_ls_mbr ){
 		n = g_sel_ls_mbr->ls_mbr_n;
@@ -953,6 +957,7 @@ char	*menu_town_mbr_data(
 		return STR_MENU_ERR;
 
 	page_n = 0;
+	data_n = DATA_N_NEXT_PAGE;
 
 	while( 1 ){
 		long	add;
@@ -962,7 +967,7 @@ char	*menu_town_mbr_data(
 		if( flg_ls_mbr )
 			not_join_mbr( n, prev_mbr_n );
 
-		add = menu_mbr_data( mbr[n], &page_n, edit_kind );
+		add = menu_mbr_data( mbr[n], &page_n, &data_n, edit_kind );
 
 		if( flg_ls_mbr )
 			join_mbr( n, prev_mbr_n );
@@ -2014,6 +2019,9 @@ char	*cb_menu_bar_arrange( long d )
 	ls_mbr = get_ls_mbr();
 	trgt_ls_mbr_n = g_sel_ls_mbr->ls_mbr_n;
 
+	arrange_cast_tab( trgt_ls_mbr_n, d );
+	arrange_auto_mark_mbr( trgt_ls_mbr_n, d );
+
 	tmp_mbr = g_sel_ls_mbr;
 	if( d <= -1 ){
 		for( i = trgt_ls_mbr_n - 1; i >= 0; i-- ){
@@ -2061,6 +2069,7 @@ bool_t	exec_menu_new_mbr( void )
 	mbr_t	**ls_mbr;
 	race_t	race;
 	long	page_n;
+	data_n_t	data_n;
 	ask_t	ask;
 	long	n;
 
@@ -2078,8 +2087,10 @@ bool_t	exec_menu_new_mbr( void )
 			'@', race, MALE, 0, n );
 
 	page_n = 0;
+	data_n = DATA_N_NEXT_PAGE;
+
 	while( 1 ){
-		menu_mbr_data( ls_mbr[n], &page_n,
+		menu_mbr_data( ls_mbr[n], &page_n, &data_n,
 				MBR_DATA_EDIT_KIND_NEW );
 
 		ask = exec_menu_ask(
@@ -2626,28 +2637,39 @@ void	menu_edit_class_inc_abl(
 
 /**/
 
-char	*cb_menu_bar_load( menu_t **pp, menu_t **dflt )
+char	*cb_menu_load_bar( menu_t **pp, menu_t **dflt )
 {
-	menu_bar_load();
+	menu_load_bar();
 
-	return STR_MENU_CANCEL;
+/*@@@*/
+	return NULL;
+	return "/";
+	return "/bar";
 }
 
 /**/
 
-void	menu_bar_load( void )
+char	*cb_menu_save_bar( menu_t **pp, menu_t **dflt )
+{
+	menu_save_bar();
+
+	return NULL;
+}
+
+/**/
+
+void	menu_load_bar( void )
 {
 	if( menu_load( FALSE ) )
-		reset_all( TRUE );
+		reset_all_save( FALSE );
 }
 
 /**/
 
-char	*cb_menu_bar_save( menu_t **pp, menu_t **dflt )
+void	menu_save_bar( void )
 {
-	menu_save( FALSE );
-
-	return STR_MENU_CANCEL;
+	if( menu_save( FALSE ) )
+		reset_all_save( FALSE );
 }
 
 /**/
@@ -2672,6 +2694,14 @@ char	*menu_inn( void )
 	sprintf( p->msg, MSG_MENU_INN_SHORT_STAY,
 			fmt_gold( get_price_inn( TRUE ) ) );
 
+	/* Ͼǰ */
+
+	p = srch_menu( ls_menu_inn, "stay in mews" );
+	if( p == NULL )
+		return STR_MENU_ERR;
+	sprintf( p->msg, MSG_MENU_INN_STAY_IN_MEWS,
+			fmt_gold( 0 ) );
+
 	/**/
 
 	return exec_menu( ls_menu_inn, NULL, NULL );
@@ -2701,7 +2731,7 @@ char	*cb_menu_inn_stay( menu_t **pp, menu_t **dflt )
 	for( mbr_n = 0; mbr_n < MBR_MAX_N; mbr_n++ )
 		add_chr_gold( pty->mbr[mbr_n], -price );
 
-	stay_inn( flg_short );
+	stay_inn( flg_short, FALSE );
 
 	return NULL;
 }
@@ -2715,6 +2745,15 @@ char	*cb_menu_inn_short_stay( menu_t **pp, menu_t **dflt )
 
 /**/
 
+char	*cb_menu_inn_stay_in_mews( menu_t **pp, menu_t **dflt )
+{
+	stay_inn( FALSE, TRUE );
+
+	return NULL;
+}
+
+/**/
+
 char	*cb_menu_inn_bath( menu_t **pp, menu_t **dflt )
 {
 	char	*str_goto;
@@ -2742,7 +2781,7 @@ char	*cb_menu_magic_guild_init( menu_t **pp, menu_t **dflt )
 {
 	menu_t	*ls, *p;
 	unsigned char	key;
-	bool_t	flg;
+	bool_t	flg_no_enter;
 	gold_t	gold;
 	long	i;
 
@@ -2812,39 +2851,42 @@ char	*cb_menu_magic_guild_init( menu_t **pp, menu_t **dflt )
 		}
 	}
 
-	flg = FALSE;
+	if( !FLG_CAN_ENTER_MAGIC_GUILD_NOT_LEARNED ){
+		flg_no_enter = FALSE;
 
-	if( get_lev( g_sel_mbr, ABL_KIND_MAG ) > 0 ){
-		clr_flg_menu( ls, "MAG", FLG_MENU_HIDDEN );
-		flg = TRUE;
-	} else {
-		set_flg_menu( ls, "MAG", FLG_MENU_HIDDEN );
-	}
+		if( get_lev( g_sel_mbr, ABL_KIND_MAG ) > 0 ){
+			clr_flg_menu( ls, "MAG", FLG_MENU_HIDDEN );
+			flg_no_enter = TRUE;
+		} else {
+			set_flg_menu( ls, "MAG", FLG_MENU_HIDDEN );
+		}
 
-	if( get_lev( g_sel_mbr, ABL_KIND_SOR ) > 0 ){
-		clr_flg_menu( ls, "SOR", FLG_MENU_HIDDEN );
-		flg = TRUE;
-	} else {
-		set_flg_menu( ls, "SOR", FLG_MENU_HIDDEN );
-	}
+		if( get_lev( g_sel_mbr, ABL_KIND_SOR ) > 0 ){
+			clr_flg_menu( ls, "SOR", FLG_MENU_HIDDEN );
+			flg_no_enter = TRUE;
+		} else {
+			set_flg_menu( ls, "SOR", FLG_MENU_HIDDEN );
+		}
 
-	if( get_lev( g_sel_mbr, ABL_KIND_ENC ) > 0 ){
-		clr_flg_menu( ls, "ENC", FLG_MENU_HIDDEN );
-		flg = TRUE;
-	} else {
-		set_flg_menu( ls, "ENC", FLG_MENU_HIDDEN );
-	}
+		if( get_lev( g_sel_mbr, ABL_KIND_ENC ) > 0 ){
+			clr_flg_menu( ls, "ENC", FLG_MENU_HIDDEN );
+			flg_no_enter = TRUE;
+		} else {
+			set_flg_menu( ls, "ENC", FLG_MENU_HIDDEN );
+		}
 
-	if( get_lev( g_sel_mbr, ABL_KIND_SUM ) > 0 ){
-		clr_flg_menu( ls, "SUM", FLG_MENU_HIDDEN );
-		flg = TRUE;
-	} else {
-		set_flg_menu( ls, "SUM", FLG_MENU_HIDDEN );
-	}
+		if( get_lev( g_sel_mbr, ABL_KIND_SUM ) > 0 ){
+			clr_flg_menu( ls, "SUM", FLG_MENU_HIDDEN );
+			flg_no_enter = TRUE;
+		} else {
+			set_flg_menu( ls, "SUM", FLG_MENU_HIDDEN );
+		}
 
-	if( !flg ){
-		print_msg( FLG_MSG_ERR, MSG_ERR_SPELL, g_sel_mbr->name );
-		return STR_MENU_CANCEL;
+		if( !flg_no_enter ){
+			print_msg( FLG_MSG_ERR, MSG_ERR_SPELL,
+					g_sel_mbr->name );
+			return STR_MENU_CANCEL;
+		}
 	}
 
 	return NULL;
